@@ -1,21 +1,20 @@
 from __future__ import annotations
 
-from typing import List, Optional, Tuple
+from functools import partial
 
 import gdsfactory as gf
-from gdsfactory.cell import cell
-from gdsfactory.component import Component
-from gdsfactory.types import ComponentSpec, LayerSpec
+from gdsfactory.component import Component, ComponentAllAngle, Instance, container
+from gdsfactory.typings import ComponentSpec, LayerSpec
 
 
 def get_padding_points(
-    component: Component,
+    component: Component | Instance | ComponentAllAngle,
     default: float = 50.0,
-    top: Optional[float] = None,
-    bottom: Optional[float] = None,
-    right: Optional[float] = None,
-    left: Optional[float] = None,
-) -> List[float]:
+    top: float | None = None,
+    bottom: float | None = None,
+    right: float | None = None,
+    left: float | None = None,
+) -> list[list[float]]:
     """Returns padding points for a component outline.
 
     Args:
@@ -32,27 +31,27 @@ def get_padding_points(
     right = right if right is not None else default
     left = left if left is not None else default
     return [
-        [c.xmin - left, c.ymin - bottom],
-        [c.xmax + right, c.ymin - bottom],
-        [c.xmax + right, c.ymax + top],
-        [c.xmin - left, c.ymax + top],
+        [c.dxmin - left, c.dymin - bottom],
+        [c.dxmax + right, c.dymin - bottom],
+        [c.dxmax + right, c.dymax + top],
+        [c.dxmin - left, c.dymax + top],
     ]
 
 
 def add_padding(
     component: ComponentSpec = "mmi2x2",
-    layers: Tuple[LayerSpec, ...] = ("PADDING",),
-    **kwargs,
+    layers: tuple[LayerSpec, ...] = ("PADDING",),
+    default: float = 50.0,
+    top: float | None = None,
+    bottom: float | None = None,
+    right: float | None = None,
+    left: float | None = None,
 ) -> Component:
-    """Adds padding layers to a component inside a container.
-
-    Returns the same ports as the component.
+    """Adds padding layers to component. Returns same component.
 
     Args:
         component: to add padding.
         layers: list of layers.
-
-    keyword Args:
         default: default padding.
         top: north padding in um.
         bottom: south padding in um.
@@ -61,50 +60,24 @@ def add_padding(
     """
     component = gf.get_component(component)
 
-    points = get_padding_points(component, **kwargs)
+    points = get_padding_points(
+        component,
+        default=default,
+        top=top,
+        bottom=bottom,
+        right=right,
+        left=left,
+    )
     for layer in layers:
         component.add_polygon(points, layer=layer)
     return component
 
 
-@cell
-def add_padding_container(
-    component: ComponentSpec,
-    layers: Tuple[LayerSpec, ...] = ("PADDING",),
-    **kwargs,
-) -> Component:
-    """Returns new component with padding added.
-
-    Args:
-        component: to add padding.
-        layers: list of layers.
-
-    Keyword Args:
-        default: default padding in um.
-        top: north padding in um.
-        bottom: south padding in um.
-        right: east padding in um.
-        left: west padding in um.
-    """
-    component = gf.get_component(component)
-
-    c = Component()
-    c.component = component
-    cref = c << component
-
-    points = get_padding_points(component, **kwargs)
-    for layer in layers:
-        c.add_polygon(points, layer=layer)
-    c.ports = cref.ports
-    c.copy_child_info(component)
-    return c
-
-
 def add_padding_to_size(
     component: ComponentSpec,
-    layers: Tuple[LayerSpec, ...] = ("PADDING",),
-    xsize: Optional[float] = None,
-    ysize: Optional[float] = None,
+    layers: tuple[LayerSpec, ...] = ("PADDING",),
+    xsize: float | None = None,
+    ysize: float | None = None,
     left: float = 0,
     bottom: float = 0,
 ) -> Component:
@@ -123,13 +96,13 @@ def add_padding_to_size(
     component = gf.get_component(component)
 
     c = component
-    top = abs(ysize - component.ysize) if ysize else 0
-    right = abs(xsize - component.xsize) if xsize else 0
+    top = abs(ysize - component.dysize) if ysize else 0
+    right = abs(xsize - component.dxsize) if xsize else 0
     points = [
-        [c.xmin - left, c.ymin - bottom],
-        [c.xmax + right, c.ymin - bottom],
-        [c.xmax + right, c.ymax + top],
-        [c.xmin - left, c.ymax + top],
+        [c.dxmin - left, c.dymin - bottom],
+        [c.dxmax + right, c.dymin - bottom],
+        [c.dxmax + right, c.dymax + top],
+        [c.dxmin - left, c.dymax + top],
     ]
 
     for layer in layers:
@@ -138,56 +111,17 @@ def add_padding_to_size(
     return component
 
 
-@cell
-def add_padding_to_size_container(
-    component: ComponentSpec,
-    layers: Tuple[LayerSpec, ...] = ("PADDING",),
-    xsize: Optional[float] = None,
-    ysize: Optional[float] = None,
-    left: float = 0,
-    bottom: float = 0,
-) -> Component:
-    """Returns new component with padding layers on each side. New size is.
-
-    multiple of grid size.
-
-    Args:
-        component: to add padding.
-        layers: list of layers.
-        xsize: x size to fill up in um.
-        ysize: y size to fill up in um.
-        left: left padding in um to fill up in um.
-        bottom: bottom padding in um to fill up in um.
-    """
-    component = gf.get_component(component)
-
-    c = Component()
-    cref = c << component
-
-    top = abs(ysize - component.ysize) if ysize else 0
-    right = abs(xsize - component.xsize) if xsize else 0
-    points = [
-        [cref.xmin - left, cref.ymin - bottom],
-        [cref.xmax + right, cref.ymin - bottom],
-        [cref.xmax + right, cref.ymax + top],
-        [cref.xmin - left, cref.ymax + top],
-    ]
-
-    for layer in layers:
-        c.add_polygon(points, layer=layer)
-
-    c.ports = cref.ports
-    c.copy_child_info(component)
-    return c
+add_padding_container = partial(container, function=add_padding)
+add_padding_to_size_container = partial(container, function=add_padding_to_size)
 
 
 if __name__ == "__main__":
     # test_container()
-    c = gf.components.straight(length=10)
-    c.unlock()
-    cc = add_padding(component=c, layers=["DEVREC"])
 
-    # c = gf.components.straight(length=5)
-    # c.unlock()
-    # cc = add_padding_to_size(component=c, xsize=10, layers=[(2, 0)])
-    cc.show(show_ports=True)
+    # p = partial(add_padding, layers=((1, 0)))
+    c = gf.components.straight(length=10)
+    c1 = add_padding_to_size_container(c, xsize=100, ysize=100)
+    c2 = add_padding_to_size_container(c, xsize=100, ysize=100)
+    print(c1.name)
+    print(c2.name)
+    c2.show()
