@@ -7,38 +7,106 @@ Some functions modify a component without changing its name.
 Make sure these functions are inside a new Component or called as a decorator
 They without modifying the cell name
 """
+
 from __future__ import annotations
 
 import json
+import warnings
+from collections.abc import Callable
 from functools import partial
-from typing import TYPE_CHECKING, Callable, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any
 
-import gdstk
+import kfactory as kf
 import numpy as np
-from numpy import ndarray
-from omegaconf import OmegaConf
+import numpy.typing as npt
+import yaml
 
-from gdsfactory.snap import snap_to_grid
+import gdsfactory as gf
+from gdsfactory.component import container
+from gdsfactory.config import CONF
+from gdsfactory.port import select_ports
+from gdsfactory.serialization import convert_tuples_to_lists
 
 if TYPE_CHECKING:
-    from gdsfactory.component import Component
-    from gdsfactory.component_reference import ComponentReference
+    from gdsfactory.component import Component, Instance
     from gdsfactory.port import Port
 
-Layer = Tuple[int, int]
-Layers = Tuple[Layer, ...]
-LayerSpec = Optional[Union[Layer, str, int]]
-LayerSpecs = Tuple[LayerSpec, ...]
+Layer = tuple[int, int]
+Layers = tuple[Layer, ...]
+LayerSpec = Layer | str | int
+LayerSpecs = tuple[LayerSpec, ...]
 nm = 1e-3
 
 
-def _rotate(v: ndarray, m: ndarray) -> ndarray:
-    return np.dot(m, v)
+def _rotate(
+    vector: npt.NDArray[np.floating[Any]],
+    rotation_matrix: npt.NDArray[np.floating[Any]],
+) -> npt.NDArray[np.floating[Any]]:
+    """Rotate a vector by a rotation matrix."""
+    return rotation_matrix @ vector
+
+
+def add_bbox(
+    component: Component,
+    bbox_layer: LayerSpec = "DEVREC",
+    top: float = 0,
+    bottom: float = 0,
+    left: float = 0,
+    right: float = 0,
+) -> Component:
+    """Add bbox on outline.
+
+    Args:
+        component: component to add bbox.
+        bbox_layer: bbox layer.
+        top: padding.
+        bottom: padding.
+        left: padding.
+        right: padding.
+    """
+    from gdsfactory.pdk import get_layer
+
+    layer = get_layer(bbox_layer)
+    bbox = component.dbbox()
+    dxmin, dymin, dxmax, dymax = bbox.left, bbox.bottom, bbox.right, bbox.top
+    points = [
+        [dxmin - left, dymin - bottom],
+        [dxmax + right, dymin - bottom],
+        [dxmax + right, dymax + top],
+        [dxmin - left, dymax + top],
+    ]
+    component.add_polygon(points, layer=layer)
+    return component
+
+
+def add_bbox_siepic(
+    component: Component,
+    bbox_layer: LayerSpec = "DEVREC",
+    remove_layers: LayerSpecs = ("PORT", "PORTE"),
+) -> Component:
+    """Add bounding box device recognition layer.
+
+    Args:
+        component: to add bbox.
+        bbox_layer: bounding box.
+        remove_layers: remove other layers.
+    """
+    from gdsfactory.pdk import get_layer
+
+    bbox_layer = get_layer(bbox_layer)
+    remove_layers = remove_layers or []
+    remove_layers = list(remove_layers) + [bbox_layer]
+    remove_layers = [get_layer(layer) for layer in remove_layers]
+    component = component.remove_layers(layers=remove_layers, recursive=False)
+
+    if bbox_layer:
+        component.add_padding(default=0, layers=(bbox_layer,))
+    return component
 
 
 def get_pin_triangle_polygon_tip(
     port: Port,
-) -> Tuple[List[float], Tuple[float, float]]:
+) -> tuple[list[float], tuple[float, float]]:
     """Returns triangle polygon and tip position."""
     p = port
     port_face = p.info.get("face", None)
@@ -51,7 +119,7 @@ def get_pin_triangle_polygon_tip(
     ca = np.cos(orientation * np.pi / 180)
     sa = np.sin(orientation * np.pi / 180)
     rot_mat = np.array([[ca, -sa], [sa, ca]])
-    d = p.width / 2
+    d = p.dwidth / 2
 
     dtip = np.array([d, 0])
 
@@ -62,11 +130,11 @@ def get_pin_triangle_polygon_tip(
         dbot = np.array([0, -d])
         dtop = np.array([0, d])
 
-    p0 = p.center + _rotate(dbot, rot_mat)
-    p1 = p.center + _rotate(dtop, rot_mat)
+    p0 = p.dcenter + _rotate(dbot, rot_mat)
+    p1 = p.dcenter + _rotate(dtop, rot_mat)
     port_face = [p0, p1]
 
-    ptip = p.center + _rotate(dtip, rot_mat)
+    ptip = p.dcenter + _rotate(dtip, rot_mat)
 
     polygon = list(port_face) + [ptip]
     polygon = np.stack(polygon)
@@ -103,7 +171,7 @@ def add_pin_rectangle_inside(
     component: Component,
     port: Port,
     pin_length: float = 0.1,
-    layer: LayerSpec = "PORT",
+    layer: LayerSpec | None = "PORT",
     layer_label: LayerSpec = "TEXT",
 ) -> None:
     """Add square pin towards the inside of the port.
@@ -112,8 +180,8 @@ def add_pin_rectangle_inside(
         component: to add pins.
         port: Port.
         pin_length: length of the pin marker for the port.
-        layer: for the pin marker.
-        layer_label: for the label.
+        layer: layer to place the pin rectangle on.
+        layer_label: layer to place the text label on.
 
     .. code::
 
@@ -127,100 +195,17 @@ def add_pin_rectangle_inside(
           |      __       |
           |_______________|
     """
-    p = port
-    a = p.orientation
-    ca = np.cos(a * np.pi / 180)
-    sa = np.sin(a * np.pi / 180)
-    rot_mat = np.array([[ca, -sa], [sa, ca]])
+    if layer:
+        p = port
+        poly = gf.kdb.DPolygon(
+            gf.kdb.DBox(-pin_length, -p.dwidth / 2, 0, p.dwidth / 2)
+        ).transform(p.dcplx_trans)
+        component.shapes(gf.get_layer(layer)).insert(poly)
 
-    d = p.width / 2
-
-    dbot = np.array([0, -d])
-    dtop = np.array([0, d])
-    dbotin = np.array([-pin_length, -d])
-    dtopin = np.array([-pin_length, +d])
-
-    p0 = p.center + _rotate(dbot, rot_mat)
-    p1 = p.center + _rotate(dtop, rot_mat)
-    ptopin = p.center + _rotate(dtopin, rot_mat)
-    pbotin = p.center + _rotate(dbotin, rot_mat)
-    polygon = [p0, p1, ptopin, pbotin]
-    component.add_polygon(polygon, layer=layer)
     if layer_label:
         component.add_label(
-            text=str(p.name),
-            position=p.center,
-            layer=layer_label,
-        )
-
-
-def add_pin_rectangle_double(
-    component: Component,
-    port: Port,
-    pin_length: float = 0.1,
-    layer: LayerSpec = "PORT",
-    layer_label: LayerSpec = "TEXT",
-) -> None:
-    """Add two square pins: one inside with label, one outside.
-
-    Args:
-        component: to add pins.
-        port: Port.
-        pin_length: length of the pin marker for the port.
-        layer: for the pin marker.
-        layer_label: for the label.
-
-    .. code::
-
-           _______________
-          |               |
-          |               |
-          |               |
-         |||              |
-         |||              |
-          |               |
-          |      __       |
-          |_______________|
-                 __
-    """
-    p = port
-    a = p.orientation
-    ca = np.cos(a * np.pi / 180)
-    sa = np.sin(a * np.pi / 180)
-    rot_mat = np.array([[ca, -sa], [sa, ca]])
-
-    # outer square
-    d = p.width / 2
-    dbot = np.array([0, -d])
-    dtop = np.array([0, d])
-    dbotin = np.array([pin_length / 2, -d])
-    dtopin = np.array([pin_length / 2, +d])
-    p0 = p.center + _rotate(dbot, rot_mat)
-    p1 = p.center + _rotate(dtop, rot_mat)
-    ptopin = p.center + _rotate(dtopin, rot_mat)
-    pbotin = p.center + _rotate(dbotin, rot_mat)
-    polygon = [p0, p1, ptopin, pbotin]
-    component.add_polygon(polygon, layer=layer)
-
-    # inner square
-    d = p.width / 2
-    dbot = np.array([0, -d])
-    dtop = np.array([0, d])
-    dbotin = np.array([-pin_length / 2, -d])
-    dtopin = np.array([-pin_length / 2, +d])
-    p0 = p.center + _rotate(dbot, rot_mat)
-    p1 = p.center + _rotate(dtop, rot_mat)
-    ptopin = p.center + _rotate(dtopin, rot_mat)
-    pbotin = p.center + _rotate(dbotin, rot_mat)
-    polygon = [p0, p1, ptopin, pbotin]
-    component.add_polygon(polygon, layer=layer)
-
-    x = (p0[0] + ptopin[0]) / 2
-    y = (ptopin[1] + pbotin[1]) / 2
-    if layer_label:
-        component.add_label(
-            text=str(p.name),
-            position=(x, y),
+            text=port.name,
+            position=port.dcenter,
             layer=layer_label,
         )
 
@@ -229,7 +214,7 @@ def add_pin_rectangle(
     component: Component,
     port: Port,
     pin_length: float = 0.1,
-    layer: LayerSpec = "PORT",
+    layer: LayerSpec | None = "PORT",
     layer_label: LayerSpec = "TEXT",
     port_margin: float = 0.0,
 ) -> None:
@@ -256,30 +241,18 @@ def add_pin_rectangle(
           |_______________|
                  __
     """
-    p = port
-    a = p.orientation
-    ca = np.cos(a * np.pi / 180)
-    sa = np.sin(a * np.pi / 180)
-    rot_mat = np.array([[ca, -sa], [sa, ca]])
-
-    d = p.width / 2 + port_margin
-
-    dbot = np.array([pin_length / 2, -d])
-    dtop = np.array([pin_length / 2, d])
-    dbotin = np.array([-pin_length / 2, -d])
-    dtopin = np.array([-pin_length / 2, +d])
-
-    p0 = p.center + _rotate(dbot, rot_mat)
-    p1 = p.center + _rotate(dtop, rot_mat)
-    ptopin = p.center + _rotate(dtopin, rot_mat)
-    pbotin = p.center + _rotate(dbotin, rot_mat)
-    polygon = [p0, p1, ptopin, pbotin]
-    component.add_polygon(polygon, layer=layer)
+    if layer:
+        p = port
+        width = p.dwidth + port_margin
+        poly = gf.kdb.DPolygon(
+            gf.kdb.DBox(-pin_length / 2, -width / 2, +pin_length / 2, width / 2)
+        ).transform(p.dcplx_trans)
+        component.shapes(gf.get_layer(layer)).insert(poly)
 
     if layer_label:
         component.add_label(
             text=str(p.name),
-            position=p.center,
+            position=p.dcenter,
             layer=layer_label,
         )
 
@@ -289,7 +262,7 @@ def add_pin_path(
     port: Port,
     pin_length: float = 2 * nm,
     layer: LayerSpec = "PORT",
-    layer_label: LayerSpec = None,
+    layer_label: LayerSpec | None = None,
 ) -> None:
     """Add half out path pin to a component.
 
@@ -327,31 +300,26 @@ def add_pin_path(
     d0 = np.array([-pin_length / 2, 0])
     d1 = np.array([+pin_length / 2, 0])
 
-    p0 = p.center + _rotate(d0, rot_mat)
-    p1 = p.center + _rotate(d1, rot_mat)
+    p0 = p.dcenter + _rotate(d0, rot_mat)
+    p1 = p.dcenter + _rotate(d1, rot_mat)
 
     points = [p0, p1]
+    points = [kf.kdb.DPoint(p[0], p[1]) for p in points]
     layer = get_layer(layer)
-    path = gdstk.FlexPath(
-        points,
-        width=p.width,
-        layer=layer[0],
-        datatype=layer[1],
-        simple_path=True,
-        tolerance=1e-3,
-    )
-    component.add(path)
 
-    component.add_label(
-        text=str(p.name), position=p.center, layer=layer_label, anchor="sw"
+    dpath = kf.kdb.DPath(
+        points,
+        p.dwidth,
     )
+    component.add_label(text=str(p.name), position=p.dcenter, layer=layer_label)
+    component.shapes(layer).insert(dpath)
 
 
 def add_outline(
     component: Component,
-    reference: Optional[ComponentReference] = None,
+    reference: Instance | None = None,
     layer: LayerSpec = "DEVREC",
-    **kwargs,
+    **kwargs: Any,
 ) -> None:
     """Adds devices outline bounding box in layer.
 
@@ -359,6 +327,7 @@ def add_outline(
         component: where to add the markers.
         reference: to read outline from.
         layer: to add padding.
+        kwargs: padding settings.
 
     Keyword Args:
         default: default padding.
@@ -380,8 +349,9 @@ def add_pins_siepic(
     component: Component,
     function: Callable = add_pin_path,
     port_type: str = "optical",
-    layer_pin: LayerSpec = "PORT",
+    layer: LayerSpec = "PORT",
     pin_length: float = 10 * nm,
+    **kwargs: Any,
 ) -> Component:
     """Add pins.
 
@@ -396,194 +366,148 @@ def add_pins_siepic(
         component: to add pins.
         function: to add pin.
         port_type: optical, electrical, ...
-        layer_pin: pin layer.
+        layer: pin layer.
         pin_length: length of the pin marker for the port.
+        kwargs: add pins function settings.
     """
+    from gdsfactory.pdk import get_component
+
+    component = get_component(component)
+
     for p in component.get_ports_list(port_type=port_type):
-        function(component=component, port=p, layer=layer_pin, pin_length=pin_length)
+        function(
+            component=component, port=p, layer=layer, pin_length=pin_length, **kwargs
+        )
 
     return component
 
 
 add_pins_siepic_optical = add_pins_siepic
 add_pins_siepic_electrical = partial(
-    add_pins_siepic, port_type="electrical", layer_pin="PORTE"
+    add_pins_siepic, port_type="electrical", layer="PORTE"
 )
 
 
-def add_bbox_siepic(
-    component: Component,
-    bbox_layer: LayerSpec = "DEVREC",
-    remove_layers: LayerSpecs = ("PORT", "PORTE"),
-) -> Component:
-    """Add bounding box device recognition layer.
-
-    Args:
-        component: to add bbox.
-        bbox_layer: bounding box.
-        remove_layers: remove other layers.
-    """
-    from gdsfactory.pdk import get_layer
-
-    bbox_layer = get_layer(bbox_layer)
-    layers = component.get_layers()
-
-    if bbox_layer and bbox_layer in layers:
-        component.remove_layers(layers=(bbox_layer,), recursive=False)
-
-    remove_layers = remove_layers or []
-
-    for layer in remove_layers:
-        layer = get_layer(layer)
-        if layer in layers:
-            component.remove_layers(layers=(layer,), recursive=False)
-
-    if bbox_layer:
-        component.add_padding(default=0, layers=(bbox_layer,))
-    return component
-
-
-def add_pins_bbox_siepic(
-    component: Component,
-    function: Callable = add_pin_path,
-    port_type: str = "optical",
-    layer_pin: LayerSpec = "PORT",
-    pin_length: float = 10 * nm,
-    bbox_layer: LayerSpec = "DEVREC",
-    padding: float = 0,
-) -> Component:
-    """Add bounding box device recognition layer.
-
-    Args:
-        component: to add pins.
-        function: to add pins.
-        port_type: optical, electrical...
-        layer_pin: for pin.
-        pin_length: in um.
-        bbox_layer: bounding box layer.
-        padding: around device.
-    """
-    layers = component.get_layers()
-    remove_layers = (layer_pin, bbox_layer)
-
-    for layer in remove_layers:
-        if layer in layers:
-            component.remove_layers(layers=(layer,))
-    component.add_padding(default=padding, layers=(bbox_layer,))
-
-    component = add_pins_siepic(
-        component=component,
-        function=function,
-        port_type=port_type,
-        layer_pin=layer_pin,
-        pin_length=pin_length,
-    )
-    return component
-
-
-add_pins_siepic_optical_2nm = partial(add_pins_siepic_optical, pin_length=2 * nm)
-add_pins_siepic_electrical_2nm = partial(add_pins_siepic_electrical, pin_length=2 * nm)
-add_pins_bbox_siepic_2nm = partial(add_pins_bbox_siepic, pin_length=2 * nm)
-
-
 def add_pins(
     component: Component,
-    reference: Optional[ComponentReference] = None,
+    port_type: str | None = None,
     function: Callable = add_pin_rectangle_inside,
-    select_ports: Optional[Callable] = None,
-    **kwargs,
-) -> Component:
+    **kwargs: Any,
+) -> None:
     """Add Pin port markers.
 
-    Be careful with this function as it modifies the component.
-
     Args:
         component: to add ports to.
-        reference: to add pins.
+        port_type: Which port type do you want to add pins to. optical, electrical, ...  If None, it will add to all.
+        layer: layer for the pin marker.
         function: to add each pin.
-        select_ports: function to select_ports.
         kwargs: add pins function settings.
     """
-    reference = reference or component
-    ports = (
-        select_ports(reference.ports).values()
-        if select_ports
-        else reference.get_ports_list()
+    from gdsfactory.pdk import get_component
+
+    component = get_component(component)
+
+    # This should only select ports according to the port type
+    ports = select_ports(
+        ports=component.ports,
+        port_type=port_type,
     )
+
     for port in ports:
         function(component=component, port=port, **kwargs)
-    return component
 
 
 add_pins_triangle = partial(add_pins, function=add_pin_triangle)
 add_pins_center = partial(add_pins, function=add_pin_rectangle)
+add_pin_inside1nm = partial(
+    add_pin_rectangle_inside, pin_length=1 * nm, layer_label=None
+)
+add_pin_inside2um = partial(add_pin_rectangle_inside, pin_length=2, layer_label=None)
+add_pins_inside1nm = partial(add_pins, function=add_pin_inside1nm)
+add_pins_inside2um = partial(add_pins, function=add_pin_inside2um)
 
 
 def add_settings_label(
     component: Component,
-    reference: ComponentReference,
+    reference: Instance | None = None,
     layer_label: LayerSpec = "LABEL_SETTINGS",
+    with_yaml_format: bool = False,
 ) -> None:
     """Add settings in label.
 
     Args:
         component: to add pins.
-        reference: ComponentReference.
+        reference: Instance.
         layer_label: layer spec.
+        with_yaml_format: add yaml format, False uses json.
     """
     from gdsfactory.pdk import get_layer
 
     layer_label = get_layer(layer_label)
 
-    settings_dict = OmegaConf.to_container(reference.settings.full)
-    settings_string = f"settings={json.dumps(settings_dict)}"
+    reference = reference or component
+    info = reference.cell.info
+    settings_dict = dict(info)
+    settings_string = (
+        yaml.dump(convert_tuples_to_lists(settings_dict))
+        if with_yaml_format
+        else f"settings={json.dumps(settings_dict)}"
+    )
     if len(settings_string) > 1024:
         raise ValueError(f"label > 1024 characters: {settings_string}")
     component.add_label(
-        position=reference.center, text=settings_string, layer=layer_label
+        position=reference.dcenter, text=settings_string, layer=layer_label
     )
 
 
 def add_instance_label(
     component: Component,
-    reference: ComponentReference,
-    instance_name: Optional[str] = None,
-    layer: LayerSpec = "LABEL_INSTANCE",
+    reference: Instance,
+    layer: LayerSpec | None = None,
+    instance_name: str | None = None,
 ) -> None:
-    """Adds label to a reference in a component."""
+    """Adds label to a reference in a component.
+
+    Args:
+        component: to add instance label.
+        reference: to add label.
+        layer: layer for the label.
+        instance_name: label name.
+
+    """
+    try:
+        layer = layer or gf.get_layer("LABEL_INSTANCE")
+    except ValueError:
+        warnings.warn("Layer LABEL_INSTANCE not found in PDK.layers, using (1, 0)")
+        layer = (1, 0)
     instance_name = (
         instance_name
-        or f"{reference.parent.name},{int(reference.x)},{int(reference.y)}"
+        or f"{reference.parent.name},{int(reference.dx)},{int(reference.dy)}"
     )
-    x = snap_to_grid(reference.x)
-    y = snap_to_grid(reference.y)
+
+    layer = layer or CONF.layer_label
 
     component.add_label(
         text=instance_name,
-        position=(x, y),
+        position=reference.dcenter,
         layer=layer,
     )
 
 
 def add_pins_and_outline(
     component: Component,
-    reference: Optional[ComponentReference] = None,
-    add_outline_function: Optional[Callable] = add_outline,
-    add_pins_function: Optional[Callable] = add_pins,
-    add_settings_function: Optional[Callable] = add_settings_label,
-    add_instance_label_function: Optional[Callable] = add_settings_label,
+    reference: Instance | None = None,
+    add_outline_function: Callable | None = add_outline,
+    add_pins_function: Callable | None = add_pins,
+    add_settings_function: Callable | None = add_settings_label,
+    add_instance_label_function: Callable | None = add_settings_label,
 ) -> None:
-    """Add markers.
-
-    - outline
-    - pins for the ports
-    - label for the name
-    - label for the settings
+    """Add pins component outline.
 
     Args:
         component: where to add the markers.
         reference: to add pins.
-        add_outline_function.
+        add_outline_function: to add outline around the component.
         add_pins_function: to add pins to ports.
         add_settings_function: to add outline around the component.
         add_instance_label_function: labels each instance.
@@ -598,18 +522,31 @@ def add_pins_and_outline(
         add_instance_label_function(component=component, reference=reference)
 
 
+add_pins_container = partial(container, function=add_pins)
+add_pins_siepic_container = partial(container, function=add_pins_siepic)
+
 if __name__ == "__main__":
     import gdsfactory as gf
 
     # c = test_add_pins()
-    # c.show(show_ports=True)
+    # c.show( )
     # c = gf.components.straight(length=2)
     # c.show(show_ports_suborts=True)
     # p1 = len(c1.get_polygons())
     # p2 = len(c2.get_polygons())
     # assert p2 == p1 + 2
     # c1 = gf.components.straight_heater_metal(length=2)
-    c = gf.components.straight(decorator=add_pins)
-    # cc.show(show_ports=False)
-    c.show(show_subports=True)
-    c.show(show_ports=True)
+    # c = gf.components.bend_euler()
+    # c = add_pins_container(c)
+    # add_pins_triangle(c)
+    # c = add_pins_container(c)
+    # cc.show()
+    # c.show(show_subports=True)
+    # c.show( )
+
+    c = gf.Component()
+    ref = c << gf.components.straight()
+    c.add_ports(ref.ports)
+
+    add_pin_rectangle(c, port=c.ports[0], port_margin=1)
+    c.show()
