@@ -1,17 +1,16 @@
 from __future__ import annotations
 
-from typing import Tuple
-
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec, Size
 
 
 @gf.cell
 def C(
     width: float = 1.0,
-    size: Tuple[float, float] = (10.0, 20.0),
+    size: Size = (10.0, 20.0),
     layer: LayerSpec = "WG",
+    port_type: str = "electrical",
 ) -> Component:
     """C geometry with ports on both ends.
 
@@ -21,6 +20,7 @@ def C(
         width: of the line.
         size: length and height of the base.
         layer: layer spec.
+        port_type: optical or electrical.
 
     .. code::
 
@@ -48,12 +48,12 @@ def C(
         (-w, -w),
     ]
     c.add_polygon(points, layer=layer)
-    c.add_port(name="o1", center=(s1, s2), width=width, orientation=0, layer=layer)
-    c.add_port(name="o2", center=(s1, 0), width=width, orientation=0, layer=layer)
+    port_settings = dict(width=width, orientation=0, layer=layer, port_type=port_type)
+    c.add_port(name="o1", center=(s1, s2), **port_settings)
+    c.add_port(name="o2", center=(s1, 0), **port_settings)
     return c
 
 
 if __name__ == "__main__":
-
     c = C(width=1.0)
-    c.show(show_ports=True)
+    c.show()
