@@ -1,17 +1,15 @@
 from __future__ import annotations
 
-from typing import Tuple, Union
-
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
 def L(
-    width: Union[int, float] = 1,
-    size: Tuple[int, int] = (10, 20),
-    layer: LayerSpec = "M3",
+    width: int | float = 1,
+    size: tuple[int, int] = (10, 20),
+    layer: LayerSpec = "MTOP",
     port_type: str = "electrical",
 ) -> Component:
     """Generates an 'L' geometry with ports on both ends.
@@ -49,6 +47,5 @@ def L(
 
 
 if __name__ == "__main__":
-
     c = L()
-    c.show(show_ports=True)
+    c.show()
