@@ -1,21 +1,18 @@
 from __future__ import annotations
 
-from typing import Optional, Tuple
-
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.rectangle import rectangle
-from gdsfactory.types import ComponentSpec, LayerSpec
+from gdsfactory.typings import ComponentSpec, LayerSpec
 
 
-@cell
+@gf.cell
 def align_wafer(
     width: float = 10.0,
     spacing: float = 10.0,
     cross_length: float = 80.0,
     layer: LayerSpec = "WG",
-    layer_cladding: Optional[Tuple[int, int]] = None,
+    layer_cladding: tuple[int, int] | None = None,
     square_corner: str = "bottom_left",
 ) -> Component:
     """Returns cross inside a frame to align wafer.
@@ -37,16 +34,18 @@ def align_wafer(
     w = width
 
     rh = rectangle(size=(2 * b + w, w), layer=layer, centered=True)
+    rv = rectangle(size=(w, 2 * b), layer=layer, centered=True)
+
     rtop = c.add_ref(rh)
     rbot = c.add_ref(rh)
-    rtop.movey(+b)
-    rbot.movey(-b)
 
-    rv = rectangle(size=(w, 2 * b), layer=layer, centered=True)
+    rtop.dmovey(+b)
+    rbot.dmovey(-b)
+
     rl = c.add_ref(rv)
     rr = c.add_ref(rv)
-    rl.movex(-b)
-    rr.movex(+b)
+    rl.dmovex(-b)
+    rr.dmovex(+b)
 
     wsq = (cross_length + 2 * spacing) / 4
     square_mark = c << rectangle(size=(wsq, wsq), layer=layer, centered=True)
@@ -59,7 +58,7 @@ def align_wafer(
         "top_left": (-a, a),
     }
 
-    square_mark.move(corner_to_position[square_corner])
+    square_mark.dmove(corner_to_position[square_corner])
 
     if layer_cladding:
         rc_tile_excl = rectangle(
@@ -72,7 +71,7 @@ def align_wafer(
     return c
 
 
-@cell
+@gf.cell
 def add_frame(
     component: ComponentSpec = rectangle,
     width: float = 10.0,
@@ -91,32 +90,29 @@ def add_frame(
     layer = gf.get_layer(layer)
     component = gf.get_component(component)
     cref = c.add_ref(component)
-    cref.move(-c.size_info.center)
-    y = (
-        max([component.size_info.height, component.size_info.width]) / 2
-        + spacing
-        + width / 2
-    )
+    cref.dx = 0
+    cref.dy = 0
+    y = max([component.dxsize, component.dysize]) / 2 + spacing + width / 2
     x = y
     w = width
 
     rh = rectangle(size=(2 * y + w, w), layer=layer, centered=True)
     rtop = c.add_ref(rh)
     rbot = c.add_ref(rh)
-    rtop.movey(+y)
-    rbot.movey(-y)
+    rtop.dmovey(+y)
+    rbot.dmovey(-y)
 
     rv = rectangle(size=(w, 2 * y), layer=layer, centered=True)
     rl = c.add_ref(rv)
     rr = c.add_ref(rv)
-    rl.movex(-x)
-    rr.movex(+x)
-    c.absorb(cref)
+    rl.dmovex(-x)
+    rr.dmovex(+x)
+    c.flatten()
     return c
 
 
 if __name__ == "__main__":
-    # c = gf.components.straight()
-    # c = add_frame(component=c)
-    c = align_wafer()
-    c.show(show_ports=True)
+    c = gf.components.straight()
+    c = add_frame(component=c)
+    # c = align_wafer()
+    c.show()
