@@ -1,12 +1,14 @@
 """Sample AWG."""
+
 from __future__ import annotations
 
+from functools import partial
+
 import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.cross_section import strip
-from gdsfactory.types import CrossSectionSpec
+from gdsfactory.typings import ComponentFactory, CrossSectionSpec
 
 
 @gf.cell
@@ -17,11 +19,19 @@ def free_propagation_region(
     wg_width: float = 0.5,
     inputs: int = 1,
     outputs: int = 10,
-    cross_section: CrossSectionSpec = strip,
-    **kwargs,
+    cross_section: CrossSectionSpec = "strip",
 ) -> Component:
     r"""Free propagation region.
 
+    Args:
+        width1: width of the input region.
+        width2: width of the output region.
+        length: length of the free propagation region.
+        wg_width: waveguide width.
+        inputs: number of inputs.
+        outputs: number of outputs.
+        cross_section: cross_section function.
+
     .. code::
 
                  length
@@ -34,15 +44,15 @@ def free_propagation_region(
     """
     y1 = width1 / 2
     y2 = width2 / 2
-    x = cross_section(**kwargs)
+    xs = gf.get_cross_section(cross_section)
     o = 0
-    layer = x.layer
+    layer = xs.layer
 
     xpts = [0, length, length, 0]
     ypts = [y1, y2, -y2, -y1]
 
     c = gf.Component()
-    c.add_polygon((xpts, ypts), layer=layer)
+    c.add_polygon(list(zip(xpts, ypts)), layer=layer)
 
     if inputs == 1:
         c.add_port(
@@ -60,7 +70,7 @@ def free_propagation_region(
                 f"W{i}",
                 center=(0, yi),
                 width=wg_width,
-                orientation=0,
+                orientation=180,
                 layer=layer,
             )
 
@@ -83,74 +93,74 @@ def free_propagation_region(
     return c
 
 
-@gf.cell
-def free_propagation_region_input(inputs: int = 1, **kwargs) -> Component:
-    return free_propagation_region(inputs=inputs, **kwargs)
+free_propagation_region_input = partial(free_propagation_region, inputs=1)
 
-
-@gf.cell
-def free_propagation_region_output(
-    inputs: int = 10, width1: float = 10.0, width2: float = 20.0, **kwargs
-) -> Component:
-    return free_propagation_region(
-        inputs=inputs, width2=width2, width1=width1, **kwargs
-    )
+free_propagation_region_output = partial(
+    free_propagation_region, inputs=10, width1=10, width2=20.0
+)
 
 
 @gf.cell
 def awg(
     arms: int = 10,
     outputs: int = 3,
-    free_propagation_region_input_function=free_propagation_region_input,
-    free_propagation_region_output_function=free_propagation_region_output,
+    free_propagation_region_input_function: ComponentFactory = free_propagation_region_input,
+    free_propagation_region_output_function: ComponentFactory = free_propagation_region_output,
     fpr_spacing: float = 50.0,
+    arm_spacing: float = 1.0,
+    cross_section: CrossSectionSpec = "strip",
 ) -> Component:
     """Returns a basic Arrayed Waveguide grating.
 
+    To simulate you can use
+    https://github.com/dnrobin/awg-python
+
     Args:
         arms: number of arms.
         outputs: number of outputs.
         free_propagation_region_input_function: for input.
         free_propagation_region_output_function: for output.
         fpr_spacing: x separation between input/output free propagation region.
+        arm_spacing: y separation between arms.
+        cross_section: cross_section function.
     """
     c = Component()
     fpr_in = free_propagation_region_input_function(
         inputs=1,
         outputs=arms,
+        cross_section=cross_section,
     )
     fpr_out = free_propagation_region_output_function(
         inputs=outputs,
         outputs=arms,
+        cross_section=cross_section,
     )
 
     fpr_in_ref = c.add_ref(fpr_in)
     fpr_out_ref = c.add_ref(fpr_out)
 
-    fpr_in_ref.rotate(90)
-    fpr_out_ref.rotate(90)
+    fpr_in_ref.drotate(90)
+    fpr_out_ref.drotate(90)
 
-    fpr_out_ref.x += fpr_spacing
-    routes = gf.routing.get_bundle(
-        fpr_in_ref.get_ports_list(prefix="E"), fpr_out_ref.get_ports_list(prefix="E")
+    fpr_out_ref.dx += fpr_spacing
+    _ = gf.routing.route_bundle(
+        c,
+        gf.port.get_ports_list(fpr_out_ref, prefix="E"),
+        gf.port.get_ports_list(fpr_in_ref, prefix="E"),
+        sort_ports=True,
+        separation=arm_spacing,
+        cross_section=cross_section,
     )
 
-    c.lengths = []
-    for route in routes:
-        c.add(route.references)
-        c.lengths.append(route.length)
-
     c.add_port("o1", port=fpr_in_ref.ports["o1"])
 
-    for i, port in enumerate(fpr_out_ref.get_ports_list(prefix="W")):
+    for i, port in enumerate(gf.port.get_ports_list(fpr_out_ref, prefix="W")):
         c.add_port(f"E{i}", port=port)
 
-    c.delta_length = np.mean(np.diff(c.lengths))
     return c
 
 
 if __name__ == "__main__":
     # c = free_propagation_region(inputs=2, outputs=4)
-    # print(c.ports.keys())
     c = awg()
-    c.show(show_ports=True)
+    c.show()
