@@ -1,15 +1,14 @@
 from __future__ import annotations
 
-from typing import Optional
-
 import numpy as np
+import numpy.typing as npt
 from numpy import ndarray
 
 import gdsfactory as gf
-from gdsfactory.add_padding import get_padding_points
 from gdsfactory.component import Component
-from gdsfactory.geometry.functions import angles_deg, curvature, path_length, snap_angle
-from gdsfactory.types import Coordinate, Coordinates, CrossSectionSpec
+from gdsfactory.config import ErrorType
+from gdsfactory.functions import angles_deg, curvature, snap_angle
+from gdsfactory.typings import Coordinate, Coordinates, CrossSectionSpec
 
 
 def bezier_curve(t: ndarray, control_points: Coordinates) -> ndarray:
@@ -17,7 +16,7 @@ def bezier_curve(t: ndarray, control_points: Coordinates) -> ndarray:
 
     Args:
         t: 1D array of points varying between 0 and 1.
-        control_points:
+        control_points: for the bezier curve.
     """
     from scipy.special import binom
 
@@ -34,29 +33,28 @@ def bezier_curve(t: ndarray, control_points: Coordinates) -> ndarray:
 
 @gf.cell
 def bezier(
-    width: float = 0.5,
-    control_points: Coordinates = ((0.0, 0.0), (5.0, 0.0), (5.0, 2.0), (10.0, 2.0)),
+    control_points: Coordinates = ((0.0, 0.0), (5.0, 0.0), (5.0, 1.8), (10.0, 1.8)),
     npoints: int = 201,
     with_manhattan_facing_angles: bool = True,
-    start_angle: Optional[int] = None,
-    end_angle: Optional[int] = None,
+    start_angle: int | None = None,
+    end_angle: int | None = None,
     cross_section: CrossSectionSpec = "strip",
-    with_bbox: bool = True,
-    **kwargs,
+    bend_radius_error_type: ErrorType | None = None,
+    allow_min_radius_violation: bool = False,
 ) -> Component:
     """Returns Bezier bend.
 
     Args:
-        width: straight width (um).
         control_points: list of points.
         npoints: number of points varying between 0 and 1.
         with_manhattan_facing_angles: bool.
         start_angle: optional start angle in deg.
         end_angle: optional end angle in deg.
         cross_section: spec.
-        with_bbox: box in bbox_layers and bbox_offsets to avoid DRC sharp edges.
+        bend_radius_error_type: error type.
+        allow_min_radius_violation: bool.
     """
-    xs = gf.get_cross_section(cross_section, **kwargs)
+    xs = gf.get_cross_section(cross_section)
     t = np.linspace(0, 1, npoints)
     path_points = bezier_curve(t, control_points)
     path = gf.Path(path_points)
@@ -65,37 +63,34 @@ def bezier(
         path.start_angle = start_angle or snap_angle(path.start_angle)
         path.end_angle = end_angle or snap_angle(path.end_angle)
 
-    c = Component()
-    bend = path.extrude(xs)
-    bend_ref = c << bend
-    c.add_ports(bend_ref.ports)
-    c.absorb(bend_ref)
+    c = path.extrude(xs)
     curv = curvature(path_points, t)
-    length = gf.snap.snap_to_grid(path_length(path_points))
-    min_bend_radius = gf.snap.snap_to_grid(1 / max(np.abs(curv)))
+    length = path.length()
+    if max(np.abs(curv)) == 0:
+        min_bend_radius = np.inf
+    else:
+        min_bend_radius = float(gf.snap.snap_to_grid(1 / max(np.abs(curv))))
+
     c.info["length"] = length
     c.info["min_bend_radius"] = min_bend_radius
-    c.info["start_angle"] = path.start_angle
-    c.info["end_angle"] = path.end_angle
+    c.info["start_angle"] = float(path.start_angle)
+    c.info["end_angle"] = float(path.end_angle)
+    c.add_route_info(
+        cross_section=xs,
+        length=c.info["length"],
+        n_bend_s=1,
+        min_bend_radius=min_bend_radius,
+    )
 
-    if with_bbox:
-        padding = []
-        for offset in xs.bbox_offsets:
-            points = get_padding_points(
-                component=c,
-                default=0,
-                bottom=offset,
-                top=offset,
-            )
-            padding.append(points)
+    if not allow_min_radius_violation:
+        xs.validate_radius(min_bend_radius, bend_radius_error_type)
 
-        for layer, points in zip(xs.bbox_layers, padding):
-            c.add_polygon(points, layer=layer)
+    xs.add_bbox(c)
     return c
 
 
 def find_min_curv_bezier_control_points(
-    start_point: ndarray,
+    start_point: npt.NDArray[np.float64],
     end_point: Coordinate,
     start_angle: float,
     end_angle: float,
@@ -103,21 +98,28 @@ def find_min_curv_bezier_control_points(
     alpha: float = 0.05,
     nb_pts: int = 2,
 ) -> Coordinates:
+    """Returns bezier control points that minimize curvature.
+
+    Args:
+        start_point: start point.
+        end_point: end point.
+        start_angle: start angle in deg.
+        end_angle: end angle in deg.
+        npoints: number of points varying between 0 and 1.
+        alpha: weight for angle mismatch.
+        nb_pts: number of control points.
+    """
     from scipy.optimize import minimize
 
     t = np.linspace(0, 1, npoints)
 
-    def array_1d_to_cpts(a):
+    def array_1d_to_cpts(a: npt.NDArray[np.float64]) -> list[tuple[float, float]]:
         xs = a[::2]
         ys = a[1::2]
         return list(zip(xs, ys))
 
-    def objective_func(p):
-        """We want to minimize a combination of the following.
-
-        - max curvature
-        - negligible mismatch with start angle and end angle
-        """
+    def objective_func(p: npt.NDArray[np.float64]) -> float:
+        """Minimize  max curvaturea and negligible start angle and end angle mismatch."""
         ps = array_1d_to_cpts(p)
         control_points = [start_point] + ps + [end_point]
         path_points = bezier_curve(t, control_points)
@@ -140,39 +142,13 @@ def find_min_curv_bezier_control_points(
         initial_guess += [x, y]
 
     # initial_guess = [(x0 + xn) / 2, y0, (x0 + xn) / 2, yn]
-
     res = minimize(objective_func, initial_guess, method="Nelder-Mead")
-
     p = res.x
-    return [tuple(start_point)] + array_1d_to_cpts(p) + [tuple(end_point)]
+    points = [tuple(start_point)] + array_1d_to_cpts(p) + [tuple(end_point)]
+    return tuple(points)
 
 
 if __name__ == "__main__":
-    # control_points = ((0.0, 0.0), (5.0, 0.0), (5.0, 5.0), (10.0, 5.0))
-    # cross_section = gf.get_cross_section(
-    #     "strip", bbox_offsets=[0.5], bbox_layers=[(111, 0)]
-    # )
-    # npoints = 201
-    # with_manhattan_facing_angles = True
-    # xs = gf.get_cross_section(
-    #     cross_section,
-    # )
-    # t = np.linspace(0, 1, npoints)
-    # path_points = bezier_curve(t, control_points)
-    # path = gf.Path(path_points)
-
-    # if with_manhattan_facing_angles:
-    #     angles = angles_deg(path_points)
-    #     path.start_angle = snap_angle(angles[0])
-    #     path.end_angle = snap_angle(angles[-2])
-    # c = path.extrude(xs)
-
-    # points = ((0.0, 0.0), (5.0, 0.0), (5.0, 5.0), (10.0, 5.0))
-    # c = bezier(control_points=points)
-    # c.pprint()
-    # print(c.ports)
-    # print(c.ports["0"].y - c.ports["1"].y)
-    # c.write_gds()
-
-    c = bezier(bbox_offsets=[0.5], bbox_layers=[(111, 0)])
-    c.show(show_ports=True)
+    control_points = ((0.0, 0.0), (5.0, 0.0), (5.0, 5.0), (10.0, 5.0))
+    c = bezier(control_points=control_points)
+    c.show()
