@@ -1,31 +1,27 @@
 """CD SEM structures."""
+
 from __future__ import annotations
 
-from functools import partial
-from typing import Optional, Tuple
-
-from gdsfactory.cell import cell
+import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.cdsem_bend180 import cdsem_bend180
 from gdsfactory.components.cdsem_straight import cdsem_straight
 from gdsfactory.components.cdsem_straight_density import cdsem_straight_density
-from gdsfactory.components.text_rectangular import text_rectangular
-from gdsfactory.types import ComponentSpec, CrossSectionSpec
-
-text_rectangular_mini = partial(text_rectangular, size=1)
+from gdsfactory.typings import ComponentFactory, ComponentSpec, CrossSectionSpec
 
 
-@cell
+@gf.cell
 def cdsem_all(
-    widths: Tuple[float, ...] = (0.4, 0.45, 0.5, 0.6, 0.8, 1.0),
-    dense_lines_width: Optional[float] = 0.3,
+    widths: tuple[float, ...] = (0.4, 0.45, 0.5, 0.6, 0.8, 1.0),
+    dense_lines_width: float | None = 0.3,
     dense_lines_width_difference: float = 20e-3,
     dense_lines_gap: float = 0.3,
-    dense_lines_labels: Tuple[str, ...] = ("DL", "DM", "DH"),
+    dense_lines_labels: tuple[str, ...] = ("DL", "DM", "DH"),
     straight: ComponentSpec = "straight",
-    bend90: Optional[ComponentSpec] = "bend_circular",
+    bend90: ComponentSpec | None = "bend_circular",
     cross_section: CrossSectionSpec = "strip",
-    text: ComponentSpec = text_rectangular_mini,
+    text: ComponentFactory = "text_rectangular_mini",
+    spacing: float = 5,
 ) -> Component:
     """Column with all optical PCMs.
 
@@ -39,6 +35,7 @@ def cdsem_all(
         bend90: spec.
         cross_section: spec.
         text: spec.
+        spacing: from group to group.
     """
     c = Component()
     _c1 = cdsem_straight(
@@ -77,8 +74,8 @@ def cdsem_all(
 
         all_devices += [
             cdsem_straight_density(
-                widths=[w] * 10,
-                gaps=[g] * 10,
+                widths=(w,) * 10,
+                gaps=(g,) * 10,
                 label=lbl,
                 cross_section=cross_section,
                 text=text,
@@ -86,12 +83,16 @@ def cdsem_all(
             for w, g, lbl in density_params
         ]
 
-    [c.add_ref(d) for d in all_devices]
-    c.align(elements="all", alignment="xmin")
-    c.distribute(elements="all", direction="y", spacing=5, separation=True)
+    ymin = 0
+    for d in all_devices:
+        ref = c.add_ref(d)
+        ref.dxmin = 0
+        ref.dymin = ymin
+        ymin += ref.dysize + spacing
+
     return c
 
 
 if __name__ == "__main__":
     c = cdsem_all()
-    c.show(show_ports=True)
+    c.show()
