@@ -1,20 +1,15 @@
 """CD SEM structures."""
+
 from __future__ import annotations
 
-from functools import partial
-
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
-from gdsfactory.components.text_rectangular import text_rectangular
-from gdsfactory.types import ComponentSpec, CrossSectionSpec
+from gdsfactory.typings import ComponentFactory, ComponentSpec, CrossSectionSpec
 
 LINE_LENGTH = 420.0
 
-text_rectangular_mini = partial(text_rectangular, size=1)
 
-
-@cell
+@gf.cell
 def cdsem_bend180(
     width: float = 0.5,
     radius: float = 10.0,
@@ -22,7 +17,7 @@ def cdsem_bend180(
     straight: ComponentSpec = "straight",
     bend90: ComponentSpec = "bend_circular",
     cross_section: CrossSectionSpec = "strip",
-    text: ComponentSpec = text_rectangular_mini,
+    text: ComponentFactory = "text_rectangular_mini",
 ) -> Component:
     """Returns CDSEM structures.
 
@@ -59,17 +54,17 @@ def cdsem_bend180(
     wg2 = c.add_ref(wg)
     wg2.connect("o1", b2.ports["o1"])
 
-    label = c << text(text=str(int(width * 1e3)))
-    label.ymax = b2.ymin - 5
-    label.x = 0
-    b1.rotate(90)
-    b2.rotate(90)
-    wg1.rotate(90)
-    wg2.rotate(90)
-    label.rotate(90)
-    return c
+    label = c << gf.get_component(text, text=str(int(width * 1e3)))
+    label.dymax = b2.dymin - 5
+    label.dx = 0
+
+    c2 = gf.Component()
+    ref = c2 << c
+    ref.drotate(90)
+    c2.flatten()
+    return c2
 
 
 if __name__ == "__main__":
     c = cdsem_bend180(width=2)
-    c.show(show_ports=True)
+    c.show()
