@@ -1,20 +1,21 @@
 from __future__ import annotations
 
-from typing import Optional, Tuple
-
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
-from gdsfactory.types import Ints, LayerSpec
+from gdsfactory.snap import snap_to_grid2x
+from gdsfactory.typings import Ints, LayerSpec, Size
+
+valid_port_orientations = {0, 90, 180, -90, 270}
 
 
-@cell
+@gf.cell
 def compass(
-    size: Tuple[float, float] = (4.0, 2.0),
+    size: Size = (4.0, 2.0),
     layer: LayerSpec = "WG",
-    port_type: Optional[str] = "placement",
+    port_type: str | None = "electrical",
     port_inclusion: float = 0.0,
-    port_orientations: Optional[Ints] = (180, 90, 0, -90),
+    port_orientations: Ints | None = (180, 90, 0, -90),
+    auto_rename_ports: bool = True,
 ) -> Component:
     """Rectangle with ports on each edge (north, south, east, and west).
 
@@ -23,10 +24,15 @@ def compass(
         layer: tuple (int, int).
         port_type: optical, electrical.
         port_inclusion: from edge.
-        port_orientations: list of port_orientations to add. None add one port only.
+        port_orientations: list of port_orientations to add. None does not add ports.
+        auto_rename_ports: auto rename ports.
     """
     c = gf.Component()
-    dx, dy = size
+    dx, dy = snap_to_grid2x(size)
+    port_orientations = port_orientations or []
+
+    if dx <= 0 or dy <= 0:
+        raise ValueError(f"dx={dx} and dy={dy} must be > 0")
 
     points = [
         [-dx / 2.0, -dy / 2.0],
@@ -38,6 +44,12 @@ def compass(
     c.add_polygon(points, layer=layer)
 
     if port_type:
+        for port_orientation in port_orientations:
+            if port_orientation not in valid_port_orientations:
+                raise ValueError(
+                    f"{port_orientation=} must be in {valid_port_orientations}"
+                )
+
         if 180 in port_orientations:
             c.add_port(
                 name="e1",
@@ -65,7 +77,7 @@ def compass(
                 layer=layer,
                 port_type=port_type,
             )
-        if -90 in port_orientations:
+        if -90 in port_orientations or 270 in port_orientations:
             c.add_port(
                 name="e4",
                 center=(0, -dy / 2 + port_inclusion),
@@ -74,20 +86,14 @@ def compass(
                 layer=layer,
                 port_type=port_type,
             )
-        if port_orientations is None:
-            c.add_port(
-                name="pad",
-                center=(0, 0),
-                width=dy,
-                orientation=None,
-                layer=layer,
-                port_type=port_type,
-            )
 
-        c.auto_rename_ports()
+        if auto_rename_ports:
+            c.auto_rename_ports()
     return c
 
 
 if __name__ == "__main__":
-    c = compass(size=(1, 2), layer="WG", port_type="optical", port_inclusion=0.5)
-    c.show(show_ports=True)
+    # c = compass(size=(10, 4), port_type="electrical")
+    c = compass(port_orientations=[270])
+    c.pprint_ports()
+    c.show()
