@@ -1,11 +1,10 @@
 from __future__ import annotations
 
 from collections import Counter
-from typing import Dict, Optional, Tuple
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import ComponentSpec
+from gdsfactory.typings import AngleInDegrees
 
 
 class SequenceGenerator:
@@ -38,16 +37,21 @@ class SequenceGenerator:
         O: taper with input '2'
         S: short straight waveguide
         L: long straight waveguide
+
+        Args:
+            start_sequence: starting sequence.
+            end_sequence: ending sequence.
+            repeated_sequence: repeating sequence.
         """
         self.start_sequence = start_sequence
         self.end_sequence = end_sequence
         self.repeated_sequence = repeated_sequence
 
-    def get_sequence(self, n=2):
+    def get_sequence(self, n: int = 2) -> str:
         return self.start_sequence + n * self.repeated_sequence + self.end_sequence
 
 
-def parse_component_name(name: str) -> Tuple[str, bool]:
+def parse_component_name(name: str) -> tuple[str, bool]:
     """If the component name has more than one character and starts with "!".
 
     then we need to flip along the axis given by the input port angle.
@@ -55,23 +59,23 @@ def parse_component_name(name: str) -> Tuple[str, bool]:
     return (name[1:], True) if len(name) != 1 and name[0] == "!" else (name, False)
 
 
-def _flip_ref(c_ref, port_name):
+def _flip_ref(c_ref: Component, port_name: str) -> Component:
     a = c_ref.ports[port_name].orientation
     if a in [0, 180]:
-        c_ref.mirror_y(port_name)
+        y = c_ref.ports[port_name].dcenter[1]
+        c_ref.dmirror_y(y)
     else:
-        c_ref.mirror_x(port_name)
+        c_ref.dmirror_x(port_name)
     return c_ref
 
 
-@gf.cell
 def component_sequence(
     sequence: str,
-    symbol_to_component: Dict[str, Tuple[ComponentSpec, str, str]],
-    ports_map: Optional[Dict[str, Tuple[str, str]]] = None,
+    symbol_to_component: dict[str, tuple[Component, str, str]],
+    ports_map: dict[str, tuple[str, str]] | None = None,
     port_name1: str = "o1",
     port_name2: str = "o2",
-    start_orientation: float = 0.0,
+    start_orientation: AngleInDegrees = 0.0,
 ) -> Component:
     """Returns component from ASCII sequence.
 
@@ -112,9 +116,8 @@ def component_sequence(
         c = gf.components.component_sequence(sequence=s, symbol_to_component=symbol_to_component)
         c.plot()
     """
-    named_references_counter = Counter()
     ports_map = ports_map or {}
-
+    named_references_counter: Counter[str] = Counter()
     component = Component()
 
     # Add first component reference and input port
@@ -122,22 +125,23 @@ def component_sequence(
     index = 2 if "!" in sequence[0] else 1
     name_start_device, do_flip = parse_component_name(symbol)
     component_input, input_port, prev_port = symbol_to_component[name_start_device]
-
-    named_references_counter.update({name_start_device: 1})
-    alias = f"{name_start_device}{named_references_counter[name_start_device]}"
-    prev_device = component.add_ref(component_input, alias=alias)
+    prev_device = component.add_ref(component_input, name=f"{symbol}{index}")
+    named_references_counter.update(
+        {name_start_device: 1}
+    )  # sourcery skip:simplify-dictionary-update
 
     if do_flip:
         prev_device = _flip_ref(prev_device, input_port)
 
-    prev_device.rotate(angle=start_orientation)
+    prev_device.drotate(angle=start_orientation)
 
     try:
         component.add_port(name=port_name1, port=prev_device.ports[input_port])
     except KeyError as exc:
+        port_names = [port.name for port in prev_device.ports]
         raise KeyError(
             f"{prev_device.parent.name!r} input_port {input_port!r} "
-            f"not in {list(prev_device.ports.keys())}"
+            f"not in {port_names}"
         ) from exc
 
     while index < len(sequence):
@@ -157,10 +161,11 @@ def component_sequence(
         index += 1
         component_i, input_port, next_port = symbol_to_component[s]
         component_i = gf.get_component(component_i)
-
-        named_references_counter.update({s: 1})
+        named_references_counter.update(
+            {s: 1}
+        )  # sourcery skip:simplify-dictionary-update
         alias = f"{s}{named_references_counter[s]}"
-        ref = component.add_ref(component_i, alias=alias)
+        ref = component.add_ref(component_i, name=alias)
 
         if do_flip:
             ref = _flip_ref(ref, input_port)
@@ -168,9 +173,10 @@ def component_sequence(
         try:
             ref.connect(input_port, prev_device.ports[prev_port])
         except KeyError as exc:
+            port_names = [port.name for port in prev_device.ports]
             raise KeyError(
                 f"{prev_device.parent.name!r} port {prev_port!r} "
-                f"not in {list(prev_device.ports.keys())}"
+                f"not in {port_names}"
             ) from exc
 
         prev_device = ref
@@ -188,8 +194,10 @@ def component_sequence(
         raise
 
     # Add any extra port specified in ports_map
-    for name, (alias, alias_port_name) in ports_map.items():
-        component.add_port(name=name, port=component[alias].ports[alias_port_name])
+    for name, (ref_name, alias_port_name) in ports_map.items():
+        component.add_port(
+            name=name, port=component.insts[ref_name].ports[alias_port_name]
+        )
 
     return component
 
@@ -218,8 +226,11 @@ if __name__ == "__main__":
     c = gf.components.component_sequence(
         sequence=sequence, symbol_to_component=symbol_to_component_map
     )
+    c.show()
     # n = c.get_netlist()
     # c = gf.read.from_yaml(n)
-    c.show(show_ports=True)
-    # c.pprint()
-    # print(c.named_references.keys())
+
+    # _ = c << gf.c.straight()
+    # c.name = "top"
+    # lyrdb = c.connectivity_check()
+    # gf.show(c, lyrdb=lyrdb)
