@@ -1,14 +1,16 @@
 from __future__ import annotations
 
-from gdsfactory.cell import cell
+from typing import Any
+
+import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.cross import cross
-from gdsfactory.types import ComponentSpec, LayerSpecs
+from gdsfactory.typings import ComponentSpec, LayerSpecs
 
 
-@cell
+@gf.cell
 def copy_layers(
-    factory: ComponentSpec = cross, layers: LayerSpecs = ((1, 0), (2, 0)), **kwargs
+    factory: ComponentSpec = cross, layers: LayerSpecs = ((1, 0), (2, 0)), **kwargs: Any
 ) -> Component:
     """Returns a component with the geometry copied in different layers.
 
@@ -19,15 +21,13 @@ def copy_layers(
     """
     c = Component()
     for layer in layers:
-        ci = factory(layer=layer, **kwargs)
-        c << ci
+        ci = gf.get_component(factory, layer=layer, **kwargs)
+        _ = c << ci
 
     c.copy_child_info(ci)
     return c
 
 
 if __name__ == "__main__":
-    import gdsfactory as gf
-
     c = copy_layers(gf.components.rectangle)
-    c.show(show_ports=True)
+    c.show()
