@@ -3,7 +3,7 @@ from __future__ import annotations
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bezier import bezier
-from gdsfactory.types import CrossSectionSpec
+from gdsfactory.typings import CrossSectionSpec
 
 
 @gf.cell
@@ -16,7 +16,6 @@ def coupler_adiabatic(
     output_wg_sep: float = 3.0,
     dw: float = 0.1,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
 ) -> Component:
     """Returns 50/50 adiabatic coupler.
 
@@ -45,25 +44,23 @@ def coupler_adiabatic(
             In Region 1, top arm tapers to width+dw/2.0, bottom taper to width-dw/2.0.
         cross_section: cross_section spec.
 
-    Keyword Args:
-        cross_section kwargs.
     """
     # Control points for input and output S-bends
-    control_points_input_top = [
+    control_points_input_top = (
         (0, 0),
         (length1 / 2.0, 0),
         (length1 / 2.0, -input_wg_sep / 2.0 + wg_sep / 2.0),
         (length1, -input_wg_sep / 2.0 + wg_sep / 2.0),
-    ]
+    )
 
-    control_points_input_bottom = [
+    control_points_input_bottom = (
         (0, -input_wg_sep),
         (length1 / 2.0, -input_wg_sep),
         (length1 / 2.0, -input_wg_sep / 2.0 - wg_sep / 2.0),
         (length1, -input_wg_sep / 2.0 - wg_sep / 2.0),
-    ]
+    )
 
-    control_points_output_top = [
+    control_points_output_top = (
         (length1 + length2, -input_wg_sep / 2.0 + wg_sep / 2.0),
         (
             length1 + length2 + length3 / 2.0,
@@ -77,11 +74,11 @@ def coupler_adiabatic(
             length1 + length2 + length3,
             -input_wg_sep / 2.0 + output_wg_sep / 2.0,
         ),
-    ]
+    )
 
     c = Component()
 
-    x = gf.get_cross_section(cross_section, **kwargs)
+    x = gf.get_cross_section(cross_section)
     width = float(x.width)
     width_top = width + dw
     width_bot = width - dw
@@ -91,10 +88,10 @@ def coupler_adiabatic(
     coupler = c << gf.components.coupler_straight(length=length2, cross_section=x)
 
     taper_top = c << gf.components.taper(
-        width1=width, width2=width_top, cross_section=cross_section, **kwargs
+        width1=width, width2=width_top, cross_section=cross_section
     )
     taper_bot = c << gf.components.taper(
-        width1=width, width2=width_bot, cross_section=cross_section, **kwargs
+        width1=width, width2=width_bot, cross_section=cross_section
     )
 
     taper_bot.connect("o1", coupler.ports["o1"])
@@ -113,10 +110,9 @@ def coupler_adiabatic(
     sbend_right = bezier(control_points=control_points_output_top, cross_section=x)
     sbend_right_top = c << sbend_right
     sbend_right_bot = c << sbend_right
-    sbend_right_bot.mirror()
 
     sbend_right_top.connect("o1", coupler.ports["o3"])
-    sbend_right_bot.connect("o1", coupler.ports["o4"])
+    sbend_right_bot.connect("o1", coupler.ports["o4"], mirror=True)
 
     c.add_port("o1", port=sbend_left_bot.ports["o1"])
     c.add_port("o2", port=sbend_left_top.ports["o1"])
@@ -126,5 +122,5 @@ def coupler_adiabatic(
 
 
 if __name__ == "__main__":
-    c = coupler_adiabatic(length3=5, bbox_offsets=[0.5], bbox_layers=[(111, 0)])
-    c.show(show_ports=True)
+    c = coupler_adiabatic(length3=5)
+    c.show()
