@@ -1,20 +1,22 @@
 from __future__ import annotations
 
+from typing import Any
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components import bend_s
-from gdsfactory.types import CrossSectionSpec
+from gdsfactory.typings import CrossSectionSpec, Delta
 
 
 @gf.cell
 def coupler_full(
     coupling_length: float = 40.0,
-    dx: float = 10.0,
-    dy: float = 5.0,
+    dx: Delta = 10.0,
+    dy: Delta = 4.8,
     gap: float = 0.5,
     dw: float = 0.1,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Adiabatic Full coupler.
 
@@ -40,6 +42,7 @@ def coupler_full(
         gap: Distance between the two straights in um.
         dw: delta width. Top arm tapers to width - dw, bottom to width + dw in um.
         cross_section: cross-section spec.
+        kwargs: cross_section settings.
 
     Keyword Args:
         cross_section kwargs.
@@ -55,31 +58,25 @@ def coupler_full(
         length=coupling_length,
         width1=x_top.width,
         width2=x_bottom.width,
-        cross_section=x_top,
+        cross_section=cross_section,
     )
 
     taper_bottom = c << gf.components.taper(
         length=coupling_length,
         width1=x_bottom.width,
         width2=x_top.width,
-        cross_section=x_bottom,
+        cross_section=cross_section,
     )
 
-    bend_input_top = (
-        c
-        << bend_s(
-            size=(dx, (dy - gap - x_top.width) / 2.0), cross_section=x_top
-        ).mirror()
+    bend_input_top = c << bend_s(
+        size=(dx, (dy - gap - x_top.width) / 2.0), cross_section=x_top
     )
-    bend_input_top.movey(origin=0, destination=(x_top.width + gap) / 2.0)
+    bend_input_top.dmovey((x_top.width + gap) / 2.0)
 
-    bend_input_bottom = (
-        c
-        << bend_s(
-            size=(dx, (-dy + gap + x_bottom.width) / 2.0), cross_section=x_bottom
-        ).mirror()
+    bend_input_bottom = c << bend_s(
+        size=(dx, (-dy + gap + x_bottom.width) / 2.0), cross_section=x_bottom
     )
-    bend_input_bottom.movey(origin=0, destination=-(x_bottom.width + gap) / 2.0)
+    bend_input_bottom.dmovey(-(x_bottom.width + gap) / 2.0)
 
     taper_top.connect("o1", bend_input_top.ports["o1"])
     taper_bottom.connect("o1", bend_input_bottom.ports["o1"])
@@ -87,39 +84,27 @@ def coupler_full(
     bend_output_top = c << bend_s(
         size=(dx, (dy - gap - x_top.width) / 2.0), cross_section=x_bottom
     )
-    bend_output_top.move(destination=taper_top.ports["o2"])
 
     bend_output_bottom = c << bend_s(
         size=(dx, (-dy + gap + x_bottom.width) / 2.0), cross_section=x_top
     )
-    bend_output_bottom.move(destination=taper_bottom.ports["o2"])
 
-    bend_output_top.connect("o2", taper_top.ports["o2"])
-    bend_output_bottom.connect("o2", taper_bottom.ports["o2"])
+    bend_output_top.connect("o2", taper_top.ports["o2"], mirror=True)
+    bend_output_bottom.connect("o2", taper_bottom.ports["o2"], mirror=True)
 
-    c.absorb(bend_input_bottom)
-    c.absorb(bend_input_top)
-    c.absorb(bend_output_top)
-    c.absorb(bend_output_bottom)
-    c.absorb(taper_top)
-    c.absorb(taper_bottom)
-
-    if x.add_bbox:
-        c = x.add_bbox(c)
-
-    if x.info:
-        c.info = x.info
+    x.add_bbox(c)
 
     c.add_port("o1", port=bend_input_bottom.ports["o2"])
     c.add_port("o2", port=bend_input_top.ports["o2"])
     c.add_port("o3", port=bend_output_top.ports["o1"])
     c.add_port("o4", port=bend_output_bottom.ports["o1"])
+    c.auto_rename_ports()
 
+    c.flatten()
     return c
 
 
 if __name__ == "__main__":
-
     c = coupler_full(
         # coupling_length=40,
         # gap=0.2,
@@ -128,4 +113,4 @@ if __name__ == "__main__":
         # cladding_offsets=[3],
     )
     c.show()
-    # c.show(show_ports=True)
+    # c.show( )
