@@ -3,17 +3,16 @@ from __future__ import annotations
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bend_s import bend_s
-from gdsfactory.types import ComponentSpec, CrossSectionSpec
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec, Delta
 
 
 @gf.cell
 def coupler_symmetric(
     bend: ComponentSpec = bend_s,
     gap: float = 0.234,
-    dy: float = 5.0,
-    dx: float = 10.0,
+    dy: Delta = 4.0,
+    dx: Delta = 10.0,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
 ) -> Component:
     r"""Two coupled straights with bends.
 
@@ -23,56 +22,58 @@ def coupler_symmetric(
         dy: port to port vertical spacing.
         dx: bend length in x direction.
         cross_section: section.
-        **kwargs: cross_section settings.
 
     .. code::
 
                        dx
                     |-----|
-                       ___ E1
+                       ___ o3
                       /       |
-                _____/        |
-           gap  _____         |  dy
+             o2 _____/        |
+                              |
+             o1 _____         |  dy
                      \        |
                       \___    |
-                           E0
+                           o4
 
     """
-    x = gf.get_cross_section(cross_section, **kwargs)
+    c = Component()
+    x = gf.get_cross_section(cross_section)
     width = x.width
+    dy = (dy - gap - width) / 2
+
     bend_component = gf.get_component(
         bend,
-        size=(dx, (dy - gap - width) / 2),
+        size=(dx, dy),
         cross_section=cross_section,
-        **kwargs,
     )
+    top_bend = c << bend_component
+    bot_bend = c << bend_component
+    bend_ports = top_bend.ports.filter(port_type="optical")
+    bend_port1_name = bend_ports[0].name
+    bend_port2_name = bend_ports[1].name
 
-    w = bend_component.ports["o1"].width
-    y = (w + gap) / 2
+    w = bend_component[bend_port1_name].dwidth
+    y = w + gap
+    y /= 2
 
-    c = Component()
-    top_bend = bend_component.ref(position=(0, y), port_id="o1")
-    bottom_bend = bend_component.ref(position=(0, -y), port_id="o1", v_mirror=True)
+    bot_bend.dmirror_y()
+    top_bend.dmovey(+y)
+    bot_bend.dmovey(-y)
 
-    c.add(top_bend)
-    c.add(bottom_bend)
+    c.add_port("o1", port=bot_bend[bend_port1_name])
+    c.add_port("o2", port=top_bend[bend_port1_name])
+    c.add_port("o3", port=top_bend[bend_port2_name])
+    c.add_port("o4", port=bot_bend[bend_port2_name])
 
-    c.absorb(top_bend)
-    c.absorb(bottom_bend)
-
-    c.add_port("o1", port=bottom_bend.ports["o1"])
-    c.add_port("o2", port=top_bend.ports["o1"])
-
-    c.add_port("o3", port=top_bend.ports["o2"])
-    c.add_port("o4", port=bottom_bend.ports["o2"])
     c.info["length"] = bend_component.info["length"]
     c.info["min_bend_radius"] = bend_component.info["min_bend_radius"]
     return c
 
 
 if __name__ == "__main__":
-    c = coupler_symmetric(gap=0.2, width=0.9)
-    c.show(show_ports=False)
+    c = coupler_symmetric(gap=0.2)
+    c.show()
     # c.pprint()
 
     # for dyi in [2, 3, 4, 5]:
