@@ -1,10 +1,8 @@
 from __future__ import annotations
 
-from typing import Optional
-
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
@@ -12,7 +10,7 @@ def cross(
     length: float = 10.0,
     width: float = 3.0,
     layer: LayerSpec = "WG",
-    port_type: Optional[str] = None,
+    port_type: str | None = None,
 ) -> Component:
     """Returns a cross from two rectangles of length and width.
 
@@ -25,14 +23,16 @@ def cross(
     layer = gf.get_layer(layer)
     c = gf.Component()
     R = gf.components.rectangle(size=(width, length), layer=layer)
-    r1 = c.add_ref(R).rotate(90)
+    r1 = c.add_ref(R).drotate(90)
     r2 = c.add_ref(R)
-    r1.center = (0, 0)
-    r2.center = (0, 0)
+    r1.dcenter = (0, 0)
+    r2.dcenter = (0, 0)
+    c.flatten()
 
     if port_type:
+        prefix = "o" if port_type == "optical" else "e"
         c.add_port(
-            1,
+            f"{prefix}1",
             width=width,
             layer=layer,
             orientation=0,
@@ -40,7 +40,7 @@ def cross(
             port_type=port_type,
         )
         c.add_port(
-            2,
+            f"{prefix}2",
             width=width,
             layer=layer,
             orientation=180,
@@ -48,7 +48,7 @@ def cross(
             port_type=port_type,
         )
         c.add_port(
-            3,
+            f"{prefix}3",
             width=width,
             layer=layer,
             orientation=90,
@@ -56,7 +56,7 @@ def cross(
             port_type=port_type,
         )
         c.add_port(
-            4,
+            f"{prefix}4",
             width=width,
             layer=layer,
             orientation=270,
@@ -68,8 +68,8 @@ def cross(
 
 
 if __name__ == "__main__":
-    c = cross()
-    c.show(show_ports=True)
+    c = cross(port_type="optical")
+    c.show()
     # c.pprint_ports()
     # cc = gf.routing.add_fiber_array(component=c)
-    # cc.show(show_ports=True)
+    # cc.show( )
