@@ -1,43 +1,43 @@
 from __future__ import annotations
 
-from numpy import float64
+from functools import partial
+from typing import Any
 
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.bend_circular import bend_circular, bend_circular180
 from gdsfactory.components.bend_euler import bend_euler, bend_euler180
 from gdsfactory.components.component_sequence import component_sequence
 from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.types import ComponentSpec
+from gdsfactory.typings import ComponentFactory, ComponentSpec
 
 
-def _get_bend_size(bend90: Component) -> float64:
-    p1, p2 = list(bend90.ports.values())[:2]
-    bsx = abs(p2.x - p1.x)
-    bsy = abs(p2.y - p1.y)
+def _get_bend_size(bend90: Component) -> float:
+    p1, p2 = list(bend90.ports)[:2]
+    bsx = abs(p2.dx - p1.dx)
+    bsy = abs(p2.dy - p1.dy)
     return max(bsx, bsy)
 
 
-@cell
+@gf.cell
 def cutback_bend(
-    bend90: ComponentSpec = bend_euler,
+    component: ComponentSpec = bend_euler,
+    straight: ComponentFactory = straight_function,
     straight_length: float = 5.0,
     rows: int = 6,
-    columns: int = 5,
-    straight: ComponentSpec = straight_function,
-    **kwargs,
+    cols: int = 5,
+    **kwargs: Any,
 ) -> Component:
     """Deprecated.
 
     Use cutback_bend90 instead with smaller footprint.
 
     Args:
-        bend90: bend spec.
+        component: bend spec.
+        straight: straight spec.
         straight_length: in um.
         rows: number of rows.
-        columns: number of columns.
-        straight: straight spec.
+        cols: number of cols.
         kwargs: cross_section settings.
 
     .. code::
@@ -51,8 +51,8 @@ def cutback_bend(
     """
     from gdsfactory.pdk import get_component
 
-    bend90 = get_component(bend90, **kwargs)
-    straightx = get_component(straight, length=straight_length, **kwargs)
+    bend90 = get_component(component, **kwargs)
+    straightx = straight(length=straight_length, **kwargs)
 
     # Define a map between symbols and (component, input port, output port)
     symbol_to_component = {
@@ -63,7 +63,7 @@ def cutback_bend(
 
     # Generate the sequence of staircases
     s = ""
-    for i in range(columns):
+    for i in range(cols):
         s += "ASBS" * rows
         s += "ASAS" if i % 2 == 0 else "BSBS"
     s = s[:-4]
@@ -71,28 +71,29 @@ def cutback_bend(
     c = component_sequence(
         sequence=s, symbol_to_component=symbol_to_component, start_orientation=90
     )
-    c.info["n_bends"] = rows * columns * 2 + columns * 2 - 2
+    c.info["components"] = rows * cols * 2 + cols * 2 - 2
     return c
 
 
-@cell
+@gf.cell
 def cutback_bend90(
-    bend90: ComponentSpec = bend_euler,
+    component: ComponentSpec = bend_euler,
+    straight: ComponentFactory = straight_function,
     straight_length: float = 5.0,
     rows: int = 6,
-    columns: int = 6,
+    cols: int = 6,
     spacing: int = 5,
-    straight: ComponentSpec = straight_function,
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Returns bend90 cutback.
 
     Args:
-        bend90: bend spec.
+        component: bend spec.
+        straight: straight spec.
         straight_length: in um.
         rows: number of rows.
-        columns: number of columns.
-        straight: straight spec.
+        cols: number of cols.
+        spacing: in um.
         kwargs: cross_section settings.
 
     .. code::
@@ -102,10 +103,10 @@ def cutback_bend90(
     """
     from gdsfactory.pdk import get_component
 
-    bend90 = get_component(bend90, **kwargs)
-    straightx = get_component(straight, length=straight_length, **kwargs)
+    bend90 = get_component(component, **kwargs)
+    straightx = straight(length=straight_length, **kwargs)
     straight_length = 2 * _get_bend_size(bend90) + spacing + straight_length
-    straighty = get_component(straight, length=straight_length, **kwargs)
+    straighty = straight(length=straight_length, **kwargs)
 
     # Define a map between symbols and (component, input port, output port)
     symbol_to_component = {
@@ -118,7 +119,7 @@ def cutback_bend90(
     # Generate the sequence of staircases
     s = "".join(
         "A-A-B-B-" * rows + "|" if i % 2 == 0 else "B-B-A-A-" * rows + "|"
-        for i in range(columns)
+        for i in range(cols)
     )
     s = s[:-1]
 
@@ -126,31 +127,31 @@ def cutback_bend90(
     c = component_sequence(
         sequence=s, symbol_to_component=symbol_to_component, start_orientation=0
     )
-    c.info["n_bends"] = rows * columns * 4
+    c.info["components"] = rows * cols * 4
     return c
 
 
-@cell
+@gf.cell
 def staircase(
-    bend90: ComponentSpec = bend_euler,
+    component: ComponentSpec = bend_euler,
+    straight: ComponentFactory = straight_function,
     length_v: float = 5.0,
     length_h: float = 5.0,
     rows: int = 4,
-    straight: ComponentSpec = straight_function,
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Returns staircase.
 
     Args:
-        bend90: bend spec.
+        component: bend spec.
+        straight: straight spec.
         length_v: vertical length.
         length_h: vertical length.
         rows: number of rows.
-        columns: number of columns.
-        straight: straight spec.
+        cols: number of cols.
         kwargs: cross_section settings.
     """
-    bend90 = bend90(**kwargs) if callable(bend90) else bend90
+    bend90 = component(**kwargs) if callable(component) else component
 
     wgh = straight(length=length_h, **kwargs)
     wgv = straight(length=length_v, **kwargs)
@@ -167,31 +168,33 @@ def staircase(
     s = "-A|B" * rows + "-"
 
     c = component_sequence(
-        sequence=s, symbol_to_component=symbol_to_component, start_orientation=0
+        sequence=s,
+        symbol_to_component=symbol_to_component,
+        start_orientation=0,  # type: ignore
     )
-    c.info["n_bends"] = 2 * rows
+    c.info["components"] = 2 * rows
     return c
 
 
-@cell
+@gf.cell
 def cutback_bend180(
-    bend180: ComponentSpec = bend_euler180,
+    component: ComponentSpec = bend_euler180,
+    straight: ComponentFactory = straight_function,
     straight_length: float = 5.0,
     rows: int = 6,
-    columns: int = 6,
-    spacing: int = 3,
-    straight: ComponentSpec = straight_function,
-    **kwargs,
+    cols: int = 6,
+    spacing: float = 3.0,
+    **kwargs: Any,
 ) -> Component:
     """Returns cutback to measure u bend loss.
 
     Args:
-        bend180: bend spec.
+        component: bend spec.
+        straight: straight spec.
         straight_length: in um.
         rows: number of rows.
-        columns: number of columns.
+        cols: number of cols.
         spacing: in um.
-        straight: straight spec.
         kwargs: cross_section settings.
 
     .. code::
@@ -203,11 +206,10 @@ def cutback_bend180(
     """
     from gdsfactory.pdk import get_component
 
-    bend180 = get_component(bend180, **kwargs)
-    straightx = get_component(straight, length=straight_length, **kwargs)
-    wg_vertical = get_component(
-        straight,
-        length=2 * bend180.size_info.width + straight_length + spacing,
+    bend180 = get_component(component, **kwargs)
+    straightx = straight(length=straight_length, **kwargs)
+    wg_vertical = straight(
+        length=2 * bend180.dxsize + straight_length + spacing,
         **kwargs,
     )
 
@@ -221,8 +223,7 @@ def cutback_bend180(
 
     # Generate the sequence of staircases
     s = "".join(
-        "D-C-" * rows + "|" if i % 2 == 0 else "C-D-" * rows + "|"
-        for i in range(columns)
+        "D-C-" * rows + "|" if i % 2 == 0 else "C-D-" * rows + "|" for i in range(cols)
     )
 
     s = s[:-1]
@@ -230,22 +231,22 @@ def cutback_bend180(
     c = component_sequence(
         sequence=s, symbol_to_component=symbol_to_component, start_orientation=0
     )
-    c.info["n_bends"] = rows * columns * 2 + columns * 2 - 2
+    c.info["components"] = rows * cols * 2 + cols * 2 - 2
     return c
 
 
-cutback_bend180circular = gf.partial(cutback_bend180, bend180=bend_circular180)
-cutback_bend90circular = gf.partial(cutback_bend90, bend90=bend_circular)
+cutback_bend180circular = partial(cutback_bend180, component=bend_circular180)
+cutback_bend90circular = partial(cutback_bend90, component=bend_circular)
 
 if __name__ == "__main__":
     # c = cutback_bend()
     # c = cutback_bend90()
-    # c = cutback_bend_circular(rows=7, columns=4, radius=5) #62
-    # c = cutback_bend_circular(rows=14, columns=4) #118
+    c = cutback_bend90circular(rows=7, cols=4, radius=5)
+    # c = cutback_bend_circular(rows=14, cols=4)
     # c = cutback_bend90()
-    # c = cutback_bend180(rows=3, columns=1)
-    # c = cutback_bend(rows=3, columns=2)
-    # c = cutback_bend90(rows=3, columns=2)
-    c = cutback_bend180(rows=2, columns=2)
-    # c = cutback_bend(rows=3, columns=2)
-    c.show(show_ports=True)
+    # c = cutback_bend180(rows=3, cols=1)
+    # c = cutback_bend(rows=3, cols=2)
+    # c = cutback_bend90(rows=3, cols=2)
+    # c = cutback_bend180(rows=2, cols=2)
+    # c = cutback_bend(rows=3, cols=2)
+    c.show()
