@@ -1,13 +1,15 @@
 from __future__ import annotations
 
+from functools import partial
+from typing import Any
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bend_euler import bend_euler180
 from gdsfactory.components.component_sequence import component_sequence
 from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.components.taper import taper
 from gdsfactory.components.taper_from_csv import taper_0p5_to_3_l36
-from gdsfactory.types import ComponentSpec, CrossSectionSpec, Optional
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec
 
 
 @gf.cell
@@ -18,14 +20,19 @@ def cutback_component(
     port1: str = "o1",
     port2: str = "o2",
     bend180: ComponentSpec = bend_euler180,
-    straight: ComponentSpec = straight_function,
     mirror: bool = False,
-    straight_length: Optional[float] = None,
+    mirror1: bool = False,
+    mirror2: bool = False,
+    straight_length: float | None = None,
+    straight_length_pair: float | None = None,
+    straight: ComponentSpec = straight_function,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Returns a daisy chain of components for measuring their loss.
 
+    Works only for components with 2 ports (input, output).
+
     Args:
         component: for cutback.
         cols: number of columns.
@@ -33,19 +40,24 @@ def cutback_component(
         port1: name of first optical port.
         port2: name of second optical port.
         bend180: ubend.
-        straight: waveguide spec to connect both sides.
         mirror: Flips component. Useful when 'o2' is the port that you want to route to.
+        mirror1: mirrors first component.
+        mirror2: mirrors second component.
         straight_length: length of the straight section between cutbacks.
+        straight_length_pair: length of the straight section between each component pair.
         cross_section: specification (CrossSection, string or dict).
-        kwargs: cross_section settings.
+        straight: straight spec.
+        kwargs: component settings.
     """
-    xs = gf.get_cross_section(cross_section, **kwargs)
+    xs = gf.get_cross_section(cross_section)
 
-    component = gf.get_component(component)
+    component = gf.get_component(component, **kwargs)
     bendu = gf.get_component(bend180, cross_section=xs)
-    straight_component = gf.get_component(
-        straight, length=straight_length or xs.radius * 2, cross_section=xs
-    )
+
+    straight_length = xs.radius * 2 if straight_length is None else straight_length
+    straight_component = straight(length=straight_length, cross_section=xs)
+
+    straight_pair = straight(length=straight_length_pair or 0, cross_section=xs)
 
     # Define a map between symbols and (component, input port, output port)
     symbol_to_component = {
@@ -55,13 +67,17 @@ def cutback_component(
         "C": (bendu, "o2", "o1"),
         "-": (straight_component, "o1", "o2"),
         "_": (straight_component, "o2", "o1"),
+        ".": (straight_pair, "o2", "o1"),
     }
 
     # Generate the sequence of staircases
 
     s = ""
     for i in range(rows):
-        s += "AB" * cols
+        a = "!A" if mirror1 else "A"
+        b = "!B" if mirror2 else "B"
+
+        s += f"{a}.{b}" * cols if straight_length_pair else (a + b) * cols
         if mirror:
             s += "C" if i % 2 == 0 else "D"
         else:
@@ -71,32 +87,21 @@ def cutback_component(
     s += "-_"
 
     for i in range(rows):
-        s += "AB" * cols
+        s += f"{a}.{b}" * cols if straight_length_pair else (a + b) * cols
         s += "D" if (i + rows) % 2 == 0 else "C"
 
     s = s[:-1]
 
-    seq = component_sequence(sequence=s, symbol_to_component=symbol_to_component)
-
-    c = gf.Component()
-    ref = c << seq
-    c.add_ports(ref.ports)
-
-    n = len(s) - 2
-    c.copy_child_info(component)
+    c = component_sequence(sequence=s, symbol_to_component=symbol_to_component)
+    n = 2 * s.count("A")
     c.info["components"] = n
     return c
 
 
-# straight_wide = gf.partial(straight, width=3, length=20)
-# bend180_wide = gf.partial(bend_euler180, width=3)
-component_flipped = gf.partial(taper, width2=0.5, width1=3)
-straight_long = gf.partial(straight_function, length=20)
-cutback_component_mirror = gf.partial(cutback_component, mirror=True)
-
+cutback_component_mirror = partial(cutback_component, mirror=True)
 
 if __name__ == "__main__":
     c = cutback_component()
     # c = cutback_component_mirror(component=component_flipped)
     # c = gf.routing.add_fiber_single(c)
-    c.show(show_ports=True)
+    c.show()
