@@ -1,9 +1,28 @@
 from __future__ import annotations
 
+from typing import Any
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight
-from gdsfactory.types import ComponentSpec, CrossSectionSpec
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec
+
+diagram = r"""
+
+                         length1
+         <----------------------------
+               length2    spacing    |
+                _______              |
+               |        \            |
+               |          \          | bend1 radius
+               |            \sbend   |
+          bend2|              \      |
+               |                \    |
+               |                  \__|
+               |
+               ---------------------->----------->
+                   length3              length4
+"""
 
 
 @gf.cell
@@ -17,7 +36,7 @@ def delay_snake_sbend(
     sbend: ComponentSpec = "bend_s",
     sbend_xsize: float = 100.0,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     r"""Returns compact Snake with sbend in the middle.
 
@@ -26,12 +45,12 @@ def delay_snake_sbend(
     Args:
         length: total length.
         length1: first straight section length in um.
-        length3: third straight section length in um.
+        length4: fourth straight section length in um.
         radius: u bend radius in um.
         waveguide_spacing: waveguide pitch in um.
         bend: bend spec.
         sbend: sbend spec.
-        sbend_size: sbend size.
+        sbend_xsize: sbend size.
         cross_section: cross_section spec.
         kwargs: cross_section settings.
 
@@ -66,10 +85,10 @@ def delay_snake_sbend(
     b1 = c << bend
     b2 = c << bend
     bs = c << sbend
-    bs.mirror()
+    bs.dmirror()
 
     length23 = (
-        length - (2 * bend.info["length"] - bs.info["length"]) - length1 - length4
+        length - (2 * bend.info["length"] - sbend.info["length"]) - length1 - length4
     )
     length2 = length23 / 2
     length3 = length23 / 2
@@ -77,7 +96,7 @@ def delay_snake_sbend(
     if length2 < 0:
         raise ValueError(
             f"length2 = {length2} < 0. You need to reduce length1 = {length1} "
-            f"or length3 = {length3} or increase length = {length}"
+            f"or length3 = {length3} or increase length = {length}\n" + diagram
         )
 
     straight1 = straight(length=length1, cross_section=cross_section, **kwargs)
@@ -85,10 +104,16 @@ def delay_snake_sbend(
     straight3 = straight(length=length3, cross_section=cross_section, **kwargs)
     straight4 = straight(length=length4, cross_section=cross_section, **kwargs)
 
-    s1 = c << straight1
-    s2 = c << straight2
-    s3 = c << straight3
-    s4 = c << straight4
+    # sequence = ["s1", "b1", "bs", "s2", "b2", "s3", "s4"]
+    # for i_straight, component in enumerate(straight1, straight2, straight3, straight4):
+    #     inst_name = f"s{i_straight+1}"
+    #     if component.settings["length"] != 0:
+    #         sequence.remove()
+    s1 = c.add_ref(straight1, "s1")
+    s2 = c.add_ref(straight2, "s2")
+    s3 = c.add_ref(straight3, "s3")
+    s4 = c.add_ref(straight4, "s4")
+    # for inst_name in sequence:
 
     b1.connect("o2", s1.ports["o2"])
     bs.connect("o2", b1.ports["o1"])
@@ -102,27 +127,24 @@ def delay_snake_sbend(
     c.add_port("o1", port=s1.ports["o1"])
     c.add_port("o2", port=s4.ports["o2"])
 
-    c.info["min_bend_radius"] = sbend.info["min_bend_radius"]
+    c.info["min_bend_radius"] = float(sbend.info["min_bend_radius"])
     c.info["bend180_radius"] = bend180_radius
-    return c
 
+    # delete any straights with zero length
+    for inst in s1, s2, s3, s4:
+        if inst.cell.settings["length"] == 0:
+            del c.insts[inst._kfinst]
 
-def test_delay_snake_sbend_length():
-    import numpy as np
-
-    length = 200.0
-    c = delay_snake_sbend(length=length, cross_section="strip_no_pins")
-    length_computed = c.area() / 0.5
-    np.isclose(length, length_computed)
     return c
 
 
 if __name__ == "__main__":
-    c = test_delay_snake_sbend_length()
+    # test_delay_snake_sbend_length()
     # c = gf.grid(
     #     [
     #         delay_snake_sbend(length=length, cross_section="rib")
     #         for length in [500, 3000]
     #     ]
     # )
-    c.show(show_ports=True)
+    c = delay_snake_sbend(length=200, cross_section="strip")
+    c.show()
