@@ -1,27 +1,28 @@
 """based on phidl.geometry."""
+
 from __future__ import annotations
 
-from typing import Optional
+from functools import partial
 
 import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.components.rectangle import rectangle
 from gdsfactory.components.text import text
-from gdsfactory.types import Anchor, ComponentSpec, LayerSpec
+from gdsfactory.typings import Anchor, ComponentSpec, LayerSpec
 
-big_square = gf.partial(rectangle, size=(1300, 2600))
+big_square = partial(rectangle, size=(1300, 2600), centered=False)
 
 
 @gf.cell
 def die_bbox(
     component: ComponentSpec = big_square,
     street_width: float = 100.0,
-    street_length: Optional[float] = None,
-    die_name: Optional[str] = None,
+    street_length: float | None = None,
+    die_name: str | None = None,
     text_size: float = 100.0,
     text_anchor: Anchor = "sw",
-    layer: LayerSpec = "M3",
+    layer: LayerSpec = "MTOP",
     padding: float = 10.0,
 ) -> gf.Component:
     """Returns component with boundary box frame around it.
@@ -40,15 +41,14 @@ def die_bbox(
         layer: Specific layer(s) to put polygon geometry on.
         padding: adds padding.
     """
-    D = gf.Component()
+    c = gf.Component()
     component = gf.get_component(component)
 
-    D.copy_child_info(component)
-    cref = D.add_ref(component)
-    cref.x = 0
-    cref.y = 0
-    size = cref.size
-    sx, sy = size[0] / 2, size[1] / 2
+    c.copy_child_info(component)
+    cref = c.add_ref(component)
+    cref.dmovex(-(cref.dbbox().right + cref.dbbox().left) // 2)
+    cref.dmovey(-(cref.dbbox().bottom + cref.dbbox().top) // 2)
+    sx, sy = component.dxsize, component.dysize
 
     sx += street_width + padding
     sy += street_width + padding
@@ -75,33 +75,33 @@ def die_bbox(
             sy,
         ]
     )
-    D.add_polygon([+xpts, +ypts], layer=layer)
-    D.add_polygon([-xpts, +ypts], layer=layer)
-    D.add_polygon([+xpts, -ypts], layer=layer)
-    D.add_polygon([-xpts, -ypts], layer=layer)
+    c.add_polygon(list(zip(+xpts, +ypts)), layer=layer)
+    c.add_polygon(list(zip(-xpts, +ypts)), layer=layer)
+    c.add_polygon(list(zip(+xpts, -ypts)), layer=layer)
+    c.add_polygon(list(zip(-xpts, -ypts)), layer=layer)
 
     if die_name:
-        t = D.add_ref(text(text=die_name, size=text_size, layer=layer))
+        t = c.add_ref(text(text=die_name, size=text_size, layer=layer))
 
         d = street_width + 20
         if text_anchor == "nw":
-            t.xmin, t.ymax = [-sx + d, sy - d]
+            t.dxmin, t.dymax = [-sx + d, sy - d]
         elif text_anchor == "nc":
-            t.x, t.ymax = [0, sy - d]
+            t.dx, t.dymax = [0, sy - d]
         elif text_anchor == "ne":
-            t.xmax, t.ymax = [sx - d, sy - d]
+            t.dxmax, t.dymax = [sx - d, sy - d]
         if text_anchor == "sw":
-            t.xmin, t.ymin = [-sx + d, -sy + d]
+            t.dxmin, t.dymin = [-sx + d, -sy + d]
         elif text_anchor == "sc":
-            t.x, t.ymin = [0, -sy + d]
+            t.dx, t.dymin = [0, -sy + d]
         elif text_anchor == "se":
-            t.xmax, t.ymin = [sx - d, -sy + d]
+            t.dxmax, t.dymin = [sx - d, -sy + d]
 
-    return D
+    return c
 
 
 if __name__ == "__main__":
     mask = gf.components.array(rows=10, columns=10)
     # c = die_bbox(component=mask, die_name="chip99")
-    c = die_bbox()
-    # c.show(show_ports=True)
+    c = die_bbox(component=mask, die_name="chip99", text_anchor="se")
+    c.show()
