@@ -4,23 +4,34 @@ import numpy as np
 
 import gdsfactory as gf
 from gdsfactory import Component
-from gdsfactory.types import CrossSectionSpec
+from gdsfactory.cross_section import CrossSection
+from gdsfactory.typings import (
+    AngleInDegrees,
+    ComponentSpec,
+    CrossSectionSpec,
+    LayerSpec,
+)
 
 
-def _compute_parameters(xs_bend, wrap_angle_deg, radius):
-
+def _compute_parameters(
+    xs_bend: CrossSection, wrap_angle_deg: float, radius: float
+) -> tuple[float, float, float, float]:
     r_bend = xs_bend.radius
     theta = wrap_angle_deg / 2.0
-    size_x, dy = r_bend * np.sin(theta * np.pi / 180), r_bend - r_bend * np.cos(
-        theta * np.pi / 180
+    size_x, dy = (
+        r_bend * np.sin(theta * np.pi / 180),
+        r_bend - r_bend * np.cos(theta * np.pi / 180),
     )
-    bus_length = 2 * radius if (4 * size_x < 2 * radius) else 4 * size_x
-
+    bus_length = max(4 * size_x, 2 * radius)
     return (r_bend, size_x, dy, bus_length)
 
 
-def _generate_bends(c, r_bend, wrap_angle_deg, cross_section):
-
+def _generate_bends(
+    c: Component,
+    r_bend: float,
+    wrap_angle_deg: float,
+    cross_section: CrossSectionSpec,
+) -> tuple[Component, Component, Component, Component]:
     if wrap_angle_deg != 0:
         input_arc = gf.path.arc(radius=r_bend, angle=-wrap_angle_deg / 2.0)
         bend_middle_arc = gf.path.arc(radius=r_bend, angle=-wrap_angle_deg)
@@ -29,21 +40,26 @@ def _generate_bends(c, r_bend, wrap_angle_deg, cross_section):
 
         bend_input = c << bend_input_output
         bend_middle = c << bend_middle_arc.extrude(cross_section=cross_section)
-        bend_middle.rotate(180 + wrap_angle_deg / 2.0, center=c.center)
+        bend_middle.drotate(180 + wrap_angle_deg / 2.0)
 
         bend_input.connect("o2", bend_middle.ports["o2"])
 
         bend_output = c << bend_input_output
-        bend_output.mirror()
-        bend_output.connect("o2", bend_middle.ports["o1"])
+        bend_output.connect("o2", bend_middle.ports["o1"], mirror=True)
 
         return (c, bend_input, bend_middle, bend_output)
     else:
         return (c, None, None, None)
 
 
-def _generate_straights(c, bus_length, size_x, bend_input, bend_output, cross_section):
-
+def _generate_straights(
+    c: Component,
+    bus_length: float,
+    size_x: float,
+    bend_input: Component | None,
+    bend_output: Component | None,
+    cross_section: CrossSectionSpec,
+) -> tuple[Component, Component]:
     straight_left = c << gf.components.straight(
         length=(bus_length - 4 * size_x) / 2.0, cross_section=cross_section
     )
@@ -62,40 +78,6 @@ def _generate_straights(c, bus_length, size_x, bend_input, bend_output, cross_se
     return (c, straight_left, straight_right)
 
 
-def _generate_circles(c, radius, xs, bend_middle, straight_left, r_bend, dy):
-
-    circle = c << gf.components.circle(radius=radius, layer=xs.layer)
-
-    circle_cladding = c << gf.components.circle(
-        radius=radius + xs.cladding_offsets[0], layer=xs.cladding_layers[0]
-    )
-
-    if bend_middle is not None:
-        circle.move(
-            origin=circle.center,
-            destination=(
-                (bend_middle.ports["o1"].x + bend_middle.ports["o2"].x) / 2.0,
-                straight_left.ports["o2"].y - 2 * dy + r_bend,
-            ),
-        )
-    else:
-        circle.move(
-            origin=circle.center,
-            destination=(straight_left.ports["o2"].center + (0, r_bend),),
-        )
-
-    circle_cladding.move(origin=circle_cladding.center, destination=circle.center)
-
-    return (c, circle, circle_cladding)
-
-
-def _absorb(c, *refs):
-    for ref in list(refs):
-        if ref is not None:
-            c.absorb(ref)
-    return c
-
-
 @gf.cell
 def disk(
     radius: float = 10.0,
@@ -103,7 +85,6 @@ def disk(
     wrap_angle_deg: float = 180.0,
     parity: int = 1,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
 ) -> Component:
     """Disk Resonator.
 
@@ -116,7 +97,6 @@ def disk(
         180 corresponds to a bus straight wrapped around half of the resonator.
        parity (1 or -1): 1, resonator left from bus straight, -1 resonator to the right.
        cross_section: cross_section spec.
-       kwargs: cross_section settings.
 
     """
     if parity not in (1, -1):
@@ -127,9 +107,10 @@ def disk(
 
     c = gf.Component()
 
-    xs = gf.get_cross_section(cross_section=cross_section, radius=radius, **kwargs)
-    xs_bend = xs.copy()
-    xs_bend.radius = radius + xs.width / 2.0 + gap
+    xs = gf.get_cross_section(cross_section=cross_section)
+    radius_disk = radius
+    radius = radius + xs.width / 2.0 + gap
+    xs_bend = xs.copy(radius=radius)
 
     r_bend, size_x, dy, bus_length = _compute_parameters(
         xs_bend, wrap_angle_deg, radius
@@ -143,39 +124,97 @@ def disk(
         c, bus_length, size_x, bend_input, bend_output, xs_bend
     )
 
-    c, circle, circle_cladding = _generate_circles(
-        c, radius, xs, bend_middle, straight_left, r_bend, dy
-    )
+    circle = c << gf.components.circle(radius=radius_disk, layer=xs.layer)
 
-    c = _absorb(
-        c,
-        circle,
-        circle_cladding,
-        straight_left,
-        straight_right,
-        bend_input,
-        bend_middle,
-        bend_output,
-    )
+    circle_cladding = None
+    if bend_middle is not None:
+        dx = (bend_middle.ports["o1"].dx + bend_middle.ports["o2"].dx) / 2.0
+        dy = straight_left.ports["o2"].dy - 2 * dy + r_bend
+        circle.dmove((dx, dy))
+    else:
+        circle.dmove(np.array(straight_left.ports["o2"].dcenter) + (0, r_bend))
 
-    c.add_port("o1", port=straight_left.ports["o1"], layer="PORT")
+    if circle_cladding:
+        circle_cladding.dmove(circle.dcenter)
+
+    c.add_port("o1", port=straight_left.ports["o1"])
     c.add_port("o2", port=straight_right.ports["o2"])
-
-    if xs.add_bbox:
-        c = xs.add_bbox(c)
-
-    if xs.info:
-        c = xs.info(c)
-
+    xs.add_bbox(c)
     if parity == -1:
-        c = c.rotate(180)
+        c = c.drotate(180)
 
-    c.snap_ports_to_grid()
+    c.flatten()
+    return c
 
+
+@gf.cell
+def disk_heater(
+    radius: float = 10.0,
+    gap: float = 0.2,
+    wrap_angle_deg: float = 180.0,
+    parity: int = 1,
+    cross_section: CrossSectionSpec = "strip",
+    heater_layer: LayerSpec = "HEATER",
+    via_stack: ComponentSpec = "via_stack_heater_mtop",
+    heater_width: float = 5.0,
+    heater_extent: float = 2.0,
+    via_width: float = 10.0,
+    port_orientation: AngleInDegrees | None = 90,
+) -> Component:
+    """Disk Resonator with top metal heater.
+
+    Args:
+       radius: disk resonator radius.
+       gap: Distance between the bus straight and resonator.
+       wrap_angle_deg: Angle in degrees between 0 and 180.
+        determines how much the bus straight wraps along the resonator.
+        0 corresponds to a straight bus straight.
+        180 corresponds to a bus straight wrapped around half of the resonator.
+       parity (1 or -1): 1, resonator left from bus straight, -1 resonator to the right.
+       cross_section: cross_section spec.
+       heater_layer: layer of the heater.
+       via_stack: via stack component.
+       heater_width: width of the heater.
+       heater_extent: length of heater beyond disk.
+       via_width: size of the square via at the end of the heater.
+       port_orientation: in degrees.
+    """
+    c = gf.Component()
+    xs = gf.get_cross_section(cross_section=cross_section)
+
+    disk_instance = c << disk(
+        radius=radius,
+        gap=gap,
+        wrap_angle_deg=wrap_angle_deg,
+        parity=parity,
+        cross_section=cross_section,
+    )
+
+    dx = disk_instance.dxmax - disk_instance.dxmin
+    dy = disk_instance.dymax - disk_instance.dymin
+    heater = c << gf.get_component(
+        gf.components.rectangle,
+        size=(dx + 2 * heater_extent, heater_width),
+        layer=heater_layer,
+    )
+    heater.dx = disk_instance.dx
+    heater.dy = dy / 2 + disk_instance.dymin + (xs.width + gap) / 2
+
+    via = gf.get_component(via_stack, size=(via_width, via_width))
+    c1 = c << via
+    c2 = c << via
+    c1.dxmax = heater.dxmin
+    c1.dy = heater.dy
+    c2.dxmin = heater.dxmax
+    c2.dy = heater.dy
+    c.add_ports(disk_instance.ports)
+    c.add_ports(c1.ports.filter(orientation=port_orientation), prefix="e1")
+    c.add_ports(c2.ports.filter(orientation=port_orientation), prefix="e2")
+    c.auto_rename_ports()
     return c
 
 
 if __name__ == "__main__":
-
-    c = disk(wrap_angle_deg=30)
-    c.show(show_ports=True)
+    # c = disk_heater(wrap_angle_deg=75)
+    c = disk_heater()
+    c.show()
