@@ -1,18 +1,16 @@
 from __future__ import annotations
 
-from typing import Tuple
-
 import numpy as np
 from numpy import cos, pi, sin, sqrt
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
 def ellipse(
-    radii: Tuple[float, float] = (10.0, 5.0),
+    radii: tuple[float, float] = (10.0, 5.0),
     angle_resolution: float = 2.5,
     layer: LayerSpec = "WG",
 ) -> Component:
@@ -34,10 +32,10 @@ def ellipse(
     r = a * b / (sqrt((b * cos(t)) ** 2 + (a * sin(t)) ** 2))
     xpts = r * cos(t)
     ypts = r * sin(t)
-    c.add_polygon(points=(xpts, ypts), layer=layer)
+    c.add_polygon(points=list(zip(xpts, ypts)), layer=layer)
     return c
 
 
 if __name__ == "__main__":
     c = ellipse()
-    c.show(show_ports=True)
+    c.show()
