@@ -3,7 +3,7 @@ from __future__ import annotations
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.circle import circle
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
@@ -35,4 +35,4 @@ def fiber(
 
 if __name__ == "__main__":
     c = fiber()
-    c.show(show_ports=True)
+    c.show()
