@@ -3,7 +3,7 @@ from __future__ import annotations
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.fiber import circle
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
@@ -42,14 +42,14 @@ def fiber_array(
     for i in range(n):
         core = c.add_ref(circle(radius=core_diameter / 2, layer=layer_core))
         cladding = c.add_ref(circle(radius=cladding_diameter / 2, layer=layer_cladding))
-        core.movex(i * pitch)
-        cladding.movex(i * pitch)
+        core.dmovex(i * pitch)
+        cladding.dmovex(i * pitch)
         c.add_port(
             name=f"F{i}",
             width=core_diameter,
             orientation=0,
             layer=layer_core,
-            center=(0, 0),
+            center=(i * pitch, 0),
         )
 
     return c
@@ -57,4 +57,4 @@ def fiber_array(
 
 if __name__ == "__main__":
     c = fiber_array()
-    c.show(show_ports=True)
+    c.show()
