@@ -3,7 +3,7 @@ from __future__ import annotations
 import numpy as np
 
 import gdsfactory as gf
-from gdsfactory.types import Float2, Layers
+from gdsfactory.typings import Float2, Layers
 
 
 @gf.cell
@@ -23,7 +23,7 @@ def fiducial_squares(
 
     for layer in layers:
         r = c << gf.c.rectangle(size=size, layer=layer)
-        r.move(-np.array(size) - np.array([offset, offset]))
+        r.dmove(-np.array(size) - np.array([offset, offset]))
 
     return c
 
