@@ -1,14 +1,15 @@
 from __future__ import annotations
 
-from typing import Optional
+from functools import partial
+from typing import Any
 
 import numpy as np
-from numpy import ndarray
+import numpy.typing as npt
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.geometry.functions import DEG2RAD, extrude_path
-from gdsfactory.types import CrossSectionSpec, LayerSpec
+from gdsfactory.functions import DEG2RAD, extrude_path
+from gdsfactory.typings import CrossSectionSpec, LayerSpec
 
 
 def ellipse_arc(
@@ -18,7 +19,7 @@ def ellipse_arc(
     theta_min: float,
     theta_max: float,
     angle_step: float = 0.5,
-) -> ndarray:
+) -> npt.NDArray[np.floating[Any]]:
     """Returns an elliptical arc.
 
     b = a *sqrt(1-e**2)
@@ -49,7 +50,7 @@ def grating_tooth_points(
     taper_angle: float,
     spiked: bool = True,
     angle_step: float = 1.0,
-) -> ndarray:
+) -> npt.NDArray[np.floating[Any]]:
     theta_min = -taper_angle / 2
     theta_max = taper_angle / 2
 
@@ -71,8 +72,15 @@ def grating_taper_points(
     taper_angle: float,
     wg_width: float,
     angle_step: float = 1.0,
-) -> ndarray:
-    taper_arc = ellipse_arc(a, b, taper_length, -taper_angle / 2, taper_angle / 2)
+) -> npt.NDArray[np.floating[Any]]:
+    taper_arc = ellipse_arc(
+        a=a,
+        b=b,
+        x0=taper_length,
+        theta_min=-taper_angle / 2,
+        theta_max=taper_angle / 2,
+        angle_step=angle_step,
+    )
 
     port_position = np.array((x0, 0))
     p0 = port_position + (0, wg_width / 2)
@@ -92,14 +100,12 @@ def grating_coupler_elliptical(
     nclad: float = 1.443,
     n_periods: int = 30,
     big_last_tooth: bool = False,
-    layer_slab: LayerSpec = "SLAB150",
+    layer_slab: LayerSpec | None = "SLAB150",
     slab_xmin: float = -1.0,
     slab_offset: float = 2.0,
-    fiber_marker_width: Optional[float] = 11.0,
-    fiber_marker_layer: LayerSpec = "TE",
     spiked: bool = True,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     r"""Grating coupler with parametrization based on Lumerical FDTD simulation.
 
@@ -117,8 +123,6 @@ def grating_coupler_elliptical(
         layer_slab: layer that protects the slab under the grating.
         slab_xmin: where 0 is at the start of the taper.
         slab_offset: in um.
-        fiber_marker_width: width in um.
-        fiber_marker_layer: fiber marker layer.
         spiked: grating teeth have sharp spikes to avoid non-manhattan drc errors.
         cross_section: specification (CrossSection, string or dict).
         kwargs: cross_section settings.
@@ -199,7 +203,6 @@ def grating_coupler_elliptical(
 
     if big_last_tooth:
         # Add last "large tooth" after the standard grating teeth
-
         a = total_length / (1 + x1 / a1)
         b = b1 / a1 * a
         x = x1 / a1 * a
@@ -208,31 +211,20 @@ def grating_coupler_elliptical(
         c.add_polygon(pts, layer)
 
     x = np.round(taper_length + x_output, 3)
-    if fiber_marker_width:
-        circle = gf.components.circle(
-            radius=fiber_marker_width / 2, layer=fiber_marker_layer
-        )
-        circle_ref = c.add_ref(circle)
-        circle_ref.movex(x + fiber_marker_width / 2)
-
-    name = f"vertical_{polarization.lower()}"
-    c.add_port(
-        name=name,
-        center=(x + fiber_marker_width / 2, 0),
-        width=fiber_marker_width,
-        orientation=0,
-        layer=fiber_marker_layer,
-        port_type=name,
-    )
 
     c.add_port(
-        name="o1", center=(x_output, 0), width=wg_width, orientation=180, layer=layer
+        name="o1",
+        center=(x_output, 0),
+        width=wg_width,
+        orientation=180,
+        layer=layer,
+        port_type="optical",
     )
 
     if layer_slab:
         slab_xmin += x_output + taper_length
         slab_length = total_length + slab_offset
-        slab_width = (c.ysize + 2 * slab_offset) / 2
+        slab_width = (c.dysize + 2 * slab_offset) / 2
         c.add_polygon(
             [
                 (slab_xmin, slab_width),
@@ -243,17 +235,21 @@ def grating_coupler_elliptical(
             layer_slab,
         )
 
-    if xs.add_bbox:
-        c = xs.add_bbox(c)
-    if xs.add_pins:
-        c = xs.add_pins(c)
+    xs.add_bbox(c)
+    c.add_port(
+        name="o2",
+        center=(x, 0),
+        width=10,
+        orientation=0,
+        layer=layer,
+        port_type=f"vertical_{polarization}",
+    )
     return c
 
 
-grating_coupler_elliptical_tm = gf.partial(
+grating_coupler_elliptical_tm = partial(
     grating_coupler_elliptical,
     grating_line_width=0.707,
-    fiber_marker_layer="TM",
     polarization="tm",
     taper_length=30,
     slab_xmin=-2,
@@ -276,5 +272,6 @@ if __name__ == "__main__":
     # c = gf.c.extend_ports(c)
     # c = gf.routing.add_fiber_array(grating_coupler=grating_coupler_elliptical, with_loopback=False)
 
-    c = gf.components.grating_coupler_elliptical_te()
-    c.show(show_ports=True)
+    # c = gf.components.grating_coupler_elliptical_te()
+    c = gf.components.grating_coupler_elliptical_tm()
+    c.show()
