@@ -1,19 +1,21 @@
 from __future__ import annotations
 
+from functools import partial
+from typing import Any
+
 import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.grating_coupler_elliptical import grating_tooth_points
-from gdsfactory.geometry.functions import DEG2RAD
-from gdsfactory.types import CrossSectionSpec, LayerSpec, Optional
+from gdsfactory.components.taper import taper as taper_function
+from gdsfactory.functions import DEG2RAD
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec, LayerSpec
 
 
 @gf.cell
 def grating_coupler_elliptical_trenches(
     polarization: str = "te",
-    fiber_marker_width: float = 11.0,
-    fiber_marker_layer: Optional[LayerSpec] = "TE",
     taper_length: float = 16.6,
     taper_angle: float = 30.0,
     trenches_extra_angle: float = 9.0,
@@ -22,12 +24,13 @@ def grating_coupler_elliptical_trenches(
     grating_line_width: float = 0.343,
     neff: float = 2.638,  # tooth effective index
     ncladding: float = 1.443,  # cladding index
-    layer_trench: LayerSpec = "SLAB150",
+    layer_trench: LayerSpec | None = "SHALLOW_ETCH",
     p_start: int = 26,
     n_periods: int = 30,
     end_straight_length: float = 0.2,
+    taper: ComponentSpec = taper_function,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     r"""Returns Grating coupler with defined trenches.
 
@@ -38,6 +41,7 @@ def grating_coupler_elliptical_trenches(
         polarization: 'te' or 'tm'.
         taper_length: taper length from straight I/O.
         taper_angle: grating flare angle.
+        trenches_extra_angle: extra angle for the trenches.
         wavelength: grating transmission central wavelength.
         fiber_angle: fibre polish angle in degrees.
         grating_line_width: of the 220 ridge.
@@ -47,6 +51,8 @@ def grating_coupler_elliptical_trenches(
         p_start: first tooth.
         n_periods: number of grating teeth.
         end_straight_length: at the end of straight.
+        taper: taper function.
+        cross_section: cross_section spec.
         kwargs: cross_section settings.
 
 
@@ -101,69 +107,56 @@ def grating_coupler_elliptical_trenches(
 
     xmax = x_output + taper_length + n_periods * period + 3
     y = wg_width / 2 + np.tan(taper_angle / 2 * np.pi / 180) * xmax
-    pts = [
-        (x_output, -wg_width / 2),
-        (x_output, wg_width / 2),
-        (xmax, y),
-        (xmax + end_straight_length, y),
-        (xmax + end_straight_length, -y),
-        (xmax, -y),
-    ]
-    c.add_polygon(pts, layer)
 
-    x = np.round(taper_length + period * n_periods / 2, 3)
-    if fiber_marker_layer:
-        circle = gf.components.circle(
-            radius=fiber_marker_width / 2, layer=fiber_marker_layer
-        )
-        circle_ref = c.add_ref(circle)
-        circle_ref.movex(x)
-    name = f"vertical_{polarization.lower()}"
-    c.add_port(
-        name=name,
-        center=(x, 0),
-        width=fiber_marker_width,
-        orientation=0,
-        layer=fiber_marker_layer,
-        port_type=name,
+    taper_length2 = (xmax + end_straight_length) - x_output
+    taper = c << gf.get_component(
+        taper,
+        width1=wg_width,
+        width2=2 * y,
+        length=taper_length2,
+        cross_section=cross_section,
     )
+    taper.dxmin = x_output
 
     c.add_port(
         name="o1",
-        center=(x_output, 0),
-        width=wg_width,
-        orientation=180,
-        layer=layer,
-        cross_section=xs,
+        port=taper.ports["o1"],
     )
-    c.info["period"] = period
+    c.info["period"] = float(np.round(period, 3))
     c.info["polarization"] = polarization
     c.info["wavelength"] = wavelength
-    if xs.add_bbox:
-        c = xs.add_bbox(c)
-    if xs.add_pins:
-        c = xs.add_pins(c)
+
+    x = np.round(taper_length + period * n_periods / 2, 3)
+    c.flatten()
+    c.add_port(
+        name="o2",
+        center=(x, 0),
+        width=10,
+        orientation=0,
+        layer=layer,
+        port_type=f"vertical_{polarization}",
+    )
     return c
 
 
-grating_coupler_te = gf.partial(
+grating_coupler_te = partial(
     grating_coupler_elliptical_trenches, polarization="te", taper_angle=35
 )
 
-grating_coupler_tm = gf.partial(
+grating_coupler_tm = partial(
     grating_coupler_elliptical_trenches,
     polarization="tm",
     neff=1.8,
     grating_line_width=0.6,
-    fiber_marker_layer="TM",
 )
 
 
 if __name__ == "__main__":
+    c = grating_coupler_te(cross_section="rib_bbox")
     # c = grating_coupler_elliptical_trenches(polarization="TE")
     # print(c.polarization)
-    # c = grating_coupler_te(end_straight_length=10, fiber_marker_layer=None)
+    # c = grating_coupler_te(end_straight_length=10)
     # c = grating_coupler_tm()
     # print(c.ports.keys())
-    c = gf.routing.add_fiber_array(grating_coupler=grating_coupler_elliptical_trenches)
-    c.show(show_ports=True)
+    # c = gf.routing.add_fiber_array(grating_coupler=grating_coupler_elliptical_trenches)
+    c.show()
