@@ -1,12 +1,14 @@
 from __future__ import annotations
 
+from typing import Any
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.grating_coupler_elliptical import (
     grating_coupler_elliptical_te,
 )
 from gdsfactory.components.straight_array import straight_array
-from gdsfactory.types import ComponentSpec, LayerSpec
+from gdsfactory.typings import ComponentSpec
 
 
 @gf.cell
@@ -17,8 +19,7 @@ def grating_coupler_tree(
     with_loopback: bool = False,
     bend: ComponentSpec = "bend_euler",
     fanout_length: float = 0.0,
-    layer_label: LayerSpec = "TEXT",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Array of straights connected with grating couplers.
 
@@ -31,7 +32,6 @@ def grating_coupler_tree(
         with_loopback: adds loopback.
         bend: bend spec.
         fanout_length: in um.
-        layer_label: for layer.
         kwargs: cross_section settings.
     """
     c = straight_array(
@@ -43,13 +43,9 @@ def grating_coupler_tree(
     return gf.routing.add_fiber_array(
         component=c,
         with_loopback=with_loopback,
-        optical_routing_type=0,
         grating_coupler=grating_coupler,
         fanout_length=fanout_length,
-        component_name=c.name,
         bend=bend,
-        layer_label=layer_label,
-        taper=None,
         **kwargs,
     )
 
@@ -57,4 +53,4 @@ def grating_coupler_tree(
 if __name__ == "__main__":
     c = grating_coupler_tree()
     # print(c.settings)
-    c.show(show_ports=True)
+    c.show()
