@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
@@ -43,4 +43,4 @@ def hline(
 if __name__ == "__main__":
     c = hline(width=10)
     print(c)
-    c.show(show_ports=True)
+    c.show()
