@@ -1,17 +1,14 @@
 from __future__ import annotations
 
-from typing import Tuple
-
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.rectangle import rectangle
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec, Size
 
 
-@cell
+@gf.cell
 def litho_calipers(
-    notch_size: Tuple[float, float] = (2.0, 5.0),
+    notch_size: Size = (2.0, 5.0),
     notch_spacing: float = 2.0,
     num_notches: int = 11,
     offset_per_notch: float = 0.1,
@@ -22,8 +19,7 @@ def litho_calipers(
     """Vernier caliper structure to test lithography alignment.
 
     Only the middle finger is aligned and the rest are offset.
-
-    based on phidl
+    adapted from phidl
 
     Args:
         notch_size: [xwidth, yheight].
@@ -42,21 +38,23 @@ def litho_calipers(
 
     for i in range(num_notches_total):
         if i == centre_notch:
-            D.add_ref(R1).movex(i * (notch_size[0] + notch_spacing)).movey(
-                notch_size[1]
-            )
-            D.add_ref(R2).movex(
+            ref = D.add_ref(R1)
+            ref.dmovex(i * (notch_size[0] + notch_spacing)).dmovey(notch_size[1])
+            ref = D.add_ref(R2)
+            ref.dmovex(
                 i * (notch_size[0] + notch_spacing)
                 + offset_per_notch * (centre_notch - i)
-            ).movey(-2 * notch_size[1] - row_spacing)
-        D.add_ref(R1).movex(i * (notch_size[0] + notch_spacing))
-        D.add_ref(R2).movex(
+            ).dmovey(-2 * notch_size[1] - row_spacing)
+        ref = D.add_ref(R1)
+        ref.dmovex(i * (notch_size[0] + notch_spacing))
+        ref = D.add_ref(R2)
+        ref.dmovex(
             i * (notch_size[0] + notch_spacing) + offset_per_notch * (centre_notch - i)
-        ).movey(-notch_size[1] - row_spacing)
-
+        )
+        ref.dmovey(-notch_size[1] - row_spacing)
     return D
 
 
 if __name__ == "__main__":
     c = litho_calipers()
-    c.show(show_ports=True)
+    c.show()
