@@ -1,9 +1,7 @@
 from __future__ import annotations
 
-from typing import Tuple
-
 import gdsfactory as gf
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
@@ -11,7 +9,7 @@ def litho_ruler(
     height: float = 2,
     width: float = 0.5,
     spacing: float = 2.0,
-    scale: Tuple[float, ...] = (3, 1, 1, 1, 1, 2, 1, 1, 1, 1),
+    scale: tuple[float, ...] = (3, 1, 1, 1, 1, 2, 1, 1, 1, 1),
     num_marks: int = 21,
     layer: LayerSpec = "WG",
 ) -> gf.Component:
@@ -29,17 +27,16 @@ def litho_ruler(
         num_marks: Total number of marks to generate.
         layer: Specific layer to put the ruler geometry on.
     """
+    pitch = spacing + width
     D = gf.Component()
     for n in range(num_marks):
         h = height * scale[n % len(scale)]
-        D << gf.components.rectangle(size=(width, h), layer=layer)
+        ref = D << gf.components.rectangle(size=(width, h), layer=layer)
+        ref.dmovex((n - num_marks / 2) * pitch)
 
-    D.distribute(direction="x", spacing=spacing, separation=False, edge="x")
-    D.align(alignment="ymin")
-    D.flatten()
     return D
 
 
 if __name__ == "__main__":
     c = litho_ruler()
-    c.show(show_ports=True)
+    c.show()
