@@ -1,29 +1,28 @@
 from __future__ import annotations
 
 import gdsfactory as gf
-from gdsfactory.add_padding import get_padding_points
 from gdsfactory.component import Component
-from gdsfactory.components.straight import straight
+from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.components.taper import taper as taper_function
-from gdsfactory.types import ComponentSpec, CrossSectionSpec, Optional
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec
 
 
 @gf.cell
 def mmi1x2(
-    width: Optional[float] = None,
+    width: float | None = None,
     width_taper: float = 1.0,
     length_taper: float = 10.0,
     length_mmi: float = 5.5,
     width_mmi: float = 2.5,
     gap_mmi: float = 0.25,
     taper: ComponentSpec = taper_function,
-    with_bbox: bool = True,
+    straight: ComponentSpec = straight_function,
     cross_section: CrossSectionSpec = "strip",
 ) -> Component:
-    r"""Mmi 1x2.
+    r"""1x2 MultiMode Interferometer (MMI).
 
     Args:
-        width: input and output straight width.
+        width: input and output straight width. Defaults to cross_section width.
         width_taper: interface between input straights and mmi region.
         length_taper: into the mmi region.
         length_mmi: in x direction.
@@ -31,8 +30,6 @@ def mmi1x2(
         gap_mmi:  gap between tapered wg.
         taper: taper function.
         straight: straight function.
-        with_bbox: add rectangular box in cross_section
-            bbox_layers and bbox_offsets to avoid DRC sharp edges.
         cross_section: specification (CrossSection, string or dict).
 
 
@@ -43,11 +40,11 @@ def mmi1x2(
                 ________
                |        |
                |         \__
-               |          __  E1
+               |          __  o2
             __/          /_ _ _ _
-         W0 __          | _ _ _ _| gap_mmi
+         o1 __          | _ _ _ _| gap_mmi
               \          \__
-               |          __  E0
+               |          __  o3
                |         /
                |________|
 
@@ -56,31 +53,28 @@ def mmi1x2(
 
     """
     c = Component()
-    gap_mmi = gf.snap.snap_to_grid(gap_mmi, nm=2)
-    w_mmi = width_mmi
-    w_taper = width_taper
+    gap_mmi = gf.snap.snap_to_grid(gap_mmi, grid_factor=2)
     x = gf.get_cross_section(cross_section)
+    xs_mmi = gf.get_cross_section(cross_section, width=width_mmi)
     width = width or x.width
 
-    taper = gf.get_component(
+    _taper = gf.get_component(
         taper,
         length=length_taper,
         width1=width,
-        width2=w_taper,
+        width2=width_taper,
         cross_section=cross_section,
     )
 
     a = gap_mmi / 2 + width_taper / 2
-    mmi = c << gf.get_component(
-        straight, length=length_mmi, width=w_mmi, cross_section=cross_section
-    )
+    _ = c << gf.get_component(straight, length=length_mmi, cross_section=xs_mmi)
 
     ports = [
         gf.Port(
             "o1",
             orientation=180,
             center=(0, 0),
-            width=w_taper,
+            width=width_taper,
             layer=x.layer,
             cross_section=x,
         ),
@@ -88,7 +82,7 @@ def mmi1x2(
             "o2",
             orientation=0,
             center=(+length_mmi, +a),
-            width=w_taper,
+            width=width_taper,
             layer=x.layer,
             cross_section=x,
         ),
@@ -96,52 +90,21 @@ def mmi1x2(
             "o3",
             orientation=0,
             center=(+length_mmi, -a),
-            width=w_taper,
+            width=width_taper,
             layer=x.layer,
             cross_section=x,
         ),
     ]
 
     for port in ports:
-        taper_ref = c << taper
-        taper_ref.connect(port="o2", destination=port)
+        taper_ref = c << _taper
+        taper_ref.connect(port="o2", other=port, allow_width_mismatch=True)
         c.add_port(name=port.name, port=taper_ref.ports["o1"])
-        c.absorb(taper_ref)
 
-    if with_bbox:
-        padding = []
-        for offset in x.bbox_offsets:
-            points = get_padding_points(
-                component=c,
-                default=0,
-                bottom=offset,
-                top=offset,
-            )
-            padding.append(points)
-
-        for layer, points in zip(x.bbox_layers, padding):
-            c.add_polygon(points, layer=layer)
-
-    c.absorb(mmi)
-    if x.add_bbox:
-        c = x.add_bbox(c)
-    if x.add_pins:
-        c = x.add_pins(c)
+    c.flatten()
     return c
 
 
 if __name__ == "__main__":
-    # c = mmi1x2(cross_section=dict(cross_section="rib"))
-    c = mmi1x2()
-    c.show(show_ports=True)
-
-    # c.pprint_ports()
-
-    # c2 = gf.components.extend_ports(c)
-    # c2.show()
-
-    # print(c.ports)
-    # c = mmi1x2_biased()
-    # print(c.get_optical_ports())
-    # c.write_gds(gf.PATH.gdsdir / "mmi1x2.gds")
-    # print(c.ports["o1"].cross_section.info)
+    c = mmi1x2(cross_section="rib")
+    c.show()
