@@ -1,24 +1,22 @@
 from __future__ import annotations
 
 import gdsfactory as gf
-from gdsfactory.add_padding import get_padding_points
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.components.taper import taper as taper_function
-from gdsfactory.types import ComponentSpec, CrossSectionSpec, Optional
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec
 
 
 @gf.cell
 def mmi2x2(
-    width: Optional[float] = None,
+    width: float | None = None,
     width_taper: float = 1.0,
     length_taper: float = 10.0,
     length_mmi: float = 5.5,
     width_mmi: float = 2.5,
     gap_mmi: float = 0.25,
     taper: ComponentSpec = taper_function,
-    straight: CrossSectionSpec = straight_function,
-    with_bbox: bool = True,
+    straight: ComponentSpec = straight_function,
     cross_section: CrossSectionSpec = "strip",
 ) -> Component:
     r"""Mmi 2x2.
@@ -32,7 +30,6 @@ def mmi2x2(
         gap_mmi: (width_taper + gap between tapered wg)/2.
         taper: taper function.
         straight: straight function.
-        with_bbox: box in bbox_layers and bbox_offsets to avoid DRC sharp edges.
         cross_section: spec.
 
 
@@ -43,11 +40,11 @@ def mmi2x2(
                     ________
                    |        |
                 __/          \__
-            W1  __            __  E1
+            o2  __            __  o3
                   \          /_ _ _ _
                   |         | _ _ _ _| gap_mmi
                 __/          \__
-            W0  __            __  E0
+            o1  __            __  o4
                   \          /
                    |________|
 
@@ -56,13 +53,12 @@ def mmi2x2(
 
     """
     c = gf.Component()
-    gap_mmi = gf.snap.snap_to_grid(gap_mmi, nm=2)
-    w_mmi = width_mmi
+    gap_mmi = gf.snap.snap_to_grid(gap_mmi, grid_factor=2)
     w_taper = width_taper
     x = gf.get_cross_section(cross_section)
     width = width or x.width
 
-    taper = gf.get_component(
+    _taper = gf.get_component(
         taper,
         length=length_taper,
         width1=width,
@@ -71,8 +67,8 @@ def mmi2x2(
     )
 
     a = gap_mmi / 2 + width_taper / 2
-    mmi = c << gf.get_component(
-        straight, length=length_mmi, width=w_mmi, cross_section=cross_section
+    _ = c << gf.get_component(
+        straight, length=length_mmi, width=width_mmi, cross_section=cross_section
     )
 
     ports = [
@@ -95,36 +91,16 @@ def mmi2x2(
     ]
 
     for port in ports:
-        taper_ref = c << taper
-        taper_ref.connect(port="o2", destination=port)
+        taper_ref = c << _taper
+        taper_ref.connect(port="o2", other=port, allow_width_mismatch=True)
         c.add_port(name=port.name, port=taper_ref.ports["o1"])
-        c.absorb(taper_ref)
 
-    if with_bbox:
-        x = gf.get_cross_section(cross_section)
-        padding = []
-        for offset in x.bbox_offsets:
-            points = get_padding_points(
-                component=c,
-                default=0,
-                bottom=offset,
-                top=offset,
-            )
-            padding.append(points)
-
-        for layer, points in zip(x.bbox_layers, padding):
-            c.add_polygon(points, layer=layer)
-
-    c.absorb(mmi)
-    if x.add_bbox:
-        c = x.add_bbox(c)
-    if x.add_pins:
-        c = x.add_pins(c)
+    c.flatten()
     return c
 
 
 if __name__ == "__main__":
     # c = mmi2x2(gap_mmi=0.252, cross_section="metal1")
-    c = mmi2x2(gap_mmi=0.252)
-    c.show(show_ports=True)
-    c.pprint()
+    c = mmi2x2(gap_mmi=0.252, cross_section="rib")
+    c.show()
+    # c.pprint()
