@@ -1,27 +1,19 @@
 from __future__ import annotations
 
-from typing import Tuple
+from typing import Any
 
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
-from gdsfactory.components.coupler import coupler as coupler_function
-from gdsfactory.components.mmi2x2 import mmi2x2 as mmi_splitter_function
-from gdsfactory.components.mzi import mzi2x2_2x2 as mmi_coupler_function
-from gdsfactory.components.mzi import mzi_coupler
-from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.components.taper import taper as taper_function
-from gdsfactory.types import ComponentSpec
 
 
-@cell
+@gf.cell
 def mzi_lattice(
-    coupler_lengths: Tuple[float, ...] = (10.0, 20.0),
-    coupler_gaps: Tuple[float, ...] = (0.2, 0.3),
-    delta_lengths: Tuple[float, ...] = (10.0,),
-    mzi: ComponentSpec = mzi_coupler,
-    splitter: ComponentSpec = coupler_function,
-    **kwargs,
+    coupler_lengths: tuple[float, ...] = (10.0, 20.0),
+    coupler_gaps: tuple[float, ...] = (0.2, 0.3),
+    delta_lengths: tuple[float, ...] = (10.0,),
+    mzi: str = "mzi_coupler",
+    splitter: str = "coupler",
+    **kwargs: Any,
 ) -> Component:
     r"""Mzi lattice filter.
 
@@ -31,8 +23,9 @@ def mzi_lattice(
         delta_lengths: list of length differences.
         mzi: function for the mzi.
         splitter: splitter function.
+        kwargs: additional settings.
 
-    keyword Args:
+    Keyword Args:
         length_y: vertical length for both and top arms.
         length_x: horizontal length.
         bend: 90 degrees bend library.
@@ -84,14 +77,13 @@ def mzi_lattice(
         delta_length=delta_lengths[0],
         **kwargs,
     )
-    c.add_ports(sprevious.get_ports_list(port_type="electrical"))
+    c.add_ports(sprevious.ports.filter(port_type="electrical"))
 
     stages = []
 
     for length, gap, delta_length in zip(
         coupler_lengths[2:], coupler_gaps[2:], delta_lengths[1:]
     ):
-
         splitter_settings = dict(gap=coupler_gaps[1], length=coupler_lengths[1])
         combiner_settings = dict(length=length, gap=gap)
         splitter1 = gf.get_component(splitter, **splitter_settings)
@@ -108,56 +100,56 @@ def mzi_lattice(
         splitter_settings = combiner_settings
 
         stages.append(stage)
-        c.add_ports(stage.get_ports_list(port_type="electrical"))
+        c.add_ports(stage.ports.filter(port_type="electrical"))
 
     for stage in stages:
         stage.connect("o1", sprevious.ports["o4"])
         # stage.connect('o2', sprevious.ports['o1'])
         sprevious = stage
 
-    for port in cp1.get_ports_list(orientation=180, port_type="optical"):
+    for port in cp1.ports.filter(orientation=180, port_type="optical"):
         c.add_port(port.name, port=port)
 
-    for port in sprevious.get_ports_list(orientation=0, port_type="optical"):
+    for port in sprevious.ports.filter(orientation=0, port_type="optical"):
         c.add_port(f"o_{port.name}", port=port)
 
     c.auto_rename_ports()
     return c
 
 
-@cell
+@gf.cell
 def mzi_lattice_mmi(
-    coupler_widths=(None, None),
-    coupler_widths_tapers: Tuple[float, ...] = (
+    coupler_widths: tuple[float | None, float | None] = (None, None),
+    coupler_widths_tapers: tuple[float, ...] = (
         1.0,
         1.0,
     ),
-    coupler_lengths_tapers: Tuple[float, ...] = (
+    coupler_lengths_tapers: tuple[float, ...] = (
         10.0,
         10.0,
     ),
-    coupler_lengths_mmis: Tuple[float, ...] = (
+    coupler_lengths_mmis: tuple[float, ...] = (
         5.5,
         5.5,
     ),
-    coupler_widths_mmis: Tuple[float, ...] = (
+    coupler_widths_mmis: tuple[float, ...] = (
         2.5,
         2.5,
     ),
-    coupler_gaps_mmis: Tuple[float, ...] = (
+    coupler_gaps_mmis: tuple[float, ...] = (
         0.25,
         0.25,
     ),
-    taper_functions_mmis=(
-        taper_function,
-        taper_function,
+    taper_functions_mmis: tuple[str, ...] = (
+        "taper",
+        "taper",
     ),
-    straight_functions_mmis=(straight_function, straight_function),
-    cross_sections_mmis=("strip", "strip"),
-    delta_lengths: Tuple[float, ...] = (10.0,),
-    mzi=mmi_coupler_function,
-    splitter=mmi_splitter_function,
-    **kwargs,
+    straight_functions_mmis: tuple[str, ...] = ("straight", "straight"),
+    cross_sections_mmis: tuple[str, ...] = ("strip", "strip"),
+    delta_lengths: tuple[float, ...] = (10.0,),
+    mzi: str = "mzi2x2_2x2",
+    splitter: str = "mmi2x2",
+    **kwargs: Any,
 ) -> Component:
     r"""Mzi lattice filter, with MMI couplers.
 
@@ -174,8 +166,9 @@ def mzi_lattice_mmi(
         delta_lengths: list of length differences.
         mzi: function for the mzi.
         splitter: splitter function.
+        kwargs: additional settings.
 
-    keyword Args:
+    Keyword Args:
         length_y: vertical length for both and top arms.
         length_x: horizontal length.
         bend: 90 degrees bend library.
@@ -257,7 +250,7 @@ def mzi_lattice_mmi(
         delta_length=delta_lengths[0],
         **kwargs,
     )
-    c.add_ports(sprevious.get_ports_list(port_type="electrical"))
+    c.add_ports(sprevious.ports.filter(port_type="electrical"))
 
     stages = []
 
@@ -320,17 +313,17 @@ def mzi_lattice_mmi(
         splitter_settings = combiner_settings
 
         stages.append(stage)
-        c.add_ports(stage.get_ports_list(port_type="electrical"))
+        c.add_ports(stage.ports.filter(port_type="electrical"))
 
     for stage in stages:
         stage.connect("o1", sprevious.ports["o4"])
         # stage.connect('o2', sprevious.ports['o1'])
         sprevious = stage
 
-    for port in cp1.get_ports_list(orientation=180, port_type="optical"):
+    for port in cp1.ports.filter(orientation=180, port_type="optical"):
         c.add_port(port.name, port=port)
 
-    for port in sprevious.get_ports_list(orientation=0, port_type="optical"):
+    for port in sprevious.ports.filter(orientation=0, port_type="optical"):
         c.add_port(f"o_{port.name}", port=port)
 
     c.auto_rename_ports()
@@ -338,30 +331,32 @@ def mzi_lattice_mmi(
 
 
 if __name__ == "__main__":
-    cpl = [10, 20, 30]
-    cpg = [0.1, 0.2, 0.3]
-    dl0 = [100, 200]
+    cpl = (10, 20, 30)
+    cpg = (0.1, 0.2, 0.3)
+    dl0 = (100, 200)
 
-    # cpl = [10, 20, 30, 40]
-    # cpg = [0.2, 0.3, 0.5, 0.5]
-    # dl0 = [0, 50, 100]
+    cpl = (10, 20, 30, 40)
+    cpg = (0.2, 0.3, 0.5, 0.5)
+    dl0 = (0, 50, 100)
 
-    # c = mzi_lattice(
-    #     coupler_lengths=cpl, coupler_gaps=cpg, delta_lengths=dl0, length_x=1
-    # )
-    # c = mzi_lattice(delta_lengths=(20,))
-    # c.show(show_ports=True)
-
-    c = mzi_lattice_mmi(
-        coupler_widths=(None,) * 5,
-        coupler_widths_tapers=(1.0,) * 5,
-        coupler_lengths_tapers=(10.0,) * 5,
-        coupler_lengths_mmis=(5.5,) * 5,
-        coupler_widths_mmis=(2.5,) * 5,
-        coupler_gaps_mmis=(0.25,) * 5,
-        taper_functions_mmis=(taper_function,) * 5,
-        straight_functions_mmis=(straight_function,) * 5,
-        cross_sections_mmis=("strip",) * 5,
-        delta_lengths=(10.0,) * 4,
+    c = mzi_lattice(
+        coupler_lengths=cpl, coupler_gaps=cpg, delta_lengths=dl0, length_x=1
     )
-    c.show(show_ports=True)
+    # c = mzi_lattice(delta_lengths=(20,))
+    c.show()
+
+    # c = mzi_lattice_mmi(
+    #     coupler_widths=(None,) * 5,
+    #     coupler_widths_tapers=(1.0,) * 5,
+    #     coupler_lengths_tapers=(10.0,) * 5,
+    #     coupler_lengths_mmis=(5.5,) * 5,
+    #     coupler_widths_mmis=(2.5,) * 5,
+    #     coupler_gaps_mmis=(0.25,) * 5,
+    #     taper_functions_mmis=("taper",) * 5,
+    #     straight_functions_mmis=("straight",) * 5,
+    #     cross_sections_mmis=("strip",) * 5,
+    #     delta_lengths=(10.0,) * 4,
+    # )
+    c = mzi_lattice_mmi()
+    # c.get_netlist()
+    c.show()
