@@ -1,14 +1,12 @@
 from __future__ import annotations
 
-from typing import Optional
-
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bend_euler import bend_euler
 from gdsfactory.components.coupler import coupler as coupler_function
 from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.components.taper import taper as taper_function
-from gdsfactory.types import ComponentSpec
+from gdsfactory.typings import ComponentFactory, Delta
 
 
 @gf.cell
@@ -16,20 +14,20 @@ def mzit(
     w0: float = 0.5,
     w1: float = 0.45,
     w2: float = 0.55,
-    dy: float = 2.0,
+    dy: Delta = 2.0,
     delta_length: float = 10.0,
     length: float = 1.0,
     coupler_length1: float = 5.0,
     coupler_length2: float = 10.0,
     coupler_gap1: float = 0.2,
     coupler_gap2: float = 0.3,
-    taper: ComponentSpec = taper_function,
+    taper: ComponentFactory = taper_function,
     taper_length: float = 5.0,
-    bend90: ComponentSpec = bend_euler,
-    straight: ComponentSpec = straight_function,
-    coupler1: Optional[ComponentSpec] = coupler_function,
-    coupler2: ComponentSpec = coupler_function,
-    **kwargs,
+    bend90: ComponentFactory = bend_euler,
+    straight: ComponentFactory = straight_function,
+    coupler1: ComponentFactory | None = coupler_function,
+    coupler2: ComponentFactory = coupler_function,
+    cross_section: str = "strip",
 ) -> Component:
     r"""Mzi tolerant to fabrication variations.
 
@@ -37,6 +35,7 @@ def mzit(
     http://photonics.intec.ugent.be/publications/PhD.asp?ID=250
 
     Args:
+        w0: input waveguide width (um).
         w1: narrow waveguide width (um).
         w2: wide waveguide width (um).
         dy: port to port vertical spacing.
@@ -52,7 +51,7 @@ def mzit(
         straight: spec.
         coupler1: coupler1 spec (optional).
         coupler2: coupler2 spec.
-        kwargs: cross_section settings.
+        cross_section: cross_section spec.
 
     .. code::
 
@@ -78,11 +77,13 @@ def mzit(
 
     """
     c = gf.Component()
-    cp2 = c << coupler2(
+
+    cp2 = c << gf.get_component(
+        coupler2,
         length=coupler_length2,
         gap=coupler_gap2,
         dy=dy,
-        **kwargs,
+        cross_section=cross_section,
     )
 
     # inner arm (w1)
@@ -91,96 +92,81 @@ def mzit(
         width1=w0,
         width2=w1,
         length=taper_length,
-        **kwargs,
+        cross_section=cross_section,
     )
     t1.connect("o1", cp2.ports["o3"])
-    b1t = c << gf.get_component(
-        bend90,
-        width=w1,
-        **kwargs,
-    )
-    b1b = c << gf.get_component(
-        bend90,
-        width=w1,
-        **kwargs,
-    )
+
+    b1 = gf.get_component(bend90, cross_section=cross_section, width=w1)
+    b1t = c << b1
+    b1b = c << b1
 
     b1b.connect("o1", t1.ports["o2"])
     b1t.connect("o1", b1b.ports["o2"])
 
-    t3b = c << gf.get_component(
-        taper,
+    t3b = c << taper(
         width1=w1,
         width2=w2,
         length=taper_length,
-        **kwargs,
+        cross_section=cross_section,
     )
     t3b.connect("o1", b1t.ports["o2"])
-    wgs2 = c << gf.get_component(straight, width=w2, length=length, **kwargs)
+    wgs2 = c << straight(length=length, cross_section=cross_section, width=w2)
     wgs2.connect("o1", t3b.ports["o2"])
-    t20i = c << gf.get_component(
-        taper,
+    t20i = c << taper(
         width1=w2,
         width2=w0,
         length=taper_length,
-        **kwargs,
+        cross_section=cross_section,
     )
     t20i.connect("o1", wgs2.ports["o2"])
 
     # outer_arm (w2)
-    t2 = c << gf.get_component(
-        taper,
+    t2 = c << taper(
         width1=w0,
         width2=w2,
         length=taper_length,
-        **kwargs,
+        cross_section=cross_section,
     )
     t2.connect("o1", cp2.ports["o4"])
 
     dx = (delta_length - 2 * dy) / 2
     assert (
         delta_length >= 4 * dy
-    ), f"`delta_length`={delta_length} needs to be at least {4*dy}"
+    ), f"`delta_length`={delta_length} needs to be at least {4 * dy}"
 
-    wg2b = c << gf.get_component(straight, width=w2, length=dx, **kwargs)
+    wg2b = c << straight(length=dx, cross_section=cross_section, width=w2)
     wg2b.connect("o1", t2.ports["o2"])
 
-    b2t = c << gf.get_component(
-        bend90,
-        width=w2,
-        **kwargs,
-    )
-    b2b = c << gf.get_component(
-        bend90,
-        width=w2,
-        **kwargs,
-    )
+    b2 = bend90(cross_section=cross_section, width=w2)
+    b2t = c << b2
+    b2b = c << b2
+    wy = straight(length=2 * dy, cross_section=cross_section, width=w2)
+    wx = straight(length=dx, cross_section=cross_section, width=w2)
 
     b2b.connect("o1", wg2b.ports["o2"])
+
     # vertical straight
-    wg2y = c << gf.get_component(straight, width=w2, length=2 * dy, **kwargs)
+    wg2y = c << wy
     wg2y.connect("o1", b2b.ports["o2"])
     b2t.connect("o1", wg2y.ports["o2"])
 
-    wg2t = c << gf.get_component(straight, width=w2, length=dx, **kwargs)
+    wg2t = c << wx
     wg2t.connect("o1", b2t.ports["o2"])
 
-    t3t = c << gf.get_component(
-        taper,
+    t3t = c << taper(
         width1=w2,
         width2=w1,
         length=taper_length,
-        **kwargs,
+        cross_section=cross_section,
     )
     t3t.connect("o1", wg2t.ports["o2"])
-    wgs1 = c << gf.get_component(straight, width=w1, length=length, **kwargs)
+    wgs1 = c << straight(length=length, cross_section=cross_section, width=w1)
     wgs1.connect("o1", t3t.ports["o2"])
-    t20o = c << gf.get_component(
-        taper,
+    t20o = c << taper(
         width1=w1,
         width2=w0,
         length=taper_length,
-        **kwargs,
+        cross_section=cross_section,
     )
     t20o.connect("o1", wgs1.ports["o2"])
 
@@ -189,7 +175,7 @@ def mzit(
             length=coupler_length1,
             gap=coupler_gap1,
             dy=dy,
-            **kwargs,
+            cross_section=cross_section,
         )
 
         cp1.connect("o3", t20o.ports["o2"])
@@ -207,10 +193,11 @@ def mzit(
 
 
 if __name__ == "__main__":
+    c = mzit(cross_section="rib")
     # c = mzit(coupler1=None)
     # c = mzit(delta_length=20, layer=(2, 0))
-    c = mzit(delta_length=20)
+    # c = mzit(delta_length=20, cross_section="rib_bbox")
     # c = mzit(delta_length=20, coupler_gap1=0.1, coupler_gap2=0.5)
     # c = mzit(delta_length=20, coupler_gap1=0.5, coupler_gap2=0.1)
     # c = mzit(coupler_length1=200)
-    c.show(show_ports=True)
+    c.show()
