@@ -1,18 +1,16 @@
 from __future__ import annotations
 
-from typing import Tuple
-
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.mzit import mzit
-from gdsfactory.types import ComponentSpec
+from gdsfactory.typings import ComponentSpec
 
 
 @gf.cell
 def mzit_lattice(
-    coupler_lengths: Tuple[float, ...] = (10.0, 20.0),
-    coupler_gaps: Tuple[float, ...] = (0.2, 0.3),
-    delta_lengths: Tuple[float, ...] = (10.0,),
+    coupler_lengths: tuple[float, ...] = (10.0, 20.0),
+    coupler_gaps: tuple[float, ...] = (0.2, 0.3),
+    delta_lengths: tuple[float, ...] = (10.0,),
     mzi: ComponentSpec = mzit,
 ) -> Component:
     r"""Mzi fab tolerant lattice filter.
@@ -20,23 +18,23 @@ def mzit_lattice(
     .. code::
 
                            cp1
-           W3  W1 __                  __ E1___w0_t2   _w2___
+           o4  o2 __                  __ o3___w0_t2   _w2___
                     \                /                      \
                      \    length1   /                        |
                       ============== gap1                    |
                      /              \                        |
                   __/                \_____w0___t1   _w1     |
-           W2  W0                       E0               \   | .
+           o3  o1                       o4               \   | .
                             ...                          |   | .
-           W1  W1                                        |   | .
-                  __                  __w0____t1____w1___/   |
+           o2  o2                    o3                  |   | .
+                  __                  _____w0___t1___w1__/   |
                     \                /                       |
                      \    lengthN   /                        |
                       ============== gapN                    |
                      /               \                       |
                   __/                 \_                     |
-           W0  W0                      \ E0_w0__t2 __w1_____/
-                           cpN
+           o1  o1                      \___w0___t2___w1_____/
+                           cpN       o4
 
 
     """
@@ -81,7 +79,7 @@ def mzit_lattice(
 
     for i, coupler in enumerate(couplers):
         if i % 2 == 0:
-            coupler.mirror()
+            coupler.dmirror()
         coupler.connect("o3", coupler0.ports["o1"])
         coupler.connect("o4", coupler0.ports["o2"])
         coupler0 = coupler
@@ -104,4 +102,4 @@ if __name__ == "__main__":
 
     c = mzit_lattice(coupler_lengths=cpl, coupler_gaps=cpg, delta_lengths=dl0)
     # c = mzit_lattice()
-    c.show(show_ports=True)
+    c.show()
