@@ -1,25 +1,21 @@
 from __future__ import annotations
 
 import itertools as it
-from typing import Any, Dict, List, Tuple
+from typing import Any
 
 import gdsfactory as gf
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.grid import grid, grid_with_text
 from gdsfactory.pack import pack
-from gdsfactory.types import CellSpec, ComponentSpec, Optional
-
-_doe = "mmi1x2"
-_settings = dict(length_mmi=[2.5, 100], width_mmi=[4, 10])
+from gdsfactory.typings import CellSpec, ComponentSpec
 
 
 def generate_doe(
     doe: ComponentSpec,
-    settings: Dict[str, List[Any]],
+    settings: dict[str, list[Any]],
     do_permutations: bool = False,
-    function: Optional[CellSpec] = None,
-) -> Tuple[List[Component], List[Dict]]:
+    function: CellSpec | None = None,
+) -> tuple[tuple[Component, ...], tuple[dict, ...]]:
     """Generates a component DOE (Design of Experiment).
 
     which can then be packed, or used elsewhere.
@@ -46,16 +42,18 @@ def generate_doe(
         component_list = [
             gf.get_component(doe, **settings) for settings in settings_list
         ]
+
+    component_list = tuple(component_list)
+    settings_list = tuple(settings_list)
     return component_list, settings_list
 
 
-@cell
 def pack_doe(
-    doe: ComponentSpec = _doe,
-    settings: Dict[str, List[Any]] = _settings,
+    doe: ComponentSpec,
+    settings: dict[str, tuple[Any, ...]],
     do_permutations: bool = False,
-    function: Optional[CellSpec] = None,
-    **kwargs,
+    function: CellSpec | None = None,
+    **kwargs: Any,
 ) -> Component:
     """Packs a component DOE (Design of Experiment) using pack.
 
@@ -64,8 +62,9 @@ def pack_doe(
         settings: component settings.
         do_permutations: for each setting.
         function: to apply (add padding, grating couplers).
+        kwargs: for pack.
 
-    keyword Args:
+    Keyword Args:
         spacing: Minimum distance between adjacent shapes.
         aspect_ratio: (width, height) ratio of the rectangular bin.
         max_size: Limits the size into which the shapes will be packed.
@@ -83,10 +82,10 @@ def pack_doe(
         v_mirror: vertical mirror using x axis (1, y) (0, y).
     """
     component_list, settings_list = generate_doe(
-        doe, settings, do_permutations, function
+        doe=doe, settings=settings, do_permutations=do_permutations, function=function
     )
 
-    c = pack(component_list=component_list, **kwargs)
+    c = pack(component_list, **kwargs)
 
     if len(c) > 1:
         raise ValueError(
@@ -98,25 +97,25 @@ def pack_doe(
     return c
 
 
-@cell
 def pack_doe_grid(
-    doe: ComponentSpec = _doe,
-    settings: Dict[str, List[Any]] = _settings,
+    doe: ComponentSpec,
+    settings: dict[str, tuple[Any, ...]],
     do_permutations: bool = False,
-    function: Optional[CellSpec] = None,
+    function: CellSpec | None = None,
     with_text: bool = False,
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Packs a component DOE (Design of Experiment) using grid.
 
     Args:
-        component: function to return Components.
+        doe: function to return Components.
         settings: component settings.
         do_permutations: for each setting.
         function: to apply to component (add padding, grating couplers).
         with_text: includes text label.
+        kwargs: for grid.
 
-    keyword Args:
+    Keyword Args:
         spacing: between adjacent elements on the grid, can be a tuple for
             different distances in height and width.
         separation: If True, guarantees elements are separated with fixed spacing
@@ -148,6 +147,9 @@ def pack_doe_grid(
             gf.get_component(doe, **settings) for settings in settings_list
         ]
 
+    component_list = tuple(component_list)
+    settings_list = tuple(settings_list)
+
     if with_text:
         c = grid_with_text(component_list, **kwargs)
 
@@ -160,15 +162,15 @@ def pack_doe_grid(
 
 
 if __name__ == "__main__":
-    # c = pack_doe_grid(
-    #     doe="mmi1x2",
-    #     settings=dict(length_mmi=[2.5, 100], width_mmi=[4, 10]),
-    #     with_text=True,
-    #     spacing=(100, 100),
-    #     shape=(2, 2),
-    #     do_permutations=True,
-    # )
+    c = pack_doe_grid(
+        doe="mmi1x2",
+        settings=dict(length_mmi=(2.5, 100), width_mmi=(4, 10)),
+        with_text=True,
+        spacing=(100, 100),
+        shape=(2, 2),
+        do_permutations=True,
+    )
 
-    # c = pack_doe(doe="mmi1x2", settings=dict(length_mmi=[2, 100], width_mmi=[4, 10]))
-    c = pack_doe()
-    c.show(show_ports=True)
+    c = pack_doe(doe="mmi1x2", settings=dict(length_mmi=[2, 100], width_mmi=[4, 10]))
+    # c = pack_doe()
+    c.show()
