@@ -1,17 +1,15 @@
 from __future__ import annotations
 
-from typing import Optional
-
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
 def ramp(
     length: float = 10.0,
     width1: float = 5.0,
-    width2: Optional[float] = 8.0,
+    width2: float | None = 8.0,
     layer: LayerSpec = "WG",
 ) -> Component:
     """Return a ramp component.
@@ -29,7 +27,7 @@ def ramp(
     xpts = [0, length, length, 0]
     ypts = [width1, width2, 0, 0]
     c = Component()
-    c.add_polygon([xpts, ypts], layer=layer)
+    c.add_polygon(tuple(zip(xpts, ypts)), layer=layer)
     c.add_port(
         name="o1", center=[0, width1 / 2], width=width1, orientation=180, layer=layer
     )
@@ -45,4 +43,4 @@ def ramp(
 
 if __name__ == "__main__":
     c = ramp()
-    c.show(show_ports=True)
+    c.show()
