@@ -1,12 +1,10 @@
 from __future__ import annotations
 
-from typing import Dict, Optional, Tuple
-
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.ring_single import ring_single
 from gdsfactory.components.straight import straight
-from gdsfactory.types import ComponentFactory, CrossSectionSpec
+from gdsfactory.typings import ComponentFactory, CrossSectionSpec
 
 _list_of_dicts = (
     dict(length_x=10.0, radius=5.0),
@@ -18,19 +16,16 @@ _list_of_dicts = (
 def ring_single_array(
     ring: ComponentFactory = ring_single,
     spacing: float = 5.0,
-    list_of_dicts: Optional[Tuple[Dict[str, float], ...]] = None,
+    list_of_dicts: tuple[dict[str, float], ...] | None = None,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
 ) -> Component:
     """Ring of single bus connected with straights.
 
     Args:
         ring: ring function.
-        straight: straight function.
         spacing: between rings.
         list_of_dicts: settings for each ring.
         cross_section: spec.
-        kwargs: cross_section settings.
 
     .. code::
 
@@ -45,15 +40,13 @@ def ring_single_array(
     list_of_dicts = list_of_dicts or _list_of_dicts
     c = Component()
     settings0 = list_of_dicts[0]
-    settings0.update(**kwargs)
-    ring1 = c << gf.get_component(ring, cross_section=cross_section, **settings0)
+    ring1 = c << ring(cross_section=cross_section, **settings0)
 
     ring0 = ring1
-    wg = straight(length=spacing, cross_section=cross_section, **kwargs)
+    wg = straight(length=spacing, cross_section=cross_section)
 
     for settings in list_of_dicts[1:]:
-        settings.update(**kwargs)
-        ringi = c << gf.get_component(ring, cross_section=cross_section, **settings)
+        ringi = c << ring(cross_section=cross_section, **settings)
         wgi = c << wg
         wgi.connect("o1", ring0.ports["o2"])
         ringi.connect("o1", wgi.ports["o2"])
@@ -65,5 +58,5 @@ def ring_single_array(
 
 
 if __name__ == "__main__":
-    c = ring_single_array(cross_section="rib", width=2)
-    c.show(show_ports=True)
+    c = ring_single_array(cross_section="strip")
+    c.show()
