@@ -11,8 +11,8 @@ def spiral_double(
     separation: float = 2.0,
     number_of_loops: float = 3,
     npoints: int = 1000,
-    cross_section: gf.types.CrossSectionSpec = "strip",
-    bend: gf.types.ComponentSpec = bend_circular,
+    cross_section: gf.typings.CrossSectionSpec = "strip",
+    bend: gf.typings.ComponentSpec = bend_circular,
 ) -> gf.Component:
     """Returns a spiral double (spiral in, and then out).
 
@@ -29,9 +29,9 @@ def spiral_double(
     bend = gf.get_component(
         bend, radius=min_bend_radius / 2, angle=180, cross_section=cross_section
     )
-    bend1 = component.add_ref(bend).mirror()
+    bend1 = component.add_ref(bend)
     bend2 = component.add_ref(bend)
-    bend2.connect("o2", bend1.ports["o1"])
+    bend2.connect("o2", bend1.ports["o1"], mirror=True)
 
     path = spiral_archimedean(
         min_bend_radius=min_bend_radius,
@@ -43,24 +43,28 @@ def spiral_double(
     path.end_angle = 0
 
     spiral = path.extrude(cross_section=cross_section)
-    spiral1 = component.add_ref(spiral).connect("o1", bend1.ports["o2"])
-    spiral2 = component.add_ref(spiral).connect("o1", bend2.ports["o1"])
+    spiral1 = component.add_ref(spiral)
+    spiral2 = component.add_ref(spiral)
+    spiral2.dmirror()
+
+    spiral2.connect("o1", bend2.ports["o1"])
+    spiral1.connect("o1", bend1.ports["o2"], mirror=True)
 
     component.add_port("o1", port=spiral1.ports["o2"])
     component.add_port("o2", port=spiral2.ports["o2"])
-
     component.info["length"] = float(path.length() + bend.info["length"]) * 2
+    component.flatten()
     return component
 
 
 if __name__ == "__main__":
     c = spiral_double(
-        min_bend_radius=10,
-        separation=2,
-        number_of_loops=3,
-        npoints=1000,
-        cross_section="nitride",
+        # min_bend_radius=10,
+        # separation=2,
+        # number_of_loops=3,
+        # npoints=1000,
+        # cross_section="rib",
     )
     print(c.ports["o1"].orientation)
     print(c.ports["o2"].orientation)
-    c.show(show_ports=True)
+    c.show()
