@@ -2,16 +2,14 @@ from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.components.bend_s import bend_s
-from gdsfactory.components.mmi1x2 import mmi1x2
-from gdsfactory.types import ComponentSpec
+from gdsfactory.typings import ComponentSpec
 
 
 @gf.cell
 def splitter_chain(
-    splitter: ComponentSpec = mmi1x2,
+    splitter: ComponentSpec = "mmi1x2",
     columns: int = 3,
-    bend: ComponentSpec = bend_s,
+    bend: ComponentSpec = "bend_s",
 ) -> Component:
     """Chain of splitters.
 
@@ -36,7 +34,7 @@ def splitter_chain(
     splitter_component = gf.get_component(splitter)
     cref = c.add_ref(splitter_component)
 
-    splitter_ports_east = cref.get_ports_list(port_type="optical", orientation=0)
+    splitter_ports_east = list(cref.ports.filter(port_type="optical", orientation=0))
     e1_port_name = splitter_ports_east[0].name
     e0_port_name = splitter_ports_east[1].name
 
@@ -46,11 +44,9 @@ def splitter_chain(
 
     for i in range(1, columns):
         bref = c.add_ref(bend)
-        bref.connect(port="o1", destination=cref.ports[e1_port_name])
-
+        bref.connect(port="o1", other=cref.ports[e1_port_name])
         cref = c.add_ref(splitter_component)
-
-        cref.connect(port="o1", destination=bref.ports["o2"])
+        cref.connect(port="o1", other=bref.ports["o2"])
         c.add_port(name=f"o{i+2}", port=cref.ports[e0_port_name])
 
     c.add_port(name=f"o{i+3}", port=cref.ports[e1_port_name])
@@ -62,4 +58,3 @@ if __name__ == "__main__":
     # component = splitter_chain(splitter=gf.components.mmi1x2, columns=4)
     component = splitter_chain()
     component.show()
-    component.pprint
