@@ -1,108 +1,104 @@
 from __future__ import annotations
 
-from typing import List, Optional
+from functools import partial
+from typing import Any
 
 import gdsfactory as gf
-from gdsfactory.add_padding import get_padding_points
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.port import Port
-from gdsfactory.types import CrossSectionSpec, LayerSpec
+from gdsfactory.typings import CrossSectionSpec, LayerSpec
 
 
-@cell
+@gf.cell
 def taper(
     length: float = 10.0,
     width1: float = 0.5,
-    width2: Optional[float] = None,
-    port: Optional[Port] = None,
-    with_bbox: bool = True,
+    width2: float | None = None,
+    port: Port | None = None,
     with_two_ports: bool = True,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    port_names: tuple[str, str] = ("o1", "o2"),
+    port_types: tuple[str, str] = ("optical", "optical"),
+    with_bbox: bool = True,
+    **kwargs: Any,
 ) -> Component:
-    """Linear taper.
-
-    Deprecated, use gf.components.taper_cross_section instead
+    """Linear taper, which tapers only the main cross section section.
 
     Args:
         length: taper length.
-        width1: width of the west port.
-        width2: width of the east port.
+        width1: width of the west/left port.
+        width2: width of the east/right port. Defaults to width1.
         port: can taper from a port instead of defining width1.
-        with_bbox: box in bbox_layers and bbox_offsets to avoid DRC sharp edges.
         with_two_ports: includes a second port.
             False for terminator and edge coupler fiber interface.
         cross_section: specification (CrossSection, string, CrossSectionFactory dict).
+        port_names: input and output port names. Second name only used if with_two_ports.
+        port_types: input and output port types. Second type only used if with_two_ports.
+        with_bbox: box in bbox_layers and bbox_offsets to avoid DRC sharp edges.
         kwargs: cross_section settings.
     """
-    x = gf.get_cross_section(cross_section, **kwargs)
+    if len(port_types) != 2:
+        raise ValueError("port_types should have two elements")
+
+    x1 = gf.get_cross_section(cross_section, width=width1, **kwargs)
+    if width2:
+        width2 = gf.snap.snap_to_grid2x(width2)
+        x2 = gf.get_cross_section(cross_section, width=width2, **kwargs)
+    else:
+        x2 = x1
+
+    width1 = x1.width
+    width2 = x2.width
+    width_max = max([width1, width2])
+    x = gf.get_cross_section(cross_section, width=width_max, **kwargs)
     layer = x.layer
 
     if isinstance(port, gf.Port) and width1 is None:
         width1 = port.width
-    if width2 is None:
-        width2 = width1
 
+    width2 = width2 or width1
+    c = gf.Component()
     y1 = width1 / 2
     y2 = width2 / 2
 
-    x1 = x.copy(width=width1)
-    x2 = x.copy(width=width2)
+    if length:
+        p1 = gf.kdb.DPolygon([(0, y1), (length, y2), (length, -y2), (0, -y1)])
+        c.add_polygon(p1, layer=layer)
 
-    xpts = [0, length, length, 0]
-    ypts = [y1, y2, -y2, -y1]
+        s0_width = x.sections[0].width
 
-    c = gf.Component()
-    c.add_polygon((xpts, ypts), layer=layer)
-
-    if x.cladding_layers and x.cladding_offsets:
-        for layer, offset in zip(x.cladding_layers, x.cladding_offsets):
-            y1 = width1 / 2 + offset
-            y2 = width2 / 2 + offset
-            ypts = [y1, y2, -y2, -y1]
-            c.add_polygon((xpts, ypts), layer=gf.get_layer(layer))
+        for section in x.sections[1:]:
+            delta_width = abs(section.width - s0_width)
+            y1 = (width1 + delta_width) / 2
+            y2 = (width2 + delta_width) / 2
+            p1 = gf.kdb.DPolygon([(0, y1), (length, y2), (length, -y2), (0, -y1)])
+            c.add_polygon(p1, layer=section.layer)
 
+    if with_bbox:
+        x.add_bbox(c)
     c.add_port(
-        name="o1",
+        name=port_names[0],
         center=(0, 0),
         width=width1,
         orientation=180,
         layer=x.layer,
         cross_section=x1,
+        port_type=port_types[0],
     )
     if with_two_ports:
         c.add_port(
-            name="o2",
+            name=port_names[1],
             center=(length, 0),
             width=width2,
             orientation=0,
             layer=x.layer,
             cross_section=x2,
+            port_type=port_types[1],
         )
 
-    if with_bbox and length:
-        padding = []
-        for offset in x.bbox_offsets:
-            points = get_padding_points(
-                component=c,
-                default=0,
-                bottom=offset,
-                top=offset,
-            )
-            padding.append(points)
-
-        for layer, points in zip(x.bbox_layers, padding):
-            c.add_polygon(points, layer=layer)
-
     c.info["length"] = length
     c.info["width1"] = float(width1)
     c.info["width2"] = float(width2)
-
-    if x.add_bbox:
-        c = x.add_bbox(c)
-    if x.add_pins:
-        c = x.add_pins(c)
     return c
 
 
@@ -116,13 +112,11 @@ def taper_strip_to_ridge(
     layer_wg: LayerSpec = "WG",
     layer_slab: LayerSpec = "SLAB90",
     cross_section: CrossSectionSpec = "strip",
-    bbox_layers: Optional[List[LayerSpec]] = None,
-    bbox_offsets: Optional[List[float]] = None,
+    use_slab_port: bool = False,
+    **kwargs: Any,
 ) -> Component:
     r"""Linear taper from strip to rib.
 
-    Deprecated, use gf.components.taper_cross_section instead.
-
     Args:
         length: taper length (um).
         width1: in um.
@@ -132,6 +126,8 @@ def taper_strip_to_ridge(
         layer_wg: for input waveguide.
         layer_slab: for output waveguide with slab.
         cross_section: for input waveguide.
+        use_slab_port: if True adds a second port for the slab.
+        kwargs: cross_section settings.
 
     .. code::
 
@@ -145,52 +141,38 @@ def taper_strip_to_ridge(
                      \__________________________
 
     """
+    xs = gf.get_cross_section(cross_section, **kwargs)
+
     taper_wg = taper(
         length=length,
         width1=width1,
         width2=width2,
-        layer=layer_wg,
         cross_section=cross_section,
+        layer=layer_wg,
     )
     taper_slab = taper(
         length=length,
         width1=w_slab1,
         width2=w_slab2,
+        cross_section=cross_section,
+        with_bbox=False,
         layer=layer_slab,
     )
 
     c = gf.Component()
-    for _t in [taper_wg, taper_slab]:
-        taper_ref = _t.ref()
-        c.add(taper_ref)
-        c.absorb(taper_ref)
+    taper_ref_wg = c << taper_wg
+    taper_ref_slab = c << taper_slab
 
     c.info["length"] = length
-    c.add_port(name="o1", port=taper_wg.ports["o1"])
-    c.add_port(name="o2", port=taper_slab.ports["o2"])
+    c.add_port(name="o1", port=taper_ref_wg.ports["o1"])
+    if use_slab_port:
+        c.add_port(name="o2", port=taper_ref_slab.ports["o2"])
+    else:
+        c.add_port(name="o2", port=taper_ref_wg.ports["o2"])
 
-    x = gf.get_cross_section(cross_section)
     if length:
-        padding = []
-        bbox_offsets = bbox_offsets or x.bbox_offsets
-        bbox_layers = bbox_layers or x.bbox_layers
-
-        for offset in bbox_offsets:
-            points = get_padding_points(
-                component=c,
-                default=0,
-                bottom=offset,
-                top=offset,
-            )
-            padding.append(points)
-
-        for layer, points in zip(bbox_layers, padding):
-            c.add_polygon(points, layer=layer)
-
-    if x.add_bbox:
-        c = x.add_bbox(c)
-    if x.add_pins:
-        c = x.add_pins(c)
+        xs.add_bbox(c)
+    c.flatten()
     return c
 
 
@@ -200,7 +182,7 @@ def taper_strip_to_ridge_trenches(
     width: float = 0.5,
     slab_offset: float = 3.0,
     trench_width: float = 2.0,
-    trench_layer: LayerSpec = "SLAB90",
+    trench_layer: LayerSpec = "DEEP_ETCH",
     layer_wg: LayerSpec = "WG",
     trench_offset: float = 0.1,
 ) -> gf.Component:
@@ -222,7 +204,7 @@ def taper_strip_to_ridge_trenches(
     # straight
     x = [0, length, length, 0]
     yw = [y0, yL, -yL, -y0]
-    c.add_polygon((x, yw), layer=layer_wg)
+    c.add_polygon(list(zip(x, yw)), layer=layer_wg)
 
     # top trench
     ymin0 = width / 2
@@ -232,52 +214,84 @@ def taper_strip_to_ridge_trenches(
     x = [0, length, length, 0]
     ytt = [ymin0, yminL, ymaxL, ymax0]
     ytb = [-ymin0, -yminL, -ymaxL, -ymax0]
-    c.add_polygon((x, ytt), layer=trench_layer)
-    c.add_polygon((x, ytb), layer=trench_layer)
+    c.add_polygon(list(zip(x, ytt)), layer=trench_layer)
+    c.add_polygon(list(zip(x, ytb)), layer=trench_layer)
 
     c.add_port(name="o1", center=(0, 0), width=width, orientation=180, layer=layer_wg)
     c.add_port(
         name="o2", center=(length, 0), width=width, orientation=0, layer=layer_wg
     )
-
     return c
 
 
-taper_strip_to_slab150 = gf.partial(taper_strip_to_ridge, layer_slab="SLAB150")
+taper_strip_to_slab150 = partial(taper_strip_to_ridge, layer_slab="SLAB150")
 
-# taper StripCband to NitrideCband
-taper_sc_nc = gf.partial(
-    taper_strip_to_ridge,
-    layer_wg="WG",
-    layer_slab="WGN",
-    length=20.0,
-    width1=0.5,
-    width2=0.15,
-    w_slab1=0.15,
-    w_slab2=1.0,
+
+@gf.cell
+def taper_sc_nc(
+    width1: float = 0.5,
+    width2: float = 1,
+    length: float = 20,
+    layer_wg: LayerSpec = "WG",
+    layer_nitride: LayerSpec = "WGN",
+    width_tip_nitride: float = 0.15,
+    width_tip_silicon: float = 0.15,
+    cross_section: CrossSectionSpec = "strip",
+    **kwargs: Any,
+) -> Component:
+    """Taper from strip to nitride.
+
+    Args:
+        width1: strip width.
+        width2: nitride width.
+        length: taper length.
+        layer_wg: strip layer.
+        layer_nitride: nitride layer.
+        width_tip_nitride: tip width for nitride.
+        width_tip_silicon: tip width for strip.
+        cross_section: cross_section specification.
+        kwargs: cross_section settings.
+    """
+    return taper_strip_to_ridge(
+        layer_wg=layer_wg,
+        layer_slab=layer_nitride,
+        length=length,
+        width1=width1,
+        width2=width_tip_nitride,
+        w_slab1=width_tip_silicon,
+        w_slab2=width2,
+        use_slab_port=True,
+        cross_section=cross_section,
+        **kwargs,
+    )
+
+
+def taper_nc_sc(
+    width1: float = 1, width2: float = 0.5, length: float = 20, **kwargs: Any
+) -> Component:
+    return taper_sc_nc(width2=width1, width1=width2, length=length, **kwargs)
+
+
+taper_electrical = partial(
+    taper,
+    port_types=("electrical", "electrical"),
+    port_names=("e1", "e2"),
+    cross_section="metal_routing",
 )
 
 
 if __name__ == "__main__":
-    c = gf.grid(
-        [
-            taper_sc_nc(
-                length=length, info=dict(doe="taper_length", taper_length=length)
-            )
-            for length in [1, 2, 3]
-        ]
-    )
-    c.write_gds_with_metadata("extra/tapers.gds")
-
-    # c = taper(width2=1)
+    c = taper()
+    # c = gf.grid([taper_nc_sc(), taper_sc_nc()])
+    # c = taper(cross_section="rib", width2=5, port_types="optical")
+    # c = taper_strip_to_ridge_trenches()
     # c = taper_strip_to_ridge()
-    # print(c.get_optical_ports())
-    # c = taper_strip_to_ridge_trenches()
-    # c = taper()
-    # c = gf.components.taper_strip_to_ridge(width1=1, width2=2)
-    # c = gf.components.taper_strip_to_ridge(width1=1, width2=2)
-    # c = gf.components.extend_ports(c)
-    # c = taper_strip_to_ridge_trenches()
-    # c = taper()
+    # c = taper(width1=1.5, width2=1, cross_section="rib")
     # c = taper_sc_nc()
-    c.show(show_ports=True)
+    # c = taper(cross_section="rib")
+    # c = taper(length=1, width1=0.54, width2=10, cross_section="strip")
+    # c = taper_strip_to_ridge()
+    # c = taper(width1=0.5, width2=10, length=20)
+    # c = taper_sc_nc()
+    # c.pprint_ports()
+    c.show()
