@@ -1,4 +1,5 @@
 """Adiabatic tapers from CSV files."""
+
 from __future__ import annotations
 
 import pathlib
@@ -9,7 +10,7 @@ import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import CrossSectionSpec
+from gdsfactory.typings import CrossSectionSpec
 
 data = pathlib.Path(__file__).parent / "csv_data"
 
@@ -37,12 +38,12 @@ def taper_from_csv(
     c = gf.Component()
     c.add_polygon(list(zip(xs, ys)) + list(zip(xs, -ys))[::-1], layer=layer)
 
-    # for cladding_layer, cladding_offset in zip(x.cladding_layers, x.cladding_offsets):
-    #     ys_trench = ys + cladding_offset
-    #     c.add_polygon(
-    #         list(zip(xs, ys_trench)) + list(zip(xs, -ys_trench))[::-1],
-    #         layer=cladding_layer,
-    #     )
+    for section in x.sections[1:]:
+        ys_trench = ys + section.width
+        c.add_polygon(
+            list(zip(xs, ys_trench)) + list(zip(xs, -ys_trench))[::-1],
+            layer=section.layer,
+        )
 
     c.add_port(
         name="o1",
@@ -60,10 +61,7 @@ def taper_from_csv(
         layer=layer,
         cross_section=x,
     )
-    if x.add_bbox:
-        c = x.add_bbox(c)
-    if x.add_pins:
-        c = x.add_pins(c)
+    x.add_bbox(c)
     return c
 
 
@@ -77,6 +75,6 @@ taper_w12_l200 = partial(taper_from_csv, filepath=data / "taper_strip_0p5_12_200
 
 if __name__ == "__main__":
     # c = taper_0p5_to_3_l36()
-    c = taper_w10_l100()
+    c = taper_w10_l100(cross_section="rib")
     # c = taper_w11_l200()
-    c.show(show_ports=True)
+    c.show()
