@@ -4,7 +4,7 @@ import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.path import transition_exponential
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
@@ -42,6 +42,7 @@ def taper_parabolic(
 
 
 if __name__ == "__main__":
-    c = taper_parabolic(width2=6, length=40, exp=0.6)
+    # c = taper_parabolic(width2=6, length=40, exp=0.6)
     c = taper_parabolic()
-    c.show(show_ports=True)
+    print(c.name)
+    c.show()
