@@ -1,14 +1,13 @@
 from __future__ import annotations
 
-from typing import Tuple
-
+import kfactory as kf
 import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.text_rectangular import text_rectangular
 from gdsfactory.constants import _glyph, _indent, _width
-from gdsfactory.types import Coordinate, LayerSpec
+from gdsfactory.typings import Coordinate, LayerSpec, LayerSpecs
 
 
 @gf.cell
@@ -43,32 +42,35 @@ def text(
                 for poly in _glyph[ascii_val]:
                     xpts = np.array(poly)[:, 0] * scaling
                     ypts = np.array(poly)[:, 1] * scaling
-                    label.add_polygon([xpts + xoffset, ypts + yoffset], layer=layer)
+                    label.add_polygon(
+                        list(zip(xpts + xoffset, ypts + yoffset)), layer=layer
+                    )
                 xoffset += (_width[ascii_val] + _indent[ascii_val]) * scaling
             else:
                 raise ValueError(f"No character with ascii value {ascii_val!r}")
-        ref = t.add_ref(label)
-        t.absorb(ref)
+        t.add_ref(label)
         yoffset -= 1500 * scaling
         xoffset = position[0]
     justify = justify.lower()
-    for label in t.references:
+    for label in t.insts:
         if justify == "left":
             pass
         elif justify == "right":
-            label.xmax = position[0]
+            label.dxmax = position[0]
         elif justify == "center":
-            label.move(origin=label.center, destination=position, axis="x")
+            xmin = position[0] - label.dxsize / 2
+            label.dxmin = xmin
         else:
             raise ValueError(
                 f"justify = {justify!r} not in ('center', 'right', 'left')"
             )
+    t.flatten()
     return t
 
 
 @gf.cell
 def text_lines(
-    text: Tuple[str, ...] = ("Chip", "01"),
+    text: tuple[str, ...] = ("Chip", "01"),
     size: float = 0.4,
     layer: LayerSpec = "WG",
 ) -> Component:
@@ -84,20 +86,53 @@ def text_lines(
     for i, texti in enumerate(text):
         t = text_rectangular(text=texti, size=size, layer=layer)
         tref = c.add_ref(t)
-        tref.movey(-6 * size * (i + 1))
+        tref.dmovey(-6 * size * (i + 1))
+    return c
+
+
+@gf.cell
+def text_klayout(
+    text: str = "a",
+    layer: LayerSpec = "WG",
+    layers: LayerSpecs | None = None,
+    bbox_layers: LayerSpecs | None = None,
+) -> Component:
+    """Returns a text component.
+
+    Args:
+        text: string.
+        layer: text layer.
+        layers: layers for the text.
+        bbox_layers: layers for the text bounding box.
+    """
+    c = gf.Component()
+    gen = kf.kdb.TextGenerator.default_generator()
+
+    layers = layers or [layer]
+
+    for layer in layers:
+        layer = gf.get_layer(layer)
+        reg = gen.text(text, kf.kcl.dbu)
+        c.shapes(layer).insert(reg)
+
+    for layer in bbox_layers or []:
+        layer = gf.get_layer(layer)
+        c.shapes(layer).insert(reg.bbox())
     return c
 
 
 if __name__ == "__main__":
     # c1 = gf.components.text("hello", size=10, layer=(1, 0))
-    c2 = gf.components.text("10.0")
-    # c = text(
-    #     text=".[,ABCDEFGHIKKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789:/",
-    #     size=4.0,
-    #     justify="right",
-    #     position=(120.5, 3),
-    # )
-    # c = text_lines(text=["a", "b"], size=10)
-    # c = text_lines()
-    c2.show(show_ports=True)
+    # c2 = gf.components.text("10.0")
+    c = text_klayout(
+        text=".[,ABCDEFGHIKKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789:/",
+        # size=4.0,
+        # justify="center",
+        bbox_layers=("M3",),
+        # position=(0, 0),
+    )
+    # c = text_lines(text=("a", "b"), size=10)
+    # c = logo()
+    # c2.show( )
     # c.plot()
+    c.show()
