@@ -1,13 +1,14 @@
 from __future__ import annotations
 
 from functools import partial
+from typing import Any
 
-from gdsfactory.cell import cell
+import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
-@cell
+@gf.cell
 def triangle(
     x: float = 10,
     xtop: float = 0,
@@ -43,12 +44,13 @@ def triangle(
     return c
 
 
-@cell
-def triangle2(spacing: float = 3, **kwargs):
+@gf.cell
+def triangle2(spacing: float = 3, **kwargs: Any) -> Component:
     r"""Return 2 triangles (bot, top).
 
     Args:
         spacing: between top and bottom.
+        kwargs: triangle arguments.
 
     Keyword Args:
         x: base xsize.
@@ -79,16 +81,19 @@ def triangle2(spacing: float = 3, **kwargs):
     t = triangle(**kwargs)
     tt = c << t
     tb = c << t
-    tb.mirror()
-    tb.rotate(180)
-    tb.ymax = tt.ymin - spacing
+    tb.dmirror()
+    tb.drotate(180)
+    tb.dymax = tt.dymin - spacing
     return c
 
 
-@cell
-def triangle4(**kwargs):
+@gf.cell
+def triangle4(**kwargs: Any) -> Component:
     r"""Return 4 triangles.
 
+    Args:
+        kwargs: triangle arguments.
+
     Keyword Args:
         x: base xsize.
         xtop: top xsize.
@@ -118,8 +123,8 @@ def triangle4(**kwargs):
     t = triangle2(**kwargs)
     t1 = c << t
     t2 = c << t
-    t2.mirror()
-    t2.xmax = t1.xmin
+    t2.dmirror()
+    t2.dxmax = t1.dxmin
     return c
 
 
@@ -130,4 +135,4 @@ triangle4_thin = partial(triangle2, xtop=0.2, x=2, y=5)
 if __name__ == "__main__":
     # cc = triangle(xtop=5, ybot=5)
     cc = triangle4_thin(spacing=0)
-    cc.show(show_ports=True)
+    cc.show()
