@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Tuple
+from typing import Any
 
 from numpy import floor
 
@@ -9,7 +9,7 @@ from gdsfactory.components.compass import compass
 from gdsfactory.components.via import via1
 from gdsfactory.cross_section import metal2, metal3
 from gdsfactory.port import select_ports
-from gdsfactory.types import ComponentSpec, MultiCrossSectionAngleSpec
+from gdsfactory.typings import ComponentSpec, MultiCrossSectionAngleSpec
 
 
 @gf.cell
@@ -18,9 +18,9 @@ def via_corner(
         (metal2, (0, 180)),
         (metal3, (90, 270)),
     ),
-    vias: Tuple[ComponentSpec] = (via1,),
-    layers_labels: Tuple[str, ...] = ("m2", "m3"),
-    **kwargs,
+    vias: tuple[ComponentSpec] = (via1,),
+    layers_labels: tuple[str, ...] = ("m2", "m3"),
+    **kwargs: Any,
 ) -> gf.Component:
     """Returns Corner via.
 
@@ -47,11 +47,14 @@ def via_corner(
     b = min_height / 2
 
     c = gf.Component()
-    c.height = max_height
     c.info["size"] = (float(max_width), float(max_height))
     c.info["length"] = max(max_width, max_height)
+
+    port_type = "electrical"
     for i, layer in enumerate(layers):
-        ref = c << compass(size=(widths[i], heights[i]), layer=layer)
+        ref = c << compass(
+            size=(widths[i], heights[i]), layer=layer, port_type=port_type
+        )
 
         if layer in layers_ports:
             orientations = port_orientations[i]
@@ -67,17 +70,30 @@ def via_corner(
 
     for via in vias:
         via = gf.get_component(via)
+        if "xsize" not in via.info:
+            raise ValueError(f"Via {via.name!r} does not have xsize in info")
 
-        w, h = via.info["size"]
+        if "ysize" not in via.info:
+            raise ValueError(f"Via {via.name!r} does not have ysize in info")
+
+        if "enclosure" not in via.info:
+            raise ValueError(f"Via {via.name!r} does not have enclosure in info")
+
+        if "pitch" not in via.info:
+            raise ValueError(f"Via {via.name!r} does not have pitch in info")
+
+        w = via.info["xsize"]
+        h = via.info["ysize"]
         g = via.info["enclosure"]
-        pitch_x, pitch_y = via.info["spacing"]
+        pitch = via.info["pitch"]
+        pitch_x = pitch_y = pitch
 
         nb_vias_x = (min_width - w - 2 * g) / pitch_x + 1
         nb_vias_y = (min_height - h - 2 * g) / pitch_y + 1
 
         nb_vias_x = int(floor(nb_vias_x)) or 1
         nb_vias_y = int(floor(nb_vias_y)) or 1
-        ref = c.add_array(
+        ref = c.add_ref(
             via, columns=nb_vias_x, rows=nb_vias_y, spacing=(pitch_x, pitch_y)
         )
 
@@ -85,12 +101,10 @@ def via_corner(
         ch = (min_height - (nb_vias_y - 1) * pitch_y - h) / 2
         x0 = -a + cw + w / 2
         y0 = -b + ch + h / 2
-        ref.move((x0, y0))
+        ref.dmove((x0, y0))
     return c
 
 
 if __name__ == "__main__":
-    # v = via_corner(cross_section=[(metal2, (0, 180)), (metal3, (90, 270))])
-    v = via_corner()
-    # v.plot()
-    v.show()
+    c = via_corner()
+    c.show()
