@@ -1,20 +1,21 @@
 """Define names, clean values for names."""
+
 from __future__ import annotations
 
 import hashlib
+import re
 from typing import Any
 
-import pydantic
-
-MAX_NAME_LENGTH = 32
+from gdsfactory.config import CONF
 
 
-@pydantic.validate_arguments
-def get_name_short(name: str, max_name_length=MAX_NAME_LENGTH) -> str:
+def get_name_short(
+    name: str, max_cellname_length: int = CONF.max_cellname_length
+) -> str:
     """Returns a short name."""
-    if len(name) > max_name_length:
+    if len(name) > max_cellname_length:
         name_hash = hashlib.md5(name.encode()).hexdigest()[:8]
-        name = f"{name[:(max_name_length - 9)]}_{name_hash}"
+        name = f"{name[: (max_cellname_length - 9)]}_{name_hash}"
     return name
 
 
@@ -28,10 +29,10 @@ def join_first_letters(name: str) -> str:
 
 
 # replace function_name prefix for some components
-component_type_to_name = dict(phidl="phidl")
+component_type_to_name = {"phidl": "phidl"}
 
 
-def get_component_name(component_type: str, *args, **kwargs) -> str:
+def get_component_name(component_type: str, *args: Any, **kwargs: Any) -> str:
     """Returns concatenated kwargs Key_Value."""
     name = component_type + "_".join([clean_value(a) for a in args])
     for k, v in component_type_to_name.items():
@@ -41,7 +42,7 @@ def get_component_name(component_type: str, *args, **kwargs) -> str:
     return name
 
 
-def dict2hash(**kwargs) -> str:
+def dict2hash(**kwargs: Any) -> str:
     ignore_from_name = kwargs.pop("ignore_from_name", [])
     h = hashlib.sha256()
     for key in sorted(kwargs):
@@ -52,10 +53,10 @@ def dict2hash(**kwargs) -> str:
     return h.hexdigest()
 
 
-def dict2name(prefix: str = "", **kwargs) -> str:
+def dict2name(prefix: str = "", **kwargs: Any) -> str:
     """Returns name from a dict."""
     ignore_from_name = kwargs.pop("ignore_from_name", [])
-    kv = []
+    kv: list[str] = []
     kwargs = kwargs.copy()
     kwargs.pop("layer_to_inclusion", "")
 
@@ -69,7 +70,7 @@ def dict2name(prefix: str = "", **kwargs) -> str:
     return clean_name(label)
 
 
-def assert_first_letters_are_different(**kwargs):
+def assert_first_letters_are_different(**kwargs: Any) -> None:
     """Assert that the first letters for each key are different.
 
     Avoids different args that start with the same first letter getting
@@ -85,7 +86,7 @@ def assert_first_letters_are_different(**kwargs):
         )
 
 
-def print_first_letters_warning(**kwargs) -> None:
+def print_first_letters_warning(**kwargs: Any) -> None:
     """Prints kwargs that have same cell."""
     first_letters = [join_first_letters(k) for k in kwargs]
     if len(set(first_letters)) != len(first_letters):
@@ -97,15 +98,36 @@ def print_first_letters_warning(**kwargs) -> None:
         )
 
 
-def clean_name(name: str, remove_dots: bool = False) -> str:
+def clean_name(
+    name: str,
+    remove_dots: bool = False,
+    allowed_characters: list[str] | None = None,
+) -> str:
     """Return a string with correct characters for a cell name.
 
-    [a-zA-Z0-9]
+    By default, the characters [a-zA-Z0-9] are allowed.
 
-    FIXME: only a few characters are currently replaced.
-        This function has been updated only on case-by-case basis
+    Args:
+        name (str): The name to clean.
+        remove_dots (bool, optional): Whether to remove dots from the name. Defaults to False.
+        allowed_characters (list[str], optional): List of additional allowed characters. Defaults to an empty list.
 
+    Returns:
+        str: The cleaned name.
     """
+    # Default allowed characters, including underscore
+    allowed = r"a-zA-Z0-9_"
+
+    allowed_characters = allowed_characters or []
+
+    # Add additional allowed characters
+    for char in allowed_characters:
+        allowed += re.escape(char)
+
+    # Pattern for characters to be replaced
+    pattern = f"[^{allowed}]"
+
+    # Replacements map
     replace_map = {
         " ": "_",
         "!": "",
@@ -131,9 +153,12 @@ def clean_name(name: str, remove_dots: bool = False) -> str:
 
     if remove_dots:
         replace_map["."] = ""
-    for k, v in list(replace_map.items()):
-        name = name.replace(k, v)
-    return name
+
+    # Replace characters using the replace_map
+    def replace_match(match: re.Match[str]) -> str:
+        return replace_map.get(match.group(0), "")
+
+    return re.sub(pattern, replace_match, name)
 
 
 def clean_value(value: Any) -> str:
@@ -154,20 +179,18 @@ def test_clean_name() -> None:
 
 
 if __name__ == "__main__":
-    # test_cell()
     # testclean_value_json()
-    # import gdsfactory as gf
+    import gdsfactory as gf
 
     # print(clean_value(gf.components.straight))
     # c = gf.components.straight(polarization="TMeraer")
     # print(c.settings["polarization"])
     # print(clean_value(11.001))
-    # c = gf.components.straight(length=10)
-    # c = gf.components.straight(length=10)
+    c = gf.components.straight(length=10)  # type: ignore
 
     # print(c.name)
     # print(c)
-    # c.show(show_ports=True)
+    # c.show( )
 
     # print(clean_name("Waveguidenol1_(:_=_2852"))
     # print(clean_value(1.2))
@@ -176,13 +199,13 @@ if __name__ == "__main__":
     # print(clean_value([1, 2.4324324, 3]))
     # print(clean_value((0.001, 24)))
     # print(clean_value({"a": 1, "b": 2}))
-    import gdsfactory as gf
+    # import gdsfactory as gf
 
-    d = {
-        "X": gf.components.crossing45(port_spacing=40.0),
-        "-": gf.components.compensation_path(
-            crossing45=gf.components.crossing45(port_spacing=40.0)
-        ),
-    }
-    d2 = clean_value(d)
-    print(d2)
+    # d = {
+    #     "X": gf.components.crossing45(port_spacing=40.0),
+    #     "-": gf.components.compensation_path(
+    #         crossing45=gf.components.crossing45(port_spacing=40.0)
+    #     ),
+    # }
+    # d2 = clean_value(d)
+    # print(d2)
