@@ -1,30 +1,29 @@
 """pack a list of components into as few components as possible.
 
-based on phidl.geometry.
-
+Adapted from PHIDL https://github.com/amccaugh/phidl/ by Adam McCaughan
 """
 
 from __future__ import annotations
 
 import warnings
-from typing import Any, Dict, List, Optional, Tuple
+from collections.abc import Sequence
+from typing import Any
 
 import numpy as np
-from pydantic import validate_arguments
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.name import get_name_short
-from gdsfactory.types import Anchor, ComponentSpec, Float2, Number
+from gdsfactory.snap import snap_to_grid
+from gdsfactory.typings import Anchor, ComponentSpec, Float2, Number, Size
 
 
 def _pack_single_bin(
-    rect_dict: Dict[int, Tuple[Number, Number]],
-    aspect_ratio: Tuple[Number, Number],
-    max_size: Tuple[float, float],
+    rect_dict: dict[int, tuple[Number, Number]],
+    aspect_ratio: tuple[Number, Number],
+    max_size: Size,
     sort_by_area: bool,
     density: float,
-) -> Tuple[Dict[int, Tuple[Number, Number, Number, Number]], Dict[Any, Any]]:
+) -> tuple[dict[int, tuple[Number, Number, Number, Number]], dict[Any, Any]]:
     """Packs a dict of rectangles {id:(w,h)} and tries to.
 
     Pack it into a bin as small as possible with aspect ratio `aspect_ratio`
@@ -39,8 +38,7 @@ def _pack_single_bin(
         density: of packing, closer to 1 packs tighter (more compute heavy).
 
     Returns:
-        packed rectangles dict {id:(x,y,w,h)}.
-        dict of remaining unpacked rectangles.
+        packed rectangles dict {id:(x,y,w,h)}. dict of remaining unpacked rectangles.
 
     """
     import rectpack
@@ -90,28 +88,29 @@ def _pack_single_bin(
     return packed_rect_dict, unpacked_rect_dict
 
 
-@validate_arguments
 def pack(
-    component_list: List[ComponentSpec],
+    component_list: Sequence[ComponentSpec],
     spacing: float = 10.0,
     aspect_ratio: Float2 = (1.0, 1.0),
-    max_size: Tuple[Optional[float], Optional[float]] = (None, None),
+    max_size: tuple[float | None, float | None] = (None, None),
     sort_by_area: bool = True,
     density: float = 1.1,
     precision: float = 1e-2,
-    text: Optional[ComponentSpec] = None,
+    text: ComponentSpec | None = None,
     text_prefix: str = "",
-    text_offsets: Tuple[Float2, ...] = ((0, 0),),
-    text_anchors: Tuple[Anchor, ...] = ("cc",),
-    name_prefix: Optional[str] = None,
+    text_mirror: bool = False,
+    text_rotation: int = 0,
+    text_offsets: tuple[Float2, ...] = ((0, 0),),
+    text_anchors: tuple[Anchor, ...] = ("cc",),
+    name_prefix: str | None = None,
     rotation: int = 0,
     h_mirror: bool = False,
     v_mirror: bool = False,
-) -> List[Component]:
+    add_ports_prefix: bool = True,
+    add_ports_suffix: bool = False,
+) -> list[Component]:
     """Pack a list of components into as few Components as possible.
 
-    based on phidl.geometry
-
     Args:
         component_list: list or tuple.
         spacing: Minimum distance between adjacent shapes.
@@ -122,25 +121,30 @@ def pack(
         precision: Desired precision for rounding vertex coordinates.
         text: Optional function to add text labels.
         text_prefix: for labels. For example. 'A' will produce 'A1', 'A2', ...
+        text_mirror: if True mirrors text.
+        text_rotation: Optional text rotation.
         text_offsets: relative to component size info anchor. Defaults to center.
         text_anchors: relative to component (ce cw nc ne nw sc se sw center cc).
-        name_prefix: for each packed component (avoids the Unnamed cells warning).
-            Note that the suffix contains a uuid so the name will not be deterministic.
-        rotation: for each component in degrees.
+        name_prefix: for each packed component (avoids the Unnamed cells warning). \
+                Note that the suffix contains a uuid so the name will not be deterministic.
+        rotation: optional component rotation in degrees.
         h_mirror: horizontal mirror in y axis (x, 1) (1, 0). This is the most common.
         v_mirror: vertical mirror using x axis (1, y) (0, y).
+        add_ports_prefix: adds port names with prefix.
+        add_ports_suffix: adds port names with suffix.
 
     .. plot::
         :include-source:
 
         import gdsfactory as gf
+        from functools import partial
 
         components = [gf.components.triangle(x=i) for i in range(1, 10)]
         c = gf.pack(
             components,
             spacing=20.0,
             max_size=(100, 100),
-            text=gf.partial(gf.components.text, justify="center"),
+            text=partial(gf.components.text, justify="center"),
             text_prefix="R",
             name_prefix="demo",
             text_anchors=["nc"],
@@ -166,13 +170,14 @@ def pack(
     # Convert Components to rectangles
     rect_dict = {}
     for n, D in enumerate(component_list):
-        w, h = (D.size + spacing) / precision
+        size = np.array([D.dxsize, D.dysize])
+        w, h = (size + spacing) / precision
         w, h = int(w), int(h)
         if (w > max_size[0]) or (h > max_size[1]):
             raise ValueError(
                 f"pack() failed because Component {D.name!r} has x or y "
                 "dimension larger than `max_size` and cannot be packed.\n"
-                f"size = {w*precision, h*precision}, max_size = {max_size*precision}"
+                f"size = {(w * precision, h * precision)}, max_size = {max_size * precision}"
             )
         rect_dict[n] = (w, h)
 
@@ -189,30 +194,44 @@ def pack(
 
     components_packed_list = []
     index = 0
-    for i, rect_dict in enumerate(packed_list):
-        name = get_name_short(f"{name_prefix or 'pack'}_{i}")
-        packed = Component(name, with_uuid=True)
-        packed.info["components"] = {}
+    for rect_dict in packed_list:
+        packed = Component()
         for n, rect in rect_dict.items():
             x, y, w, h = rect
             xcenter = x + w / 2 + spacing / 2
             ycenter = y + h / 2 + spacing / 2
             component = component_list[n]
-            d = component.ref(rotation=rotation, h_mirror=h_mirror, v_mirror=v_mirror)
-            packed.add(d)
+            d = (
+                packed << component
+            )  # ref(rotation=rotation, h_mirror=h_mirror, v_mirror=v_mirror)
+            if rotation:
+                d.drotate(rotation)
+            if h_mirror:
+                d.mirror_x()
+            if v_mirror:
+                d.mirror_y()
+            d.dcenter = tuple(snap_to_grid((xcenter * precision, ycenter * precision)))
+            if add_ports_prefix:
+                packed.add_ports(d.ports, prefix=f"{index}_")
+            elif add_ports_suffix:
+                packed.add_ports(d.ports, suffix=f"_{index}")
+            else:
+                try:
+                    packed.add_ports(d.ports)
+                except ValueError:
+                    packed.add_ports(d.ports, suffix=f"_{index}")
 
-            if hasattr(component, "settings"):
-                packed.info["components"][component.name] = dict(component.settings)
-            d.center = (xcenter * precision, ycenter * precision)
-
-            packed.add_ports(d.ports, prefix=f"{component.name}_{index}_")
             index += 1
 
             if text:
                 for text_offset, text_anchor in zip(text_offsets, text_anchors):
                     label = packed << text(f"{text_prefix}{index}")
-                    label.move(
-                        np.array(text_offset) + getattr(d.size_info, text_anchor)
+                    if text_mirror:
+                        label.dmirror()
+                    if text_rotation:
+                        label.drotate(text_rotation)
+                    label.dmove(
+                        np.array(text_offset) + getattr(d.dsize_info, text_anchor)
                     )
 
         components_packed_list.append(packed)
@@ -224,13 +243,14 @@ def pack(
     return components_packed_list
 
 
-def test_pack() -> Component:
-    """Test packing function."""
+if __name__ == "__main__":
+    # test_pack()
     component_list = [
-        gf.components.ellipse(radii=tuple(np.random.rand(2) * n + 2)) for n in range(2)
+        gf.components.ellipse(radii=tuple(np.random.rand(2) * n + 2)) for n in range(10)
     ]
     component_list += [
-        gf.components.rectangle(size=tuple(np.random.rand(2) * n + 2)) for n in range(2)
+        gf.components.rectangle(size=tuple(np.random.rand(2) * n + 2))
+        for n in range(10)
     ]
 
     components_packed_list = pack(
@@ -242,52 +262,18 @@ def test_pack() -> Component:
         sort_by_area=True,  # Pre-sorts the shapes by area
     )
     c = components_packed_list[0]  # Only one bin was created, so we plot that
-    assert len(c.get_dependencies()) == 4
-    return c
 
-
-def test_pack_with_settings() -> Component:
-    """Test packing function with custom settings."""
-    component_list = [
-        gf.components.rectangle(size=(i, i), port_type=None) for i in range(1, 10)
-    ]
-    component_list += [
-        gf.components.rectangle(size=(i, i), port_type=None) for i in range(1, 10)
-    ]
-
-    components_packed_list = pack(
-        component_list,  # Must be a list or tuple of Components
-        spacing=1.25,  # Minimum distance between adjacent shapes
-        aspect_ratio=(2, 1),  # (width, height) ratio of the rectangular bin
-        # max_size=(None, None),  # Limits the size into which the shapes will be packed
-        max_size=(20, 20),  # Limits the size into which the shapes will be packed
-        density=1.05,  # Values closer to 1 pack tighter but require more computation
-        sort_by_area=True,  # Pre-sorts the shapes by area
-        precision=1e-3,
-    )
-    return components_packed_list[0]
-
-
-if __name__ == "__main__":
-    # test_pack()
-
-    # c = test_pack_with_settings()
-    # c = test_pack()
-    # c.show(show_ports=True)
-    # c.pprint()
-    # c.write_gds_with_metadata("mask.gds")
-
-    p = pack(
-        [gf.components.straight(length=i) for i in [1, 1]],
-        spacing=20.0,
-        max_size=(100, 100),
-        text=gf.partial(gf.components.text, justify="center"),
-        text_prefix="R",
-        name_prefix="demo",
-        text_anchors=["nc"],
-        text_offsets=[(-10, 0)],
-        v_mirror=True,
-    )
-    c = p[0]
-    print(c.name)
-    c.show(show_ports=True)
+    # p = pack(
+    #     [gf.components.straight(length=i) for i in [1, 1]],
+    #     spacing=20.0,
+    #     max_size=(100, 100),
+    #     text=partial(gf.components.text, justify="center"),
+    #     text_prefix="R",
+    #     name_prefix="demo",
+    #     text_anchors=["nc"],
+    #     text_offsets=[(-10, 0)],
+    #     text_mirror=True,
+    #     v_mirror=True,
+    # )
+    # c = p[0]
+    c.show()
