@@ -1,15 +1,18 @@
 from __future__ import annotations
 
 import pathlib
-from typing import Tuple
+from collections.abc import Sequence
+from typing import TYPE_CHECKING
 
+from gdsfactory import logger
 from gdsfactory.component import Component
-from gdsfactory.config import logger
 from gdsfactory.read.import_gds import import_gds
-from gdsfactory.types import ComponentOrPath, PathType
+
+if TYPE_CHECKING:
+    from gdsfactory.typings import ComponentOrPath, PathType
 
 
-def from_gdspaths(cells: Tuple[ComponentOrPath, ...]) -> Component:
+def from_gdspaths(cells: "Sequence[ComponentOrPath]") -> Component:
     """Combine all GDS files or gf.components into a gf.component.
 
     Args:
@@ -19,17 +22,17 @@ def from_gdspaths(cells: Tuple[ComponentOrPath, ...]) -> Component:
     component = Component("merged")
 
     for c in cells:
-        if isinstance(c, (str, pathlib.Path)):
+        if isinstance(c, str | pathlib.Path):
             logger.info(f"Loading {c!r}")
             c = import_gds(c)
 
         assert isinstance(c, Component)
-        component << c
+        _ = component << c
 
     return component
 
 
-def from_gdsdir(dirpath: PathType) -> Component:
+def from_gdsdir(dirpath: "PathType") -> Component:
     """Merges GDS cells from a directory into a single Component."""
     dirpath = pathlib.Path(dirpath)
     assert dirpath.exists(), f"{dirpath} does not exist"
@@ -42,4 +45,4 @@ if __name__ == "__main__":
     # c = gdspaths([gf.components.straight(), gf.components.bend_circular()])
     # leave these two lines to end up tests showing the diff
     c = from_gdspaths(diff_path.glob("*.gds"))
-    c.show(show_ports=True)
+    c.show()
