@@ -1,15 +1,18 @@
 """Read component from a numpy.ndarray."""
+
 from __future__ import annotations
 
-from typing import Tuple
+from typing import Any
 
 import numpy as np
+import numpy.typing as npt
 
+import gdsfactory as gf
+from gdsfactory.boolean import boolean
 from gdsfactory.component import Component
-from gdsfactory.geometry.boolean import boolean
 
 
-def compute_area_signed(pr) -> float:
+def compute_area_signed(pr: npt.NDArray[np.floating[Any]]) -> float:
     """Return the signed area enclosed by a ring using the linear time.
 
     algorithm at http://www.cgafaq.info/wiki/Polygon_Area. A value >= 0
@@ -23,10 +26,11 @@ def compute_area_signed(pr) -> float:
 
 
 def from_np(
-    ndarray: np.ndarray,
+    ndarray: npt.NDArray[np.floating[Any]],
     nm_per_pixel: int = 20,
-    layer: Tuple[int, int] = (1, 0),
+    layer: tuple[int, int] = (1, 0),
     threshold: float = 0.99,
+    invert: bool = True,
 ) -> Component:
     """Returns Component from a np.ndarray.
 
@@ -37,7 +41,7 @@ def from_np(
         nm_per_pixel: scale_factor.
         layer: layer tuple to output gds.
         threshold: value along which to find contours in the array.
-
+        invert: invert the mask.
     """
     from skimage import measure
 
@@ -58,16 +62,49 @@ def from_np(
         else:
             d.add_polygon(points, layer=layer)
 
-    c = boolean(c, d, operation="not", layer=layer)
-    return c
+    return boolean(c, d, operation="not", layer=layer) if invert else d
+
+
+@gf.cell
+def from_image(image_path: str, **kwargs: Any) -> Component:
+    """Returns Component from a png image.
+
+    Args:
+        image_path: png file path.
+        kwargs: for from_np.
+
+    Keyword Args:
+        nm_per_pixel: scale_factor.
+        layer: layer tuple to output gds.
+        threshold: value along which to find contours in the array.
+
+    """
+    import matplotlib.pyplot as plt
+
+    # Load the image using matplotlib
+    img = plt.imread(image_path)
+
+    if len(img.shape) == 3:
+        img = 0.2989 * img[:, :, 0] + 0.5870 * img[:, :, 1] + 0.1140 * img[:, :, 2]
+
+    # Convert image to numpy array (in fact, plt.imread already returns a numpy array)
+    img_array = np.array(img)
+
+    return from_np(img_array, **kwargs)
 
 
 if __name__ == "__main__":
-    import gdsfactory as gf
+    from gdsfactory.config import PATH
 
-    c1 = gf.components.straight()
-    c1 = gf.components.bend_circular()
-    c1 = gf.components.ring_single()
-    img = gf.export.to_np(c1)
-    c2 = from_np(img)
-    c2.show()
+    # import gdsfactory as gf
+    # c1 = gf.components.straight()
+    # c1 = gf.components.bend_circular()
+    # c1 = gf.components.ring_single()
+    # img = c1.to_np()
+    # c2 = from_np(img)
+    # c2.show()
+
+    c = from_image(
+        PATH.module / "samples" / "images" / "logo.png", nm_per_pixel=500, invert=True
+    )
+    c.show()
