@@ -1,24 +1,24 @@
 from __future__ import annotations
 
-from typing import Callable, Optional
+from typing import Any
 
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.bend_s import bend_s
 from gdsfactory.components.straight import straight
 from gdsfactory.port import select_ports_optical
-from gdsfactory.types import ComponentSpec, CrossSectionSpec
+from gdsfactory.typings import ComponentSpec, CrossSectionSpec, PortsFactory
 
 
 @gf.cell
 def fanout2x2(
     component: ComponentSpec = straight,
     port_spacing: float = 20.0,
-    bend_length: Optional[float] = None,
+    bend_length: float | None = None,
     npoints: int = 101,
-    select_ports: Callable = select_ports_optical,
+    select_ports: PortsFactory = select_ports_optical,
     cross_section: CrossSectionSpec = "strip",
-    **kwargs,
+    **kwargs: Any,
 ) -> Component:
     """Returns component with Sbend fanout routes.
 
@@ -46,7 +46,7 @@ def fanout2x2(
     component = gf.get_component(component)
     component.component = component
     ref = c << component
-    ref.movey(-ref.y)
+    ref.dmovey(-ref.dy)
 
     if bend_length is None:
         bend_length = port_spacing
@@ -54,33 +54,37 @@ def fanout2x2(
 
     y = port_spacing / 2.0
 
-    p_w0 = ref.ports["o1"].center
-    p_w1 = ref.ports["o2"].center
-    p_e1 = ref.ports["o3"].center
-    p_e0 = ref.ports["o4"].center
-    y0 = p_e1[1]
+    p_w0 = ref.ports["o1"]
+    p_w1 = ref.ports["o2"]
+    p_e1 = ref.ports["o3"]
+    p_e0 = ref.ports["o4"]
 
+    y0 = p_e1.dcenter[1]
     dy = y - y0
 
     x = gf.get_cross_section(cross_section, **kwargs)
-    bend = bend_s(size=(dx, dy), nb_points=npoints, cross_section=x)
+    bend = bend_s(size=(dx, dy), npoints=npoints, cross_section=x)
 
-    b_tr = bend.ref(port_id="o1", position=p_e1)
-    b_br = bend.ref(port_id="o1", position=p_e0, v_mirror=True)
-    b_tl = bend.ref(port_id="o1", position=p_w1, h_mirror=True)
-    b_bl = bend.ref(port_id="o1", position=p_w0, rotation=180)
+    b_tr = c << bend
+    b_br = c << bend
+    b_tl = c << bend
+    b_bl = c << bend
 
-    c.add([b_tr, b_br, b_tl, b_bl])
+    b_tr.connect(port="o1", other=p_e1)
+    b_br.connect(port="o1", other=p_e0, mirror=True)
+    b_tl.connect(port="o1", other=p_w1, mirror=True)
+    b_bl.connect(port="o1", other=p_w0)
 
     c.add_port("o1", port=b_bl.ports["o2"])
     c.add_port("o2", port=b_tl.ports["o2"])
     c.add_port("o3", port=b_tr.ports["o2"])
     c.add_port("o4", port=b_br.ports["o2"])
 
-    c.min_bend_radius = bend.info["min_bend_radius"]
+    c.info["min_bend_radius"] = bend.info["min_bend_radius"]
 
     optical_ports = select_ports(ref.ports)
-    for port_name in ref.ports.keys():
+    for port in ref.ports:
+        port_name = port.name
         if port_name not in optical_ports:
             c.add_port(port_name, port=ref.ports[port_name])
     c.copy_child_info(component)
@@ -92,6 +96,6 @@ if __name__ == "__main__":
     c = gf.components.nxn(west=2, east=2)
 
     cc = fanout2x2(component=c, port_spacing=20)
-    print(cc.ports["o3"].y - cc.ports["o4"].y)
+    # print(cc.ports["o3"].dy - cc.ports["o4"].dy)
     # print(cc.ports)
-    cc.show(show_ports=True)
+    cc.show()
