@@ -1,48 +1,50 @@
 from __future__ import annotations
 
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Literal
 
+import kfactory as kf
 import numpy as np
+from kfactory.routing.generic import ManhattanRoute
 
 import gdsfactory as gf
-from gdsfactory.component import Component, ComponentReference
+from gdsfactory.component import Component
 from gdsfactory.port import Port, flipped
-from gdsfactory.routing.get_route import get_route
-from gdsfactory.types import Route
+from gdsfactory.routing.route_single import route_single
 
 
 def sort_key_west_to_east(port: Port) -> float:
-    return port.x
+    return port.dx
 
 
 def sort_key_east_to_west(port: Port) -> float:
-    return -port.x
+    return -port.dx
 
 
 def sort_key_south_to_north(port: Port) -> float:
-    return port.y
+    return port.dy
 
 
 def sort_key_north_to_south(port: Port) -> float:
-    return -port.y
+    return -port.dy
 
 
 def route_ports_to_side(
-    ports: Union[Dict[str, Port], List[Port], Component, ComponentReference],
-    side: str = "north",
-    x: Optional[float] = None,
-    y: Optional[float] = None,
-    routing_func=get_route,
-    **kwargs,
-) -> Tuple[List[Route], List[Port]]:
+    component: Component,
+    ports: list[kf.Port] | Component | list[gf.Port] | None = None,
+    side: Literal["north", "east", "south", "west"] = "north",
+    x: float | None = None,
+    y: float | None = None,
+    **kwargs: Any,
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
     """Routes ports to a given side.
 
     Args:
+        component: component to route.
         ports: list/dict/Component/ComponentReference to route to a side.
         side: 'north', 'south', 'east' or 'west'.
         x: position to route ports for east/west. None, uses most east/west value.
         y: position to route ports for south/north. None, uses most north/south value.
-        routing_func: the routing function. By default uses `get_route`.
+        kwargs: additional arguments to pass to the routing function.
 
     Keyword Args:
       radius: in um.
@@ -80,14 +82,6 @@ def route_ports_to_side(
     if not ports:
         return [], []
 
-    # Accept list of ports, Component or dict of ports
-    if isinstance(ports, dict):
-        ports = list(ports.values())
-
-    elif isinstance(ports, (Component, ComponentReference)):
-        ports = list(ports.ports.values())
-
-    # Choose which
     if side in {"north", "south"}:
         func_route = route_ports_to_y
         xy = y if y is not None else side
@@ -97,45 +91,56 @@ def route_ports_to_side(
     else:
         raise ValueError(f"side = {side} not valid (north, south, west, east)")
 
-    return func_route(ports, xy, routing_func=routing_func, **kwargs)
+    ports = ports or component.ports
+    return func_route(component, ports, xy, side=side, **kwargs)
 
 
-def route_ports_to_north(list_ports, **kwargs):
+def route_ports_to_north(
+    list_ports: list[Port], **kwargs: Any
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
     return route_ports_to_side(list_ports, side="north", **kwargs)
 
 
-def route_ports_to_south(list_ports, **kwargs):
+def route_ports_to_south(
+    list_ports: list[Port], **kwargs: Any
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
     return route_ports_to_side(list_ports, side="south", **kwargs)
 
 
-def route_ports_to_west(list_ports, **kwargs):
+def route_ports_to_west(
+    list_ports: list[Port], **kwargs: Any
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
     return route_ports_to_side(list_ports, side="west", **kwargs)
 
 
-def route_ports_to_east(list_ports, **kwargs):
+def route_ports_to_east(
+    list_ports: list[Port], **kwargs: Any
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
     return route_ports_to_side(list_ports, side="east", **kwargs)
 
 
 def route_ports_to_x(
-    list_ports: List[Port],
-    x: Union[float, str] = "east",
+    component: Component,
+    list_ports: list[Port],
+    x: float | Literal["east", "west"] = "east",
     separation: float = 10.0,
     radius: float = 10.0,
     extend_bottom: float = 0.0,
     extend_top: float = 0.0,
     extension_length: float = 0.0,
-    y0_bottom: Optional[float] = None,
-    y0_top: Optional[float] = None,
-    routing_func: Callable = get_route,
+    y0_bottom: float | None = None,
+    y0_top: float | None = None,
     backward_port_side_split_index: int = 0,
     start_straight_length: float = 0.01,
-    dx_start: Optional[float] = None,
-    dy_start: Optional[float] = None,
-    **routing_func_args,
-) -> Tuple[List[Route], List[Port]]:
+    dx_start: float | None = None,
+    dy_start: float | None = None,
+    side: Literal["east", "west"] = "east",
+    **routing_func_args: Any,
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
     """Returns route to x.
 
     Args:
+        component: component to route.
         list_ports: reasonably well behaved list of ports.
            ports facing north ports are norther than any other ports
            ports facing south ports are souther ...
@@ -152,12 +157,14 @@ def route_ports_to_x(
         extension_length: in um.
         y0_bottom: in um.
         y0_top: in um.
-        routing_func: to route.
         backward_port_side_split_index: integer represents and index in the list of backwards ports (bottom to top)
-                all ports with an index strictly lower or equal are routed bottom
-            all ports with an index larger or equal are routed top
+            all ports with an index strictly lower or equal are routed bottom
+            all ports with an index larger or equal are routed top.
+        start_straight_length: in um.
         dx_start: override minimum starting x distance.
         dy_start: override minimum starting y distance.
+        side: "east" or "west".
+        routing_func_args: additional arguments to pass to the routing function.
 
     Returns:
         routes: list of routes
@@ -179,8 +186,8 @@ def route_ports_to_x(
     bx = epsilon + max(radius, dx_start) if dx_start else a
     by = epsilon + max(radius, dy_start) if dy_start else a
 
-    xs = [p.x for p in list_ports]
-    ys = [p.y for p in list_ports]
+    xs = [p.dx for p in list_ports]
+    ys = [p.dy for p in list_ports]
 
     if y0_bottom is None:
         y0_bottom = min(ys) - by
@@ -195,10 +202,10 @@ def route_ports_to_x(
         extension_length = -extension_length
 
     if x == "east":
-        x = max(p.x for p in list_ports) + bx
+        x = max(p.dx for p in list_ports) + bx
     elif x == "west":
-        x = min(p.x for p in list_ports) - bx
-    elif isinstance(x, (float, int)):
+        x = min(p.dx for p in list_ports) - bx
+    elif isinstance(x, float | int):
         pass
     else:
         raise ValueError(f"x={x!r} should be a float or east or west")
@@ -234,21 +241,37 @@ def route_ports_to_x(
     ports = []
 
     def add_port(
-        p, y, l_elements, l_ports, start_straight_length=start_straight_length
+        port: Port,
+        y: float,
+        l_elements: list[ManhattanRoute],
+        l_ports: list[Port],
+        start_straight_length: float = start_straight_length,
     ) -> None:
-        new_port = p.copy(name=f"{p.name}_new")
+        if side == "west":
+            angle = 0
+
+        elif side == "east":
+            angle = 180
+
+        new_port = port.copy()
         new_port.orientation = angle
-        new_port.center = (x + extension_length, y)
+        new_port.dx = x + extension_length
+        new_port.dy = y
+
+        new_port2 = new_port.copy()
+        new_port2.trans *= gf.kdb.Trans.R180
+
         l_elements += [
-            routing_func(
-                p,
+            route_single(
+                component,
+                port,
                 new_port,
                 start_straight_length=start_straight_length,
                 radius=radius,
                 **routing_func_args,
             )
         ]
-        l_ports += [new_port.flip()]
+        l_ports += [new_port2]
 
     y_optical_bot = y0_bottom
     for p in south_ports:
@@ -256,7 +279,7 @@ def route_ports_to_x(
         y_optical_bot -= separation
 
     for p in forward_ports:
-        add_port(p, p.y, routes, ports)
+        add_port(p, p.dy, routes, ports)
 
     y_optical_top = y0_top
     for p in north_ports:
@@ -269,10 +292,10 @@ def route_ports_to_x(
 
     for p in backward_ports_thru_north:
         # Extend ports if necessary
-        if angle == 0 and p.x < max_x:
-            start_straight_length_section = max_x - p.x
-        elif angle == 180 and p.x > min_x:
-            start_straight_length_section = p.x - min_x
+        if angle == 0 and p.dx < max_x:
+            start_straight_length_section = max_x - p.dx
+        elif angle == 180 and p.dx > min_x:
+            start_straight_length_section = p.dx - min_x
         else:
             start_straight_length_section = 0
 
@@ -289,10 +312,10 @@ def route_ports_to_x(
     start_straight_length_section = start_straight_length
     for p in backward_ports_thru_south:
         # Extend ports if necessary
-        if angle == 0 and p.x < max_x:
-            start_straight_length_section = max_x - p.x
-        elif angle == 180 and p.x > min_x:
-            start_straight_length_section = p.x - min_x
+        if angle == 0 and p.dx < max_x:
+            start_straight_length_section = max_x - p.dx
+        elif angle == 180 and p.dx > min_x:
+            start_straight_length_section = p.dx - min_x
         else:
             start_straight_length_section = 0
 
@@ -310,49 +333,60 @@ def route_ports_to_x(
 
 
 def route_ports_to_y(
-    list_ports: List[Port],
-    y: Union[float, str] = "north",
+    component: Component,
+    list_ports: list[Port],
+    y: float | Literal["north", "south"] = "north",
     separation: float = 10.0,
     radius: float = 10.0,
-    x0_left: Optional[float] = None,
-    x0_right: Optional[float] = None,
+    x0_left: float | None = None,
+    x0_right: float | None = None,
     extension_length: float = 0.0,
     extend_left: float = 0.0,
     extend_right: float = 0.0,
-    routing_func: Callable = get_route,
     backward_port_side_split_index: int = 0,
     start_straight_length: float = 0.01,
-    dx_start: float = None,
-    dy_start: float = None,
-    **routing_func_args: Dict[Any, Any],
-) -> Tuple[List[Route], List[Port]]:
-    """Args are the following.
+    dx_start: float | None = None,
+    dy_start: float | None = None,
+    side: Literal["north", "south"] = "north",
+    **routing_func_args: dict[Any, Any],
+) -> tuple[list[ManhattanRoute], list[kf.Port]]:
+    """Route ports to y.
 
+    Args:
+        component: component to route.
         list_ports: reasonably well behaved list of ports.
            ports facing north ports are norther than any other ports
            ports facing south ports are souther ...
            ports facing west ports are the wester ...
            ports facing east ports are the easter ...
-
         y: float or string.
                if float: y coordinate to which the ports will be routed
                if string: "north" -> route to north
                if string: "south" -> route to south
-
+        separation: in um.
+        radius: in um.
+        x0_left: in um.
+        x0_right: in um.
+        extension_length: in um.
+        extend_left: in um.
+        extend_right: in um.
         backward_port_side_split_index: integer
                this integer represents and index in the list of backwards ports
                    (sorted from left to right)
                all ports with an index strictly larger are routed right
                all ports with an index lower or equal are routed left
-        separation: in um.
-        radius: in um.
+        start_straight_length: in um.
+        dx_start: override minimum starting x distance.
+        dy_start: override minimum starting y distance.
+        side: "north" or "south".
+        routing_func_args: additional arguments to pass to the routing function.
+
 
     Returns:
         - a list of Routes
         - a list of the new optical ports
 
-    First route the bottom-half of the back ports
-        (back ports are the one facing opposite side of x)
+    First route the bottom-half of the back ports (back ports are the one facing opposite side of x)
     Then route the south ports
     then the front ports
     then the north ports
@@ -379,8 +413,8 @@ def route_ports_to_y(
     bx = epsilon + max(radius, dx_start) if dx_start else a
     by = epsilon + max(radius, dy_start) if dy_start else a
 
-    xs = [p.x for p in list_ports]
-    ys = [p.y for p in list_ports]
+    xs = [p.dx for p in list_ports]
+    ys = [p.dy for p in list_ports]
 
     if x0_left is None:
         x0_left = min(xs) - bx
@@ -393,7 +427,7 @@ def route_ports_to_y(
     if y == "north":
         y = (
             max(
-                p.y + a * np.abs(np.cos(p.orientation * np.pi / 180))
+                p.dy + a * np.abs(np.cos(p.orientation * np.pi / 180))
                 for p in list_ports
             )
             + by
@@ -401,26 +435,24 @@ def route_ports_to_y(
     elif y == "south":
         y = (
             min(
-                p.y - a * np.abs(np.cos(p.orientation * np.pi / 180))
+                p.dy - a * np.abs(np.cos(p.orientation * np.pi / 180))
                 for p in list_ports
             )
             - by
         )
-    elif isinstance(y, (float, int)):
+    elif isinstance(y, float | int):
         pass
     if y <= min(ys):
         sort_key_east = sort_key_south_to_north
         sort_key_west = sort_key_south_to_north
         forward_ports = south_ports
         backward_ports = north_ports
-        angle = 90.0
 
     elif y >= max(ys):
         sort_key_west = sort_key_north_to_south
         sort_key_east = sort_key_north_to_south
         forward_ports = north_ports
         backward_ports = south_ports
-        angle = -90.0
     else:
         raise ValueError("y should be either to the north or to the south of all ports")
 
@@ -436,24 +468,35 @@ def route_ports_to_y(
     backward_ports_thru_west.sort(key=sort_key_west_to_east)
     backward_ports_thru_east.sort(key=sort_key_east_to_west)
 
-    routes = []
-    ports = []
+    routes: list[ManhattanRoute] = []
+    ports: list[Port] = []
 
     def add_port(
-        p, x, l_elements, l_ports, start_straight_length=start_straight_length
-    ):
-        new_port = p.copy()
-        new_port.orientation = angle
-        new_port.center = (x, y + extension_length)
+        port: Port,
+        x: float,
+        l_elements: list[ManhattanRoute],
+        l_ports: list[Port],
+        start_straight_length: float = start_straight_length,
+    ) -> None:
+        if side == "south":
+            angle = 90
 
-        if np.sum(np.abs((new_port.center - p.center) ** 2)) < 1e-12:
+        elif side == "north":
+            angle = 270
+
+        new_port = port.copy()
+        new_port.orientation = angle
+        new_port.dcenter = (x, y + extension_length)
+
+        if np.sum(np.abs((np.array(new_port.center) - port.center) ** 2)) < 1:
             l_ports += [flipped(new_port)]
             return
 
         try:
             l_elements += [
-                routing_func(
-                    p,
+                route_single(
+                    component,
+                    port,
                     new_port,
                     start_straight_length=start_straight_length,
                     radius=radius,
@@ -464,7 +507,7 @@ def route_ports_to_y(
 
         except Exception as error:
             raise ValueError(
-                f"Could not connect {p.name!r} to {new_port.name!r}"
+                f"Could not connect {port.name!r} to {new_port.name!r} {error}"
             ) from error
 
     x_optical_left = x0_left
@@ -473,7 +516,7 @@ def route_ports_to_y(
         x_optical_left -= separation
 
     for p in forward_ports:
-        add_port(p, p.x, routes, ports)
+        add_port(p, p.dx, routes, ports)
 
     x_optical_right = x0_right
     for p in east_ports:
@@ -507,68 +550,29 @@ def route_ports_to_y(
     return routes, ports
 
 
-@gf.cell
-def _sample_route_side() -> Component:
-    c = Component()
-    xs = [0.0, 10.0, 25.0, 50.0]
-    ys = [0.0, 10.0, 25.0, 50.0]
-    a = 5
-    xl = min(xs) - a
-    xr = max(xs) + a
-    yb = min(ys) - a
-    yt = max(ys) + a
-
-    layer = (1, 0)
-
-    c.add_polygon([(xl, yb), (xl, yt), (xr, yt), (xr, yb)], layer)
-
-    for i, y in enumerate(ys):
-        p0 = (xl, y)
-        p1 = (xr, y)
-        c.add_port(name=f"W{i}", center=p0, orientation=180, width=0.5, layer=layer)
-        c.add_port(name=f"E{i}", center=p1, orientation=0, width=0.5, layer=layer)
-
-    for i, x in enumerate(xs):
-        p0 = (x, yb)
-        p1 = (x, yt)
-        c.add_port(name=f"S{i}", center=p0, orientation=270, width=0.5, layer=layer)
-        c.add_port(name=f"N{i}", center=p1, orientation=90, width=0.5, layer=layer)
-
-    return c
-
-
-@gf.cell
-def _sample_route_sides() -> Component:
-    c = Component()
-    dummy = _sample_route_side()
-    sides = ["north", "south", "east", "west"]
-    positions = [(0, 0), (400, 0), (400, 400), (0, 400)]
-    for pos, side in zip(positions, sides):
-        dummy_ref = dummy.ref(position=pos)
-        c.add(dummy_ref)
-        routes, ports = route_ports_to_side(dummy_ref, side, layer=(1, 0))
-        for route in routes:
-            c.add(route.references)
-        for i, p in enumerate(ports):
-            c.add_port(name=f"{side[0]}{i}", port=p)
-    return c
-
-
 if __name__ == "__main__":
     c = Component("sample_route_sides")
-    dummy = gf.components.nxn(north=2, south=2, west=2, east=2)
-    sides = ["north", "south", "east", "west"]
-    d = 100
-    positions = [(0, 0), (d, 0), (d, d), (0, d)]
+    cross_section = "strip"
+    dummy = gf.components.nxn(
+        north=2, south=2, west=2, east=2, cross_section=cross_section
+    )
+    dummy_ref = c << dummy
+    routes = route_ports_to_side(
+        c,
+        dummy_ref.ports,
+        "south",
+        cross_section=cross_section,
+        y=-91,
+        x=-100,
+        # radius=5
+    )
+    # sides = ["north", "south", "east", "west"]
+    # d = 100
+    # positions = [(0, 0), (d, 0), (d, d), (0, d)]
 
-    for pos, side in zip(positions, sides):
-        dummy_ref = dummy.ref(position=pos)
-        c.add(dummy_ref)
-        routes, ports = route_ports_to_side(dummy_ref, side, layer=(1, 0))
-        for route in routes:
-            c.add(route.references)
-        for i, p in enumerate(ports):
-            c.add_port(name=f"{side[0]}{i}", port=p)
+    # for pos, side in zip(positions, sides):
+    #     dummy_ref = c << dummy
+    #     dummy_ref.dcenter = pos
+    #     routes = route_ports_to_side(c, dummy_ref.ports, side, layer=(1, 0))
 
-    # c.plot()
-    c.show(show_ports=True)
+    c.show()
