@@ -1,49 +1,66 @@
 from __future__ import annotations
 
-from typing import Callable, List, Optional, Tuple
-
 import numpy as np
+from kfactory.routing.generic import ManhattanRoute
 
 import gdsfactory as gf
 from gdsfactory.component import Component, ComponentReference
 from gdsfactory.components.bend_euler import bend_euler
 from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.components.taper import taper as taper_function
-from gdsfactory.cross_section import strip
+from gdsfactory.cross_section import CrossSection, strip
 from gdsfactory.port import Port, select_ports_optical
-from gdsfactory.routing.get_route import get_route
-from gdsfactory.routing.utils import direction_ports_from_list_ports, flip
-from gdsfactory.types import ComponentSpec, CrossSectionSpec, Number, Routes
+from gdsfactory.routing.auto_taper import add_auto_tapers
+from gdsfactory.routing.route_single import route_single
+from gdsfactory.routing.utils import direction_ports_from_list_ports
+from gdsfactory.typings import (
+    ComponentSpec,
+    CrossSectionSpec,
+    Radius,
+    SelectPorts,
+    Strs,
+)
 
 
 def route_south(
     component: Component,
+    component_to_route: Component | ComponentReference,
     optical_routing_type: int = 1,
-    excluded_ports: Optional[Tuple[str, ...]] = None,
-    straight_separation: Number = 4.0,
-    io_gratings_lines: Optional[List[List[ComponentReference]]] = None,
+    excluded_ports: tuple[str, ...] | None = None,
+    straight_separation: float = 4.0,
+    io_gratings_lines: list[list[ComponentReference]] | None = None,
     gc_port_name: str = "o1",
     bend: ComponentSpec = bend_euler,
     straight: ComponentSpec = straight_function,
-    taper: Optional[ComponentSpec] = taper_function,
-    select_ports: Callable = select_ports_optical,
+    select_ports: SelectPorts = select_ports_optical,
+    port_names: Strs | None = None,
     cross_section: CrossSectionSpec = strip,
-    **kwargs,
-) -> Routes:
-    """Returns Routes to route a component ports to the south.
+    start_straight_length: float = 0.5,
+    port_type: str | None = None,
+    allow_width_mismatch: bool = False,
+    auto_taper: bool = True,
+) -> list[ManhattanRoute]:
+    """Places routes to route a component ports to the south.
 
     Args:
-        component: component to route.
-        optical_routing_type: routing heuristic `1` or `2`
-            `1` uses the component size info to estimate the box size.
-            `2` only looks at the optical port positions to estimate the size.
+        component: top level component to add the routes.
+        component_to_route: component or reference to route ports to south.
+        optical_routing_type: routing heuristic `1` or `2` \
+            1: uses the component size info to estimate the box size.\
+            2: only looks at the optical port positions to estimate the size.
         excluded_ports: list of port names to NOT route.
         straight_separation: in um.
-        io_gratings_lines: list of ports to which the ports produced by this
-            function will be connected. Supplying this information helps
-            avoiding straight collisions.
-        gc_port_name: grating coupler port name.
-
+        io_gratings_lines: list of ports to which the ports produced by this function will be connected. \
+                Supplying this information helps avoiding straight collisions.
+        gc_port_name: grating coupler port name. Used only if io_gratings_lines is supplied.
+        bend: spec.
+        straight: spec.
+        select_ports: function to select_ports.
+        port_names: optional port names. Overrides select_ports.
+        cross_section: cross_section spec.
+        start_straight_length: in um.
+        port_type: optical or electrical.
+        allow_width_mismatch: allow width mismatch.
+        auto_taper: auto taper.
 
     Works well if the component looks roughly like a rectangular box with:
         north ports on the north of the box.
@@ -56,28 +73,38 @@ def route_south(
 
         import gdsfactory as gf
 
-        c = gf.components.ring_double()
         c = gf.Component()
         ref = c << gf.components.ring_double()
-        r = gf.routing.route_south(ref)
-        for e in r.references:
-            c.add(e)
+        r = gf.routing.route_south(c, ref)
         c.plot()
 
     """
+    c = component
+    component = component_to_route
     xs = gf.get_cross_section(cross_section)
-    excluded_ports = excluded_ports or []
-    assert optical_routing_type in {
+    excluded_ports = excluded_ports or ()
+    start_straight_length0 = start_straight_length
+    routes = []
+
+    if optical_routing_type not in {
         1,
         2,
-    }, f"optical_routing_type = {optical_routing_type}, not supported "
+    }:
+        raise ValueError(
+            f"optical_routing_type = {optical_routing_type} not in supported [1, 2]"
+        )
 
-    optical_ports = list(select_ports(component.ports).values())
-    optical_ports = [p for p in optical_ports if p.name not in excluded_ports]
-    csi = component.size_info
-    references = []
-    lengths = []
-    bend90 = bend(cross_section=cross_section, **kwargs) if callable(bend) else bend
+    if port_names:
+        optical_ports = [component[port_name] for port_name in port_names]
+    else:
+        optical_ports = select_ports(component.ports)
+        optical_ports = [p for p in optical_ports if p.name not in excluded_ports]
+
+    if auto_taper:
+        optical_ports = add_auto_tapers(c, optical_ports, cross_section)
+
+    port_type = port_type or optical_ports[0].port_type
+    bend90 = bend(cross_section=cross_section) if callable(bend) else bend
     bend90 = gf.get_component(bend90)
     dy = abs(bend90.info["dy"])
 
@@ -88,15 +115,15 @@ def route_south(
     conn_params = dict(
         bend=bend,
         straight=straight,
-        taper=taper,
         cross_section=cross_section,
-        **kwargs,
+        port_type=port_type,
+        allow_width_mismatch=allow_width_mismatch,
+        auto_taper=False,
     )
 
     # Used to avoid crossing between straights in special cases
     # This could happen when abs(x_port - x_grating) <= 2 * dy
     delta_gr_min = 2 * dy + 1
-
     sep = straight_separation
 
     # Get lists of optical ports by orientation
@@ -114,26 +141,30 @@ def route_south(
     north_start.reverse()  # Sort right to left
     ordered_ports = north_start + west_ports + south_ports + east_ports + north_finish
 
-    def get_index_port_closest_to_x(x, list_ports):
-        return np.array([abs(x - p.ports[gc_port_name].x) for p in list_ports]).argmin()
+    def get_index_port_closest_to_x(
+        x: float, component_references: list[ComponentReference]
+    ) -> np.intp:
+        return np.array(
+            [abs(x - p.ports[gc_port_name].dx) for p in component_references]
+        ).argmin()
 
-    def gen_port_from_port(x, y, p, cross_section):
+    def gen_port_from_port(
+        x: float, y: float, p: Port, cross_section: CrossSection
+    ) -> Port:
         return Port(
             name=p.name,
             center=(x, y),
             orientation=90.0,
-            width=p.width,
-            cross_section=cross_section,
+            width=p.dwidth,
+            layer=cross_section.layer,
+            port_type=p.port_type,
         )
 
     west_ports.reverse()
-
-    y0 = min(p.y for p in ordered_ports) - dy - 0.5
-
+    y0 = min(p.dy for p in ordered_ports) - dy - 0.5
     ports_to_route = []
 
-    i = 0
-    optical_xs_tmp = [p.x for p in ordered_ports]
+    optical_xs_tmp = [p.dx for p in ordered_ports]
     x_optical_min = min(optical_xs_tmp)
     x_optical_max = max(optical_xs_tmp)
 
@@ -144,7 +175,7 @@ def route_south(
     # The starting x depends on the heuristic chosen : ``1`` or ``2``
     if optical_routing_type == 1:
         # use component size to know how far to route
-        x = csi.west - dy - 1
+        x = component.dxmin - dy - 1
     elif optical_routing_type == 2:
         # use optical port to know how far to route
         x = x_optical_min - dy - 1
@@ -160,7 +191,7 @@ def route_south(
     for p in west_ports:
         if io_gratings_lines:
             i_grating = get_index_port_closest_to_x(x, io_gratings_lines[-1])
-            x_gr = io_gratings_lines[-1][i_grating].ports[gc_port_name].x
+            x_gr = io_gratings_lines[-1][i_grating].ports[gc_port_name].dx
             if abs(x - x_gr) < delta_gr_min:
                 if x > x_gr:
                     x = x_gr
@@ -169,39 +200,34 @@ def route_south(
 
         tmp_port = gen_port_from_port(x, y0, p, cross_section=xs)
         ports_to_route.append(tmp_port)
-        route = get_route(input_port=p, output_port=tmp_port, **conn_params)
-        references.extend(route.references)
-        lengths.append(route.length)
+        route = route_single(c, tmp_port, p, **conn_params)
         x -= sep
 
-        i += 1
-    start_straight_length = 0.5
-
-    # First-half of north ports
-    # This ensures that north ports are routed above the top west one
+    # route first halft of north ports above the top west one
     north_start.reverse()  # We need them from left to right
+
+    start_straight_length = start_straight_length0
     if len(north_start) > 0:
-        y_max = max(p.y for p in west_ports + north_start)
+        y_max = max(p.dy for p in west_ports + north_start)
         for p in north_start:
             tmp_port = gen_port_from_port(x, y0, p, cross_section=xs)
-
-            route = get_route(
-                input_port=p,
-                output_port=tmp_port,
-                start_straight_length=start_straight_length + y_max - p.y,
+            route = route_single(
+                component=c,
+                port2=p,
+                port1=tmp_port,
+                end_straight_length=start_straight_length + y_max - p.dy,
                 **conn_params,
             )
-            references.extend(route.references)
-            lengths.append(route.length)
 
             ports_to_route.append(tmp_port)
             x -= sep
             start_straight_length += sep
+            routes.append(route)
 
     # Set starting ``x`` on the east side
     if optical_routing_type == 1:
         #  use component size to know how far to route
-        x = csi.east + dy + 1
+        x = component.dxmax + dy + 1
     elif optical_routing_type == 2:
         # use optical port to know how far to route
         x = x_optical_max + dy + 1
@@ -209,17 +235,16 @@ def route_south(
         raise ValueError(
             f"Invalid optical routing type. Got {optical_routing_type}, only (1, 2 supported) "
         )
-    i = 0
 
     # Route the east ports
     # In case we have to connect these ports to a line of gratings,
     # Ensure that the port is aligned with the grating port or
     # has enough space for manhattan routing (at least two bend radius)
-    start_straight_length = 0.5
+    start_straight_length = start_straight_length0
     for p in east_ports:
         if io_gratings_lines:
             i_grating = get_index_port_closest_to_x(x, io_gratings_lines[-1])
-            x_gr = io_gratings_lines[-1][i_grating].ports[gc_port_name].x
+            x_gr = io_gratings_lines[-1][i_grating].ports[gc_port_name].dx
             if abs(x - x_gr) < delta_gr_min:
                 if x < x_gr:
                     x = x_gr
@@ -227,51 +252,64 @@ def route_south(
                     x = x_gr + delta_gr_min
 
         tmp_port = gen_port_from_port(x, y0, p, cross_section=xs)
-        route = get_route(
-            p, tmp_port, start_straight_length=start_straight_length, **conn_params
+        route = route_single(
+            c,
+            tmp_port,
+            p,
+            end_straight_length=start_straight_length,
+            **conn_params,
         )
-
-        references.extend(route.references)
-        lengths.append(route.length)
-
+        routes.append(route)
         ports_to_route.append(tmp_port)
         x += sep
-        i += 1
 
     # Route the remaining north ports
-    start_straight_length = 0.5
+    start_straight_length = start_straight_length0
     if len(north_finish) > 0:
-        y_max = max(p.y for p in east_ports + north_finish)
+        y_max = max(p.dy for p in east_ports + north_finish)
         for p in north_finish:
             tmp_port = gen_port_from_port(x, y0, p, cross_section=xs)
             ports_to_route.append(tmp_port)
-            route = get_route(
-                input_port=p,
-                output_port=tmp_port,
-                start_straight_length=start_straight_length + y_max - p.y,
+            route = route_single(
+                c,
+                tmp_port,
+                p,
+                end_straight_length=start_straight_length + y_max - p.dy,
                 **conn_params,
             )
-            references.extend(route.references)
-            lengths.append(route.length)
             x += sep
             start_straight_length += sep
+            routes.append(route)
 
-    # Add south ports
-    ports = [flip(p) for p in ports_to_route] + south_ports
-    return Routes(references=references, ports=ports, lengths=lengths)
+    flipped_ports = [p.copy() for p in ports_to_route]
+    for p in flipped_ports:
+        p.trans *= gf.kdb.Trans.R180
+    c.add_ports(flipped_ports)
+    c.add_ports(south_ports)
+    c.auto_rename_ports()
+    return routes
 
 
 if __name__ == "__main__":
-    # c = gf.components.mmi2x2()
-    # c = gf.components.ring_single()
-
-    c = gf.components.ring_double()
-    layer = (2, 0)
     c = gf.Component()
-    ref = c << gf.components.ring_double(layer=layer)
-    r = route_south(ref, bend=gf.components.bend_euler, layer=layer)
-    for e in r.references:
-        c.add(e)
 
-    print(r.lengths)
-    c.show(show_ports=True)
+    @gf.cell
+    def mzi_with_bend(radius: Radius = 10) -> Component:
+        c = gf.Component()
+        bend = c.add_ref(gf.components.bend_euler(radius=radius))
+        mzi = c.add_ref(gf.components.mzi())
+        bend.connect("o1", mzi.ports["o2"])
+        c.add_port(name="o1", port=mzi.ports["o1"])
+        c.add_port(name="o2", port=bend.ports["o2"])
+        return c
+
+    component = gf.c.mzi_phase_shifter()
+    component = mzi_with_bend()
+    component = gf.components.mmi2x2()
+    component = gf.components.nxn(north=4, south=2, west=2, east=2)
+    component = gf.components.straight(length=10, width=2)
+    ref = c << component
+    # r = route_south(c, ref, optical_routing_type=1, start_straight_length=0)
+    r = route_south(c, ref, auto_taper=True)
+    # print(r.lengths)
+    c.show()
