@@ -10,11 +10,11 @@ from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import Layer
+from gdsfactory.typings import ComponentFactory, Layer
 
 
 @gf.cell
-def test_crossing_arm(
+def crossing_arm(
     wg_width: float = 0.5,
     r1: float = 3.0,
     r2: float = 1.1,
@@ -23,9 +23,19 @@ def test_crossing_arm(
     layer_wg: Layer = (1, 0),
     layer_slab: Layer = (2, 0),
 ) -> Component:
-    """Crossing arm."""
+    """Crossing arm.
+
+    Args:
+        wg_width: waveguide width.
+        r1: radius of the ellipse.
+        r2: radius of the ellipse.
+        taper_width: width of the taper.
+        taper_length: length of the taper.
+        layer_wg: waveguide layer.
+        layer_slab: slab layer.
+    """
     c = gf.Component()
-    c << gf.components.ellipse(radii=(r1, r2), layer=layer_slab)
+    _ = c << gf.components.ellipse(radii=(r1, r2), layer=layer_slab)
 
     xmax = taper_length + taper_width / 2
     h = wg_width / 2
@@ -52,30 +62,34 @@ def test_crossing_arm(
     return c
 
 
-@gf.cell  # This decorator will generate a good name for the component
-def test_crossing() -> Component:
-    c = gf.Component()
-    arm = test_crossing_arm()
+@gf.cell
+def crossing(
+    arm: ComponentFactory = crossing_arm,
+    cross_section: str = "strip",
+) -> Component:
+    """Waveguide crossing.
 
-    # Create two arm references. One has a 90Deg rotation
-    arm_h = arm.ref(position=(0, 0))
-    arm_v = arm.ref(position=(0, 0), rotation=90)
-
-    # Add each arm to the component
-    # Also add the ports
+    Args:
+        arm: arm spec.
+        cross_section: spec.
+    """
+    x = gf.get_cross_section(cross_section)
+    c = Component()
+    arm_c = gf.get_component(arm)
     port_id = 0
-    for a in [arm_h, arm_v]:
-        c.add(a)
-        for p in a.ports.values():
-            # Here we don't care too much about the name we give to the ports
-            # since they will be renamed. We just want the names to be unique
-            c.add_port(name=f"{port_id}", port=p)
+    for rotation in [0, 90]:
+        ref = c << arm_c
+        ref.drotate(rotation)
+        for p in ref.ports:
+            c.add_port(name=str(port_id), port=p)
             port_id += 1
 
     c.auto_rename_ports()
+    x.add_bbox(c)
+    c.flatten()
     return c
 
 
 if __name__ == "__main__":
-    c = test_crossing()
-    c.show(show_ports=True)
+    c = crossing()
+    c.show()
