@@ -12,11 +12,11 @@ from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import LayerSpec
+from gdsfactory.typings import LayerSpec
 
 
 @gf.cell
-def test_component_with_port(
+def component_with_port(
     length: float = 5.0, width: float = 0.5, layer: LayerSpec = "WG"
 ) -> Component:
     """Returns a component with one port on the west side.
@@ -25,18 +25,20 @@ def test_component_with_port(
         length: in um.
         width: waveguide width in um.
         layer: layer.
-
     """
-    y = width
-    x = length
-
     c = gf.Component()
-    c.add_polygon([(0, 0), (x, 0), (x, y), (0, y)], layer=layer)
-    c.add_port(name="o1", center=(0, y / 2), width=y, orientation=180, layer=layer)
+    c.add_polygon([(0, 0), (length, 0), (length, width), (0, width)], layer=layer)
+    c.add_port(
+        name="o1", center=(0, width / 2), width=width, orientation=180, layer=layer
+    )
     assert len(c.ports) == 1
     return c
 
 
+def test_component_with_port() -> None:
+    assert component_with_port()
+
+
 if __name__ == "__main__":
-    c = test_component_with_port()
-    c.show(show_ports=True)
+    c = component_with_port()
+    c.show()
