@@ -5,8 +5,8 @@ from .phase_shifters import (
     ps_heater_doped,
     ps_heater_metal,
     ps_pin,
-    xs_rib_heater_doped,
-    xs_rib_pin,
+    rib_heater_doped,
+    rib_pin,
     xs_strip_heater_metal,
 )
 
@@ -21,7 +21,7 @@ __all__ = [
     "ps_heater_doped",
     "ps_heater_metal",
     "ps_pin",
-    "xs_rib_heater_doped",
-    "xs_rib_pin",
+    "rib_heater_doped",
+    "rib_pin",
     "xs_strip_heater_metal",
 ]
