@@ -7,6 +7,7 @@ the same repo as you store the code. See code below
 
 ```
 from __future__ import annotations
+from functools import partial
 import pathlib
 
 dirpath = pathlib.Path(__file__).absolute().with_suffix(".gds")
@@ -20,18 +21,39 @@ def test_gds(component_name: str) -> None:
 
 """
 
+from collections.abc import Generator
+from typing import Any
 
 import pytest
 from pytest_regressions.data_regression import DataRegressionFixture
 
 from gdsfactory.difftest import difftest
+from gdsfactory.generic_tech import get_generic_pdk
 from gdsfactory.samples.pdk.fab_c import cells
 
 cell_names = list(cells.keys())
 
 
+@pytest.fixture(autouse=True)
+def activate_pdk() -> Generator[None, Any, None]:
+    from gdsfactory.samples.pdk.fab_c import PDK
+
+    PDK.activate()
+    yield
+    pdk = get_generic_pdk()
+    pdk.activate()
+
+
+def test_to_updk() -> None:
+    from gdsfactory.samples.pdk.fab_c import PDK
+
+    PDK.activate()
+    yaml_pdk_decription = PDK.to_updk()
+    assert yaml_pdk_decription
+
+
 @pytest.fixture(params=cell_names, scope="function")
-def component_name(request) -> str:
+def component_name(request: pytest.FixtureRequest) -> Any:
     return request.param
 
 
@@ -52,13 +74,8 @@ def test_settings(component_name: str, data_regression: DataRegressionFixture) -
     data_regression.check(component.to_dict())
 
 
-def test_assert_ports_on_grid(component_name: str) -> None:
-    """Ensures all ports are on grid to avoid 1nm gaps."""
-    component = cells[component_name]()
-    component.assert_ports_on_grid()
-
-
 if __name__ == "__main__":
-    print(cell_names)
-    c = cells[cell_names[0]]()
-    difftest(c, test_name=f"fabc_{cell_names[0]}")
+    # print(cell_names)
+    # c = cells[cell_names[0]]()
+    # difftest(c, test_name=f"fabc_{cell_names[0]}")
+    test_to_updk()
